
#include <pmu-events/pmu-events.h>
#include "util/header.h"
#include "util/pmu.h"
#include <string.h>
#include <stddef.h>

struct compact_pmu_event {
        int offset;
};

struct pmu_table_entry {
        const struct compact_pmu_event *entries;
        uint32_t num_entries;
        struct compact_pmu_event pmu_name;
};

static const char *const big_c_string =
/* offset=0 */ "cpum_cf\000"
/* offset=8 */ "cpu_cycles\000basic\000Cycle Count\000event=0\000\00000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000"
/* offset=167 */ "instructions\000basic\000Instruction Count\000event=1\000\00000\000This counter counts the total number of instructions executed by the CPU\000"
/* offset=289 */ "l1i_dir_writes\000basic\000Level-1 I-Cache Directory Write Count\000event=2\000\00000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000"
/* offset=460 */ "l1i_penalty_cycles\000basic\000Level-1 I-Cache Penalty Cycle Count\000event=3\000\00000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000"
/* offset=641 */ "l1d_dir_writes\000basic\000Level-1 D-Cache Directory Write Count\000event=4\000\00000\000This counter counts the total number of level-1 data-cache directory writes\000"
/* offset=788 */ "l1d_penalty_cycles\000basic\000Level-1 D-Cache Penalty Cycle Count\000event=5\000\00000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000"
/* offset=945 */ "problem_state_cpu_cycles\000basic\000Problem-State Cycle Count\000event=0x20\000\00000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000"
/* offset=1172 */ "problem_state_instructions\000basic\000Problem-State Instruction Count\000event=0x21\000\00000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000"
/* offset=1352 */ "problem_state_l1i_dir_writes\000basic\000Problem-State Level-1 I-Cache Directory Write Count\000event=0x22\000\00000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes while the CPU is in the problem state\000"
/* offset=1592 */ "problem_state_l1i_penalty_cycles\000basic\000Level-1 I-Cache Penalty Cycle Count\000event=0x23\000\00000\000This counter counts the total number of penalty cycles for level-1 instruction cache or unified cache while the CPU is in the problem state\000"
/* offset=1822 */ "problem_state_l1d_dir_writes\000basic\000Problem-State Level-1 D-Cache Directory Write Count\000event=0x24\000\00000\000This counter counts the total number of level-1 data-cache directory writes while the CPU is in the problem state\000"
/* offset=2038 */ "problem_state_l1d_penalty_cycles\000basic\000Problem-State Level-1 D-Cache Penalty Cycle Count\000event=0x25\000\00000\000This counter counts the total number of penalty cycles for level-1 data cache while the CPU is in the problem state\000"
/* offset=2258 */ "prng_functions\000crypto\000PRNG Function Count\000event=0x40\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000"
/* offset=2418 */ "prng_cycles\000crypto\000PRNG Cycle Count\000event=0x41\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000"
/* offset=2636 */ "prng_blocked_functions\000crypto\000PRNG Blocked Function Count\000event=0x42\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=2925 */ "prng_blocked_cycles\000crypto\000PRNG Blocked Cycle Count\000event=0x43\000\00000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=3206 */ "sha_functions\000crypto\000SHA Function Count\000event=0x44\000\00000\000This counter counts the total number of the SHA functions issued by the CPU\000"
/* offset=3337 */ "sha_cycles\000crypto\000SHA Cycle Count\000event=0x45\000\00000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000"
/* offset=3517 */ "sha_blocked_functions\000crypto\000SHA Blocked Function Count\000event=0x46\000\00000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=3769 */ "sha_blocked_cycles\000crypto\000SHA Blocked Cycle Count\000event=0x47\000\00000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=4013 */ "dea_functions\000crypto\000DEA Function Count\000event=0x48\000\00000\000This counter counts the total number of the DEA functions issued by the CPU\000"
/* offset=4144 */ "dea_cycles\000crypto\000DEA Cycle Count\000event=0x49\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000"
/* offset=4328 */ "dea_blocked_functions\000crypto\000DEA Blocked Function Count\000event=0x4a\000\00000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=4584 */ "dea_blocked_cycles\000crypto\000DEA Blocked Cycle Count\000event=0x4b\000\00000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=4832 */ "aes_functions\000crypto\000AES Function Count\000event=0x4c\000\00000\000This counter counts the total number of the AES functions issued by the CPU\000"
/* offset=4963 */ "aes_cycles\000crypto\000AES Cycle Count\000event=0x4d\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000"
/* offset=5147 */ "aes_blocked_functions\000crypto\000AES Blocked Function Count\000event=0x4e\000\00000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=5403 */ "aes_blocked_cycles\000crypto\000AES Blocked Cycle Count\000event=0x4f\000\00000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=5651 */ "l1i_l2_sourced_writes\000extended\000L1I L2 Sourced Writes\000event=0x80\000\00000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from the Level-2 (L1.5) cache\000"
/* offset=5852 */ "l1d_l2_sourced_writes\000extended\000L1D L2 Sourced Writes\000event=0x81\000\00000\000A directory write to the Level-1 Data Cache directory where the installed cache line was sourced from the Level-2 (L1.5) cache\000"
/* offset=6047 */ "l1i_l3_local_writes\000extended\000L1I L3 Local Writes\000event=0x82\000\00000\000A directory write to the Level-1 Instruction Cache directory where the installed cache line was sourced from the Level-3 cache that is on the same book as the Instruction cache (Local L2 cache)\000"
/* offset=6305 */ "l1d_l3_local_writes\000extended\000L1D L3 Local Writes\000event=0x83\000\00000\000A directory write to the Level-1 Data Cache directory where the installed cache line was source from the Level-3 cache that is on the same book as the Data cache (Local L2 cache)\000"
/* offset=6548 */ "l1i_l3_remote_writes\000extended\000L1I L3 Remote Writes\000event=0x84\000\00000\000A directory write to the Level-1 Instruction Cache directory where the installed cache line was sourced from a Level-3 cache that is not on the same book as the Instruction cache (Remote L2 cache)\000"
/* offset=6811 */ "l1d_l3_remote_writes\000extended\000L1D L3 Remote Writes\000event=0x85\000\00000\000A directory write to the Level-1 Data Cache directory where the installed cache line was sourced from a Level-3 cache that is not on the same book as the Data cache (Remote L2 cache)\000"
/* offset=7060 */ "l1d_lmem_sourced_writes\000extended\000L1D Local Memory Sourced Writes\000event=0x86\000\00000\000A directory write to the Level-1 Data Cache directory where the installed cache line was sourced from memory that is attached to the same book as the Data cache (Local Memory)\000"
/* offset=7316 */ "l1i_lmem_sourced_writes\000extended\000L1I Local Memory Sourced Writes\000event=0x87\000\00000\000A directory write to the Level-1 Instruction Cache where the installed cache line was sourced from memory that is attached to the s ame book as the Instruction cache (Local Memory)\000"
/* offset=7577 */ "l1d_ro_excl_writes\000extended\000L1D Read-only Exclusive Writes\000event=0x88\000\00000\000A directory write to the Level-1 Data Cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000"
/* offset=7846 */ "l1i_cacheline_invalidates\000extended\000L1I Cacheline Invalidates\000event=0x89\000\00000\000A cache line in the Level-1 Instruction Cache has been invalidated by a store on the same CPU as the Level-1 Instruction Cache\000"
/* offset=8049 */ "itlb1_writes\000extended\000ITLB1 Writes\000event=0x8a\000\00000\000A translation entry has been written into the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000"
/* offset=8202 */ "dtlb1_writes\000extended\000DTLB1 Writes\000event=0x8b\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000"
/* offset=8346 */ "tlb2_pte_writes\000extended\000TLB2 PTE Writes\000event=0x8c\000\00000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000"
/* offset=8482 */ "tlb2_crste_writes\000extended\000TLB2 CRSTE Writes\000event=0x8d\000\00000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays\000"
/* offset=8639 */ "tlb2_crste_hpage_writes\000extended\000TLB2 CRSTE One-Megabyte Page Writes\000event=0x8e\000\00000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays for a one-megabyte large page translation\000"
/* offset=8862 */ "itlb1_misses\000extended\000ITLB1 Misses\000event=0x91\000\00000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle an ITLB1 miss is in progress\000"
/* offset=9018 */ "dtlb1_misses\000extended\000DTLB1 Misses\000event=0x92\000\00000\000Level-1 Data TLB miss in progress. Incremented by one for every cycle an DTLB1 miss is in progress\000"
/* offset=9167 */ "l2c_stores_sent\000extended\000L2C Stores Sent\000event=0x93\000\00000\000Incremented by one for every store sent to Level-2 (L1.5) cache\000"
/* offset=9287 */ "l1d_ro_excl_writes\000extended\000L1D Read-only Exclusive Writes\000event=0x80\000\00000\000A directory write to the Level-1 Data cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000"
/* offset=9556 */ "dtlb1_writes\000extended\000DTLB1 Writes\000event=0x81\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000"
/* offset=9700 */ "dtlb1_misses\000extended\000DTLB1 Misses\000event=0x82\000\00000\000Level-1 Data TLB miss in progress. Incremented by one for every cycle a DTLB1 miss is in progress\000"
/* offset=9848 */ "dtlb1_hpage_writes\000extended\000DTLB1 One-Megabyte Page Writes\000event=0x83\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a one-megabyte page\000"
/* offset=10032 */ "dtlb1_gpage_writes\000extended\000DTLB1 Two-Gigabyte Page Writes\000event=0x84\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a two-gigabyte page\000"
/* offset=10216 */ "l1d_l2d_sourced_writes\000extended\000L1D L2D Sourced Writes\000event=0x85\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache\000"
/* offset=10410 */ "itlb1_writes\000extended\000ITLB1 Writes\000event=0x86\000\00000\000A translation entry has been written to the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000"
/* offset=10561 */ "itlb1_misses\000extended\000ITLB1 Misses\000event=0x87\000\00000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle an ITLB1 miss is in progress\000"
/* offset=10717 */ "l1i_l2i_sourced_writes\000extended\000L1I L2I Sourced Writes\000event=0x88\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000"
/* offset=10925 */ "tlb2_pte_writes\000extended\000TLB2 PTE Writes\000event=0x89\000\00000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000"
/* offset=11061 */ "tlb2_crste_hpage_writes\000extended\000TLB2 CRSTE One-Megabyte Page Writes\000event=0x8a\000\00000\000A translation entry has been written to the Level-2 TLB Combined Region Segment Table Entry arrays for a one-megabyte large page translation\000"
/* offset=11286 */ "tlb2_crste_writes\000extended\000TLB2 CRSTE Writes\000event=0x8b\000\00000\000A translation entry has been written to the Level-2 TLB Combined Region Segment Table Entry arrays\000"
/* offset=11445 */ "tx_c_tend\000extended\000Completed TEND instructions in constrained TX mode\000event=0x8c\000\00000\000A TEND instruction has completed in a constrained transactional-execution mode\000"
/* offset=11609 */ "tx_nc_tend\000extended\000Completed TEND instructions in non-constrained TX mode\000event=0x8d\000\00000\000A TEND instruction has completed in a non-constrained transactional-execution mode\000"
/* offset=11782 */ "l1c_tlb1_misses\000extended\000L1C TLB1 Misses\000event=0x8f\000\00000\000Increments by one for any cycle where a Level-1 cache or Level-1 TLB miss is in progress\000"
/* offset=11927 */ "l1d_onchip_l3_sourced_writes\000extended\000L1D On-Chip L3 Sourced Writes\000event=0x90\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention\000"
/* offset=12157 */ "l1d_onchip_l3_sourced_writes_iv\000extended\000L1D On-Chip L3 Sourced Writes with Intervention\000event=0x91\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache with intervention\000"
/* offset=12405 */ "l1d_onnode_l4_sourced_writes\000extended\000L1D On-Node L4 Sourced Writes\000event=0x92\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Node Level-4 cache\000"
/* offset=12614 */ "l1d_onnode_l3_sourced_writes_iv\000extended\000L1D On-Node L3 Sourced Writes with Intervention\000event=0x93\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Node Level-3 cache with intervention\000"
/* offset=12862 */ "l1d_onnode_l3_sourced_writes\000extended\000L1D On-Node L3 Sourced Writes\000event=0x94\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Node Level-3 cache without intervention\000"
/* offset=13092 */ "l1d_ondrawer_l4_sourced_writes\000extended\000L1D On-Drawer L4 Sourced Writes\000event=0x95\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-4 cache\000"
/* offset=13307 */ "l1d_ondrawer_l3_sourced_writes_iv\000extended\000L1D On-Drawer L3 Sourced Writes with Intervention\000event=0x96\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache with intervention\000"
/* offset=13561 */ "l1d_ondrawer_l3_sourced_writes\000extended\000L1D On-Drawer L3 Sourced Writes\000event=0x97\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache without intervention\000"
/* offset=13797 */ "l1d_offdrawer_scol_l4_sourced_writes\000extended\000L1D Off-Drawer Same-Column L4 Sourced Writes\000event=0x98\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-4 cache\000"
/* offset=14044 */ "l1d_offdrawer_scol_l3_sourced_writes_iv\000extended\000L1D Off-Drawer Same-Column L3 Sourced Writes with Intervention\000event=0x99\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache with intervention\000"
/* offset=14330 */ "l1d_offdrawer_scol_l3_sourced_writes\000extended\000L1D Off-Drawer Same-Column L3 Sourced Writes\000event=0x9a\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache without intervention\000"
/* offset=14598 */ "l1d_offdrawer_fcol_l4_sourced_writes\000extended\000L1D Off-Drawer Far-Column L3 Sourced Writes\000event=0x9b\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-4 cache\000"
/* offset=14843 */ "l1d_offdrawer_fcol_l3_sourced_writes_iv\000extended\000L1D Off-Drawer Far-Column L3 Sourced Writes with Intervention\000event=0x9c\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache with intervention\000"
/* offset=15127 */ "l1d_offdrawer_fcol_l3_sourced_writes\000extended\000L1D Off-Drawer Far-Column L3 Sourced Writes\000event=0x9d\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache without intervention\000"
/* offset=15393 */ "l1d_onnode_mem_sourced_writes\000extended\000L1D On-Node Memory Sourced Writes\000event=0x9e\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Node memory\000"
/* offset=15597 */ "l1d_ondrawer_mem_sourced_writes\000extended\000L1D On-Drawer Memory Sourced Writes\000event=0x9f\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer memory\000"
/* offset=15807 */ "l1d_offdrawer_mem_sourced_writes\000extended\000L1D Off-Drawer Memory Sourced Writes\000event=0xa0\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory\000"
/* offset=16020 */ "l1d_onchip_mem_sourced_writes\000extended\000L1D On-Chip Memory Sourced Writes\000event=0xa1\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory\000"
/* offset=16224 */ "l1i_onchip_l3_sourced_writes\000extended\000L1I On-Chip L3 Sourced Writes\000event=0xa2\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention\000"
/* offset=16461 */ "l1i_onchip_l3_sourced_writes_iv\000extended\000L1I On-Chip L3 Sourced Writes with Intervention\000event=0xa3\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Chip Level-3 cache with intervention\000"
/* offset=16716 */ "l1i_onnode_l4_sourced_writes\000extended\000L1I On-Chip L4 Sourced Writes\000event=0xa4\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Node Level-4 cache\000"
/* offset=16932 */ "l1i_onnode_l3_sourced_writes_iv\000extended\000L1I On-Node L3 Sourced Writes with Intervention\000event=0xa5\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Node Level-3 cache with intervention\000"
/* offset=17187 */ "l1i_onnode_l3_sourced_writes\000extended\000L1I On-Node L3 Sourced Writes\000event=0xa6\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Node Level-3 cache without intervention\000"
/* offset=17424 */ "l1i_ondrawer_l4_sourced_writes\000extended\000L1I On-Drawer L4 Sourced Writes\000event=0xa7\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-4 cache\000"
/* offset=17646 */ "l1i_ondrawer_l3_sourced_writes_iv\000extended\000L1I On-Drawer L3 Sourced Writes with Intervention\000event=0xa8\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache with intervention\000"
/* offset=17907 */ "l1i_ondrawer_l3_sourced_writes\000extended\000L1I On-Drawer L3 Sourced Writes\000event=0xa9\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache without intervention\000"
/* offset=18150 */ "l1i_offdrawer_scol_l4_sourced_writes\000extended\000L1I Off-Drawer Same-Column L4 Sourced Writes\000event=0xaa\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-4 cache\000"
/* offset=18404 */ "l1i_offdrawer_scol_l3_sourced_writes_iv\000extended\000L1I Off-Drawer Same-Column L3 Sourced Writes with Intervention\000event=0xab\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache with intervention\000"
/* offset=18697 */ "l1i_offdrawer_scol_l3_sourced_writes\000extended\000L1I Off-Drawer Same-Column L3 Sourced Writes\000event=0xac\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache without intervention\000"
/* offset=18972 */ "l1i_offdrawer_fcol_l4_sourced_writes\000extended\000L1I Off-Drawer Far-Column L4 Sourced Writes\000event=0xad\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-4 cache\000"
/* offset=19224 */ "l1i_offdrawer_fcol_l3_sourced_writes_iv\000extended\000L1I Off-Drawer Far-Column L3 Sourced Writes with Intervention\000event=0xae\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache with intervention\000"
/* offset=19515 */ "l1i_offdrawer_fcol_l3_sourced_writes\000extended\000L1I Off-Drawer Far-Column L3 Sourced Writes\000event=0xaf\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache without intervention\000"
/* offset=19788 */ "l1i_onnode_mem_sourced_writes\000extended\000L1I On-Node Memory Sourced Writes\000event=0xb0\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Node memory\000"
/* offset=19999 */ "l1i_ondrawer_mem_sourced_writes\000extended\000L1I On-Drawer Memory Sourced Writes\000event=0xb1\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer memory\000"
/* offset=20216 */ "l1i_offdrawer_mem_sourced_writes\000extended\000L1I Off-Drawer Memory Sourced Writes\000event=0xb2\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer memory\000"
/* offset=20435 */ "l1i_onchip_mem_sourced_writes\000extended\000L1I On-Chip Memory Sourced Writes\000event=0xb3\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Chip memory\000"
/* offset=20646 */ "tx_nc_tabort\000extended\000Aborted transactions in non-constrained TX mode\000event=0xda\000\00000\000A transaction abort has occurred in a non-constrained transactional-execution mode\000"
/* offset=20814 */ "tx_c_tabort_no_special\000extended\000Aborted transactions in constrained TX mode not using special completion logic\000event=0xdb\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000"
/* offset=21099 */ "tx_c_tabort_special\000extended\000Aborted transactions in constrained TX mode using special completion logic\000event=0xdc\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000"
/* offset=21369 */ "mt_diag_cycles_one_thr_active\000extended\000Cycle count with one thread active\000event=0x1c0\000\00000\000Cycle count with one thread active\000"
/* offset=21494 */ "mt_diag_cycles_two_thr_active\000extended\000Cycle count with two threads active\000event=0x1c1\000\00000\000Cycle count with two threads active\000"
/* offset=21621 */ "dtlb2_writes\000extended\000DTLB2 Writes\000event=0x81\000\00000\000A translation has been written into The Translation Lookaside Buffer 2 (TLB2) and the request was made by the data cache. This is a replacement for what was provided for the DTLB on prior machines\000"
/* offset=21868 */ "dtlb2_misses\000extended\000DTLB2 Misses\000event=0x82\000\00000\000A TLB2 miss is in progress for a request made by the data cache. Incremented by one for every TLB2 miss in progress for the Level-1 Data cache on this cycle. This is a replacement for what was provided for the DTLB on prior machines\000"
/* offset=22151 */ "dtlb2_hpage_writes\000extended\000DTLB2 One-Megabyte Page Writes\000event=0x83\000\00000\000A translation entry was written into the Combined Region and Segment Table Entry array in the Level-2 TLB for a one-megabyte page or a Last Host Translation was done\000"
/* offset=22391 */ "dtlb2_gpage_writes\000extended\000DTLB2 Two-Gigabyte Page Writes\000event=0x84\000\00000\000A translation entry for a two-gigabyte page was written into the Level-2 TLB\000"
/* offset=22542 */ "itlb2_writes\000extended\000ITLB2 Writes\000event=0x86\000\00000\000A translation entry has been written into the Translation Lookaside Buffer 2 (TLB2) and the request was made by the instruction cache. This is a replacement for what was provided for the ITLB on prior machines\000"
/* offset=22802 */ "itlb2_misses\000extended\000ITLB2 Misses\000event=0x87\000\00000\000A TLB2 miss is in progress for a request made by the instruction cache. Incremented by one for every TLB2 miss in progress for the Level-1 Instruction cache in a cycle. This is a replacement for what was provided for the ITLB on prior machines\000"
/* offset=23096 */ "tlb2_pte_writes\000extended\000TLB2 PTE Writes\000event=0x89\000\00000\000A translation entry was written into the Page Table Entry array in the Level-2 TLB\000"
/* offset=23235 */ "tlb2_crste_writes\000extended\000TLB2 CRSTE Writes\000event=0x8a\000\00000\000Translation entries were written into the Combined Region and Segment Table Entry array and the Page Table Entry array in the Level-2 TLB\000"
/* offset=23433 */ "tlb2_engines_busy\000extended\000TLB2 Engines Busy\000event=0x8b\000\00000\000The number of Level-2 TLB translation engines busy in a cycle\000"
/* offset=23555 */ "l1c_tlb2_misses\000extended\000L1C TLB2 Misses\000event=0x8f\000\00000\000Increments by one for any cycle where a level-1 cache or level-2 TLB miss is in progress\000"
/* offset=23700 */ "l1d_onchip_memory_sourced_writes\000extended\000L1D On-Chip Memory Sourced Writes\000event=0x91\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory\000"
/* offset=23907 */ "l1d_onchip_l3_sourced_writes_iv\000extended\000L1D On-Chip L3 Sourced Writes with Intervention\000event=0x92\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache with intervention\000"
/* offset=24155 */ "l1d_oncluster_l3_sourced_writes\000extended\000L1D On-Cluster L3 Sourced Writes\000event=0x93\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Cluster Level-3 cache without intervention\000"
/* offset=24391 */ "l1d_oncluster_memory_sourced_writes\000extended\000L1D On-Cluster Memory Sourced Writes\000event=0x94\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster memory\000"
/* offset=24610 */ "l1d_oncluster_l3_sourced_writes_iv\000extended\000L1D On-Cluster L3 Sourced Writes with Intervention\000event=0x95\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache with intervention\000"
/* offset=24867 */ "l1d_offcluster_l3_sourced_writes\000extended\000L1D Off-Cluster L3 Sourced Writes\000event=0x96\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention\000"
/* offset=25109 */ "l1d_offcluster_memory_sourced_writes\000extended\000L1D Off-Cluster Memory Sourced Writes\000event=0x97\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Cluster memory\000"
/* offset=25328 */ "l1d_offcluster_l3_sourced_writes_iv\000extended\000L1D Off-Cluster L3 Sourced Writes with Intervention\000event=0x98\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention\000"
/* offset=25588 */ "l1d_offdrawer_l3_sourced_writes\000extended\000L1D Off-Drawer L3 Sourced Writes\000event=0x99\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention\000"
/* offset=25827 */ "l1d_offdrawer_memory_sourced_writes\000extended\000L1D Off-Drawer Memory Sourced Writes\000event=0x9a\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory\000"
/* offset=26043 */ "l1d_offdrawer_l3_sourced_writes_iv\000extended\000L1D Off-Drawer L3 Sourced Writes with Intervention\000event=0x9b\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention\000"
/* offset=26300 */ "l1d_ondrawer_l4_sourced_writes\000extended\000L1D On-Drawer L4 Sourced Writes\000event=0x9c\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer Level-4 cache\000"
/* offset=26512 */ "l1d_offdrawer_l4_sourced_writes\000extended\000L1D Off-Drawer L4 Sourced Writes\000event=0x9d\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache\000"
/* offset=26727 */ "l1d_onchip_l3_sourced_writes_ro\000extended\000L1D On-Chip L3 Sourced Writes read-only\000event=0x9e\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip L3 but a read-only invalidate was done to remove other copies of the cache line\000"
/* offset=27012 */ "l1i_onchip_l3_sourced_writes\000extended\000L1I On-Chip L3 Sourced Writes\000event=0xa2\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache without intervention\000"
/* offset=27248 */ "l1i_onchip_memory_sourced_writes\000extended\000L1I On-Chip Memory Sourced Writes\000event=0xa3\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from On-Chip memory\000"
/* offset=27461 */ "l1i_onchip_l3_sourced_writes_iv\000extended\000L1I On-Chip L3 Sourced Writes with Intervention\000event=0xa4\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache with intervention\000"
/* offset=27715 */ "l1i_oncluster_l3_sourced_writes\000extended\000L1I On-Cluster L3 Sourced Writes\000event=0xa5\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache without intervention\000"
/* offset=27961 */ "l1i_oncluster_memory_sourced_writes\000extended\000L1I On-Cluster Memory Sourced Writes\000event=0xa6\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster memory\000"
/* offset=28187 */ "l1i_oncluster_l3_sourced_writes_iv\000extended\000L1I On-Cluster L3 Sourced Writes with Intervention\000event=0xa7\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Cluster Level-3 cache with intervention\000"
/* offset=28448 */ "l1i_offcluster_l3_sourced_writes\000extended\000L1I Off-Cluster L3 Sourced Writes\000event=0xa8\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention\000"
/* offset=28697 */ "l1i_offcluster_memory_sourced_writes\000extended\000L1I Off-Cluster Memory Sourced Writes\000event=0xa9\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Cluster memory\000"
/* offset=28923 */ "l1i_offcluster_l3_sourced_writes_iv\000extended\000L1I Off-Cluster L3 Sourced Writes with Intervention\000event=0xaa\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention\000"
/* offset=29190 */ "l1i_offdrawer_l3_sourced_writes\000extended\000L1I Off-Drawer L3 Sourced Writes\000event=0xab\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention\000"
/* offset=29436 */ "l1i_offdrawer_memory_sourced_writes\000extended\000L1I Off-Drawer Memory Sourced Writes\000event=0xac\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer memory\000"
/* offset=29659 */ "l1i_offdrawer_l3_sourced_writes_iv\000extended\000L1I Off-Drawer L3 Sourced Writes with Intervention\000event=0xad\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention\000"
/* offset=29923 */ "l1i_ondrawer_l4_sourced_writes\000extended\000L1I On-Drawer L4 Sourced Writes\000event=0xae\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer Level-4 cache\000"
/* offset=30142 */ "l1i_offdrawer_l4_sourced_writes\000extended\000L1I Off-Drawer L4 Sourced Writes\000event=0xaf\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache\000"
/* offset=30364 */ "bcd_dfp_execution_slots\000extended\000BCD DFP Execution Slots\000event=0xe0\000\00000\000Count of floating point execution slots used for finished Binary Coded Decimal to Decimal Floating Point conversions. Instructions: CDZT, CXZT, CZDT, CZXT\000"
/* offset=30591 */ "vx_bcd_execution_slots\000extended\000VX BCD Execution Slots\000event=0xe1\000\00000\000Count of floating point execution slots used for finished vector arithmetic Binary Coded Decimal instructions. Instructions: VAP, VSP, VMPVMSP, VDP, VSDP, VRP, VLIP, VSRP, VPSOPVCP, VTP, VPKZ, VUPKZ, VCVB, VCVBG, VCVDVCVDG\000"
/* offset=30884 */ "decimal_instructions\000extended\000Decimal Instructions\000event=0xe2\000\00000\000Decimal instructions dispatched. Instructions: CVB, CVD, AP, CP, DP, ED, EDMK, MP, SRP, SP, ZAP\000"
/* offset=31046 */ "last_host_translations\000extended\000Last host translation done\000event=0xe8\000\00000\000Last Host Translation done\000"
/* offset=31147 */ "tx_nc_tabort\000extended\000Aborted transactions in non-constrained TX mode\000event=0xf3\000\00000\000A transaction abort has occurred in a non-constrained transactional-execution mode\000"
/* offset=31315 */ "tx_c_tabort_no_special\000extended\000Aborted transactions in constrained TX mode not using special completion logic\000event=0xf4\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000"
/* offset=31600 */ "tx_c_tabort_special\000extended\000Aborted transactions in constrained TX mode using special completion logic\000event=0xf5\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000"
/* offset=31870 */ "prng_functions\000crypto6\000PRNG Function Count\000event=0x40\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000"
/* offset=32031 */ "prng_cycles\000crypto6\000PRNG Cycle Count\000event=0x41\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000"
/* offset=32250 */ "prng_blocked_functions\000crypto6\000PRNG Blocked Function Count\000event=0x42\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=32540 */ "prng_blocked_cycles\000crypto6\000PRNG Blocked Cycle Count\000event=0x43\000\00000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=32822 */ "sha_functions\000crypto6\000SHA Function Count\000event=0x44\000\00000\000This counter counts the total number of the SHA functions issued by the CPU\000"
/* offset=32954 */ "sha_cycles\000crypto6\000SHA Cycle Count\000event=0x45\000\00000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000"
/* offset=33135 */ "sha_blocked_functions\000crypto6\000SHA Blocked Function Count\000event=0x46\000\00000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=33388 */ "sha_blocked_cycles\000crypto6\000SHA Blocked Cycle Count\000event=0x47\000\00000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000"
/* offset=33633 */ "dea_functions\000crypto6\000DEA Function Count\000event=0x48\000\00000\000This counter counts the total number of the DEA functions issued by the CPU\000"
/* offset=33765 */ "dea_cycles\000crypto6\000DEA Cycle Count\000event=0x49\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000"
/* offset=33950 */ "dea_blocked_functions\000crypto6\000DEA Blocked Function Count\000event=0x4a\000\00000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=34207 */ "dea_blocked_cycles\000crypto6\000DEA Blocked Cycle Count\000event=0x4b\000\00000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=34456 */ "aes_functions\000crypto6\000AES Function Count\000event=0x4c\000\00000\000This counter counts the total number of the AES functions issued by the CPU\000"
/* offset=34588 */ "aes_cycles\000crypto6\000AES Cycle Count\000event=0x4d\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000"
/* offset=34773 */ "aes_blocked_functions\000crypto6\000AES Blocked Function Count\000event=0x4e\000\00000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=35030 */ "aes_blocked_cycles\000crypto6\000AES Blocked Cycle Count\000event=0x4f\000\00000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000"
/* offset=35279 */ "ecc_function_count\000crypto6\000ECC Function Count\000event=0x50\000\00000\000This counter counts the total number of the elliptic-curve cryptography (ECC) functions issued by the CPU\000"
/* offset=35446 */ "ecc_cycles_count\000crypto6\000ECC Cycles Count\000event=0x51\000\00000\000This counter counts the total number of CPU cycles when the ECC coprocessor is busy performing the elliptic-curve cryptography (ECC) functions issued by the CPU\000"
/* offset=35664 */ "ecc_blocked_function_count\000crypto6\000Ecc Blocked Function Count\000event=0x52\000\00000\000This counter counts the total number of the elliptic-curve cryptography (ECC) functions that are issued by the CPU and are blocked because the ECC coprocessor is busy performing a function issued by another CPU\000"
/* offset=35952 */ "ecc_blocked_cycles_count\000crypto6\000ECC Blocked Cycles Count\000event=0x53\000\00000\000This counter counts the total number of CPU cycles blocked for the elliptic-curve cryptography (ECC) functions issued by the CPU because the ECC coprocessor is busy performing a function issued by another CPU\000"
/* offset=36234 */ "dtlb2_hpage_writes\000extended\000DTLB2 One-Megabyte Page Writes\000event=0x83\000\00000\000A translation entry was written into the Combined Region and Segment Table Entry array in the Level-2 TLB for a one-megabyte page\000"
/* offset=36438 */ "dflt_access\000extended\000Cycles CPU spent obtaining access to Deflate unit\000event=0xf7\000\00000\000Cycles CPU spent obtaining access to Deflate unit\000"
/* offset=36574 */ "dflt_cycles\000extended\000Cycles CPU is using Deflate unit\000event=0xfc\000\00000\000Cycles CPU is using Deflate unit\000"
/* offset=36676 */ "dflt_cc\000extended\000Increments DEFLATE CONVERSION CALL\000event=0x108\000\00000\000Increments by one for every DEFLATE CONVERSION CALL instruction executed\000"
/* offset=36817 */ "dflt_ccfinish\000extended\000Increments completed DEFLATE CONVERSION CALL\000event=0x109\000\00000\000 Increments by one for every DEFLATE CONVERSION CALL instruction executed that ended in Condition Codes 0, 1 or 2 complete\000"
/* offset=37024 */ "dtlb2_writes\000extended\000DTLB2 Writes\000event=0x81\000\00000\000A translation has been written into The Translation Lookaside Buffer 2 (TLB2) and the request was made by the Level-1 Data cache. This is a replacement for what was provided for the DTLB on z13 and prior machines\000"
/* offset=37287 */ "dtlb2_misses\000extended\000DTLB2 Misses\000event=0x82\000\00000\000A TLB2 miss is in progress for a request made by the Level-1 Data cache. Incremented by one for every TLB2 miss in progress for the Level-1 Data cache on this cycle. This is a replacement for what was provided for the DTLB on z13 and prior machines\000"
/* offset=37586 */ "crste_1mb_writes\000extended\000One Megabyte CRSTE writes\000event=0x83\000\00000\000A translation entry was written into the Combined Region and Segment Table Entry array in the Level-2 TLB for a one-megabyte page\000"
/* offset=37783 */ "itlb2_writes\000extended\000ITLB2 Writes\000event=0x86\000\00000\000A translation entry has been written into the Translation Lookaside Buffer 2 (TLB2) and the request was made by the instruction cache. This is a replacement for what was provided for the ITLB on z13 and prior machines\000"
/* offset=38051 */ "itlb2_misses\000extended\000ITLB2 Misses\000event=0x87\000\00000\000A TLB2 miss is in progress for a request made by the Level-1 Instruction cache. Incremented by one for every TLB2 miss in progress for the Level-1 Instruction cache in a cycle. This is a replacement for what was provided for the ITLB on z13 and prior machines\000"
/* offset=38361 */ "tlb2_pte_writes\000extended\000TLB2 Page Table Entry Writes\000event=0x89\000\00000\000A translation entry was written into the Page Table Entry array in the Level-2 TLB\000"
/* offset=38513 */ "tlb2_crste_writes\000extended\000TLB2 Combined Region and Segment Entry Writes\000event=0x8a\000\00000\000Translation entries were written into the Combined Region and Segment Table Entry array and the Page Table Entry array in the Level-2 TLB\000"
/* offset=38739 */ "dcw_req\000extended\000Directory Write Level 1 Data Cache from L2-Cache\000event=0x91\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestors Level-2 cache\000"
/* offset=38950 */ "dcw_req_iv\000extended\000Directory Write Level 1 Data Cache from L2-Cache with Intervention\000event=0x92\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestors Level-2 cache with intervention\000"
/* offset=39200 */ "dcw_req_chip_hit\000extended\000Directory Write Level 1 Data Cache from L2-Cache with Chip HP Hit\000event=0x93\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestors Level-2 cache after using chip level horizontal persistence, Chip-HP hit\000"
/* offset=39496 */ "dcw_req_drawer_hit\000extended\000Directory Write Level 1 Data Cache from L2-Cache with Drawer HP Hit\000event=0x94\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestors Level-2 cache after using drawer level horizontal persistence, Drawer-HP hit\000"
/* offset=39800 */ "dcw_on_chip\000extended\000Directory Write Level 1 Data Cache from On-Chip L2-Cache\000event=0x95\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache\000"
/* offset=40019 */ "dcw_on_chip_iv\000extended\000Directory Write Level 1 Data Cache from On-Chip L2-Cache with Intervention\000event=0x96\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache with intervention\000"
/* offset=40277 */ "dcw_on_chip_chip_hit\000extended\000Directory Write Level 1 Data Cache from On-Chip L2-Cache with Chip HP Hit\000event=0x97\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache after using chip level horizontal persistence, Chip-HP hit\000"
/* offset=40581 */ "dcw_on_chip_drawer_hit\000extended\000Directory Write Level 1 Data Cache from On-Chip L2-Cache with Drawer HP Hit\000event=0x98\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000"
/* offset=40887 */ "dcw_on_module\000extended\000Directory Write Level 1 Data Cache from On-Module L2-Cache\000event=0x99\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Module Level-2 cache\000"
/* offset=41112 */ "dcw_on_drawer\000extended\000Directory Write Level 1 Data Cache from On-Drawer L2-Cache\000event=0x9a\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache\000"
/* offset=41337 */ "dcw_off_drawer\000extended\000Directory Write Level 1 Data Cache from Off-Drawer L2-Cache\000event=0x9b\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache\000"
/* offset=41565 */ "dcw_on_chip_memory\000extended\000Directory Write Level 1 Data Cache from On-Chip Memory\000event=0x9c\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory\000"
/* offset=41779 */ "dcw_on_module_memory\000extended\000Directory Write Level 1 Data Cache from On-Module Memory\000event=0x9d\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Module memory\000"
/* offset=41999 */ "dcw_on_drawer_memory\000extended\000Directory Write Level 1 Data Cache from On-Drawer Memory\000event=0x9e\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer memory\000"
/* offset=42219 */ "dcw_off_drawer_memory\000extended\000Directory Write Level 1 Data Cache from Off-Drawer Memory\000event=0x9f\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory\000"
/* offset=42442 */ "idcw_on_module_iv\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Module Memory L2-Cache with Intervention\000event=0xa0\000\00000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache with intervention\000"
/* offset=42753 */ "idcw_on_module_chip_hit\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Module Memory L2-Cache with Chip Hit\000event=0xa1\000\00000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache using chip horizontal persistence, Chip-HP hit\000"
/* offset=43095 */ "idcw_on_module_drawer_hit\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Module Memory L2-Cache with Drawer Hit\000event=0xa2\000\00000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000"
/* offset=43451 */ "idcw_on_drawer_iv\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Drawer L2-Cache with Intervention\000event=0xa3\000\00000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache with intervention\000"
/* offset=43755 */ "idcw_on_drawer_chip_hit\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Drawer L2-Cache with Chip Hit\000event=0xa4\000\00000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache using chip level horizontal persistence, Chip-HP hit\000"
/* offset=44096 */ "idcw_on_drawer_drawer_hit\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Drawer L2-Cache with Drawer Hit\000event=0xa5\000\00000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000"
/* offset=44445 */ "idcw_off_drawer_iv\000extended\000Directory Write Level 1 Instruction and Data Cache from Off-Drawer L2-Cache with Intervention\000event=0xa6\000\00000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache with intervention\000"
/* offset=44752 */ "idcw_off_drawer_chip_hit\000extended\000Directory Write Level 1 Instruction and Data Cache from Off-Drawer L2-Cache with Chip Hit\000event=0xa7\000\00000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache using chip level horizontal persistence, Chip-HP hit\000"
/* offset=45096 */ "idcw_off_drawer_drawer_hit\000extended\000Directory Write Level 1 Instruction and Data Cache from Off-Drawer L2-Cache with Drawer Hit\000event=0xa8\000\00000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000"
/* offset=45448 */ "icw_req\000extended\000Directory Write Level 1 Instruction Cache from L2-Cache\000event=0xa9\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced the requestors Level-2 cache\000"
/* offset=45668 */ "icw_req_iv\000extended\000Directory Write Level 1 Instruction Cache from L2-Cache with Intervention\000event=0xaa\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the requestors Level-2 cache with intervention\000"
/* offset=45932 */ "icw_req_chip_hit\000extended\000Directory Write Level 1 Instruction Cache from L2-Cache with Chip HP Hit\000event=0xab\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the requestors Level-2 cache using chip level horizontal persistence, Chip-HP hit\000"
/* offset=46236 */ "icw_req_drawer_hit\000extended\000Directory Write Level 1 Instruction Cache from L2-Cache with Drawer HP Hit\000event=0xac\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the requestors Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000"
/* offset=46548 */ "icw_on_chip\000extended\000Directory Write Level 1 Instruction Cache from On-Chip L2-Cache\000event=0xad\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip Level-2 cache\000"
/* offset=46781 */ "icw_on_chip_iv\000extended\000Directory Write Level 1 Instruction Cache from On-Chip L2-Cache with Intervention\000event=0xae\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced an On-Chip Level-2 cache with intervention\000"
/* offset=47048 */ "icw_on_chip_chip_hit\000extended\000Directory Write Level 1 Instruction Cache from On-Chip L2-Cache with Chip HP Hit\000event=0xaf\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip Level-2 cache using chip level horizontal persistence, Chip-HP hit\000"
/* offset=47360 */ "icw_on_chip_drawer_hit\000extended\000Directory Write Level 1 Instruction Cache from On-Chip L2-Cache with Drawer HP Hit\000event=0xb0\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip level 2 cache using drawer level horizontal persistence, Drawer-HP hit\000"
/* offset=47680 */ "icw_on_module\000extended\000Directory Write Level 1 Instruction Cache from On-Module L2-Cache\000event=0xb1\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache\000"
/* offset=47919 */ "icw_on_drawer\000extended\000Directory Write Level 1 Instruction Cache from On-Drawer L2-Cache\000event=0xb2\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced an On-Drawer Level-2 cache\000"
/* offset=48153 */ "icw_off_drawer\000extended\000Directory Write Level 1 Instruction Cache from Off-Drawer L2-Cache\000event=0xb3\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced an Off-Drawer Level-2 cache\000"
/* offset=48390 */ "icw_on_chip_memory\000extended\000Directory Write Level 1 Instruction Cache from On-Chip Memory\000event=0xb4\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Chip memory\000"
/* offset=48618 */ "icw_on_module_memory\000extended\000Directory Write Level 1 Instruction Cache from On-Module Memory\000event=0xb5\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Module memory\000"
/* offset=48852 */ "icw_on_drawer_memory\000extended\000Directory Write Level 1 Instruction Cache from On-Drawer Memory\000event=0xb6\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer memory\000"
/* offset=49086 */ "icw_off_drawer_memory\000extended\000Directory Write Level 1 Instruction Cache from Off-Drawer Memory\000event=0xb7\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer memory\000"
/* offset=49323 */ "bcd_dfp_execution_slots\000extended\000Binary Coded Decimal to Decimal Floating Point conversions\000event=0xe0\000\00000\000Count of floating point execution slots used for finished Binary Coded Decimal to Decimal Floating Point conversions. Instructions: CDZT, CXZT, CZDT, CZXT\000"
/* offset=49585 */ "vx_bcd_execution_slots\000extended\000Count finished vector arithmetic Binary Coded Decimal instructions\000event=0xe1\000\00000\000Count of floating point execution slots used for finished vector arithmetic Binary Coded Decimal instructions. Instructions: VAP, VSP, VMP, VMSP, VDP, VSDP, VRP, VLIP, VSRP, VPSOP, VCP, VTP, VPKZ, VUPKZ, VCVB, VCVBG, VCVD, VCVDG\000"
/* offset=49928 */ "decimal_instructions\000extended\000Decimal instruction dispatched\000event=0xe2\000\00000\000Decimal instruction dispatched. Instructions: CVB, CVD, AP, CP, DP, ED, EDMK, MP, SRP, SP, ZAP\000"
/* offset=50099 */ "tx_nc_tabort\000extended\000Aborted transactions in unconstrained TX mode\000event=0xf4\000\00000\000A transaction abort has occurred in a non-constrained transactional-execution mode\000"
/* offset=50265 */ "tx_c_tabort_no_special\000extended\000Aborted transactions in constrained TX mode\000event=0xf5\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000"
/* offset=50515 */ "tx_c_tabort_special\000extended\000Aborted transactions in constrained TX mode using special completion logic\000event=0xf6\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000"
/* offset=50785 */ "dflt_access\000extended\000Cycles CPU spent obtaining access to Deflate unit\000event=0xf8\000\00000\000Cycles CPU spent obtaining access to Deflate unit\000"
/* offset=50921 */ "dflt_cycles\000extended\000Cycles CPU is using Deflate unit\000event=0xfd\000\00000\000Cycles CPU is using Deflate unit\000"
/* offset=51023 */ "sortl\000extended\000Count SORTL instructions\000event=0x100\000\00000\000Increments by one for every SORT LISTS instruction executed\000"
/* offset=51139 */ "dflt_cc\000extended\000Increments DEFLATE CONVERSION CALL\000event=0x109\000\00000\000Increments by one for every DEFLATE CONVERSION CALL instruction executed\000"
/* offset=51280 */ "dflt_ccfinish\000extended\000Increments completed DEFLATE CONVERSION CALL\000event=0x10a\000\00000\000Increments by one for every DEFLATE CONVERSION CALL instruction executed that ended in Condition Codes 0, 1 or 2\000"
/* offset=51477 */ "nnpa_invocations\000extended\000NNPA Total invocations\000event=0x10b\000\00000\000Increments by one for every Neural Network Processing Assist instruction executed\000"
/* offset=51624 */ "nnpa_completions\000extended\000NNPA Total completions\000event=0x10c\000\00000\000Increments by one for every Neural Network Processing Assist instruction executed that ended in Condition Codes 0, 1 or 2\000"
/* offset=51811 */ "nnpa_wait_lock\000extended\000Cycles spent obtaining NNPA lock\000event=0x10d\000\00000\000Cycles CPU spent obtaining access to IBM Z Integrated Accelerator for AI\000"
/* offset=51957 */ "nnpa_hold_lock\000extended\000Cycles spent holding NNPA lock\000event=0x10e\000\00000\000Cycles CPU is using IBM Z Integrated Accelerator for AI\000"
/* offset=52084 */ "pai_crypto\000"
/* offset=52095 */ "crypto_all\000pai_crypto\000CRYPTO ALL\000event=0x1000\000\00000\000Sums of all non zero cryptography counters\000"
/* offset=52188 */ "km_dea\000pai_crypto\000KM DEA\000event=0x1001\000\00000\000KM-DEA function ending with CC=0\000"
/* offset=52263 */ "km_tdea_128\000pai_crypto\000KM TDEA 128\000event=0x1002\000\00000\000KM-TDEA-128 function ending with CC=0\000"
/* offset=52353 */ "km_tdea_192\000pai_crypto\000KM TDEA 192\000event=0x1003\000\00000\000KM-TDEA-192 function ending with CC=0\000"
/* offset=52443 */ "km_encrypted_dea\000pai_crypto\000KM ENCRYPTED DEA\000event=0x1004\000\00000\000KM-Encrypted-DEA function ending with CC=0\000"
/* offset=52548 */ "km_encrypted_tdea_128\000pai_crypto\000KM ENCRYPTED TDEA 128\000event=0x1005\000\00000\000KM-Encrypted-TDEA-128 function ending with CC=0\000"
/* offset=52668 */ "km_encrypted_tdea_192\000pai_crypto\000KM ENCRYPTED TDEA 192\000event=0x1006\000\00000\000KM-Encrypted-TDEA-192 function ending with CC=0\000"
/* offset=52788 */ "km_aes_128\000pai_crypto\000KM AES 128\000event=0x1007\000\00000\000KM-AES-128 function ending with CC=0\000"
/* offset=52875 */ "km_aes_192\000pai_crypto\000KM AES 192\000event=0x1008\000\00000\000KM-AES-192 function ending with CC=0\000"
/* offset=52962 */ "km_aes_256\000pai_crypto\000KM AES 256\000event=0x1009\000\00000\000KM-AES-256 function ending with CC=0\000"
/* offset=53049 */ "km_encrypted_aes_128\000pai_crypto\000KM ENCRYPTED AES 128\000event=0x100a\000\00000\000KM-Encrypted-AES-128 function ending with CC=0\000"
/* offset=53166 */ "km_encrypted_aes_192\000pai_crypto\000KM ENCRYPTED AES 192\000event=0x100b\000\00000\000KM-Encrypted-AES-192 function ending with CC=0\000"
/* offset=53283 */ "km_encrypted_aes_256\000pai_crypto\000KM ENCRYPTED AES 256\000event=0x100c\000\00000\000KM-Encrypted-AES-256 function ending with CC=0\000"
/* offset=53400 */ "km_xts_aes_128\000pai_crypto\000KM XTS AES 128\000event=0x100d\000\00000\000KM-XTS-AES-128 function ending with CC=0\000"
/* offset=53499 */ "km_xts_aes_256\000pai_crypto\000KM XTS AES 256\000event=0x100e\000\00000\000KM-XTS-AES-256 function ending with CC=0\000"
/* offset=53598 */ "km_xts_encrypted_aes_128\000pai_crypto\000KM XTS ENCRYPTED AES 128\000event=0x100f\000\00000\000KM-XTS-Encrypted-AES-128 function ending with CC=0\000"
/* offset=53727 */ "km_xts_encrypted_aes_256\000pai_crypto\000KM XTS ENCRYPTED AES 256\000event=0x1010\000\00000\000KM-XTS-Encrypted-AES-256 function ending with CC=0\000"
/* offset=53856 */ "kmc_dea\000pai_crypto\000KMC DEA\000event=0x1011\000\00000\000KMC-DEA function ending with CC=0\000"
/* offset=53934 */ "kmc_tdea_128\000pai_crypto\000KMC TDEA 128\000event=0x1012\000\00000\000KMC-TDEA-128 function ending with CC=0\000"
/* offset=54027 */ "kmc_tdea_192\000pai_crypto\000KMC TDEA 192\000event=0x1013\000\00000\000KMC-TDEA-192 function ending with CC=0\000"
/* offset=54120 */ "kmc_encrypted_dea\000pai_crypto\000KMC ENCRYPTED DEA\000event=0x1014\000\00000\000KMC-Encrypted-DEA function ending with CC=0\000"
/* offset=54228 */ "kmc_encrypted_tdea_128\000pai_crypto\000KMC ENCRYPTED TDEA 128\000event=0x1015\000\00000\000KMC-Encrypted-TDEA-128 function ending with CC=0\000"
/* offset=54351 */ "kmc_encrypted_tdea_192\000pai_crypto\000KMC ENCRYPTED TDEA 192\000event=0x1016\000\00000\000KMC-Encrypted-TDEA-192 function ending with CC=0\000"
/* offset=54474 */ "kmc_aes_128\000pai_crypto\000KMC AES 128\000event=0x1017\000\00000\000KMC-AES-128 function ending with CC=0\000"
/* offset=54564 */ "kmc_aes_192\000pai_crypto\000KMC AES 192\000event=0x1018\000\00000\000KMC-AES-192 function ending with CC=0\000"
/* offset=54654 */ "kmc_aes_256\000pai_crypto\000KMC AES 256\000event=0x1019\000\00000\000KMC-AES-256 function ending with CC=0\000"
/* offset=54744 */ "kmc_encrypted_aes_128\000pai_crypto\000KMC ENCRYPTED AES 128\000event=0x101a\000\00000\000KMC-Encrypted-AES-128 function ending with CC=0\000"
/* offset=54864 */ "kmc_encrypted_aes_192\000pai_crypto\000KMC ENCRYPTED AES 192\000event=0x101b\000\00000\000KMC-Encrypted-AES-192 function ending with CC=0\000"
/* offset=54984 */ "kmc_encrypted_aes_256\000pai_crypto\000KMC ENCRYPTED AES 256\000event=0x101c\000\00000\000KMC-Encrypted-AES-256 function ending with CC=0\000"
/* offset=55104 */ "kmc_prng\000pai_crypto\000KMC PRNG\000event=0x101d\000\00000\000KMC-PRNG function ending with CC=0\000"
/* offset=55185 */ "kma_gcm_aes_128\000pai_crypto\000KMA GCM AES 128\000event=0x101e\000\00000\000KMA-GCM-AES-128 function ending with CC=0\000"
/* offset=55287 */ "kma_gcm_aes_192\000pai_crypto\000KMA GCM AES 192\000event=0x101f\000\00000\000KMA-GCM-AES-192 function ending with CC=0\000"
/* offset=55389 */ "kma_gcm_aes_256\000pai_crypto\000KMA GCM AES 256\000event=0x1020\000\00000\000KMA-GCM-AES-256 function ending with CC=0\000"
/* offset=55491 */ "kma_gcm_encrypted_aes_128\000pai_crypto\000KMA GCM ENCRYPTED AES 128\000event=0x1021\000\00000\000KMA-GCM-Encrypted-AES-128 function ending with CC=0\000"
/* offset=55623 */ "kma_gcm_encrypted_aes_192\000pai_crypto\000KMA GCM ENCRYPTED AES 192\000event=0x1022\000\00000\000KMA-GCM-Encrypted-AES-192 function ending with CC=0\000"
/* offset=55755 */ "kma_gcm_encrypted_aes_256\000pai_crypto\000KMA GCM ENCRYPTED AES 256\000event=0x1023\000\00000\000KMA-GCM-Encrypted-AES-256 function ending with CC=0\000"
/* offset=55887 */ "kmf_dea\000pai_crypto\000KMF DEA\000event=0x1024\000\00000\000KMF-DEA function ending with CC=0\000"
/* offset=55965 */ "kmf_tdea_128\000pai_crypto\000KMF TDEA 128\000event=0x1025\000\00000\000KMF-TDEA-128 function ending with CC=0\000"
/* offset=56058 */ "kmf_tdea_192\000pai_crypto\000KMF TDEA 192\000event=0x1026\000\00000\000KMF-TDEA-192 function ending with CC=0\000"
/* offset=56151 */ "kmf_encrypted_dea\000pai_crypto\000KMF ENCRYPTED DEA\000event=0x1027\000\00000\000KMF-Encrypted-DEA function ending with CC=0\000"
/* offset=56259 */ "kmf_encrypted_tdea_128\000pai_crypto\000KMF ENCRYPTED TDEA 128\000event=0x1028\000\00000\000KMF-Encrypted-TDEA-128 function ending with CC=0\000"
/* offset=56382 */ "kmf_encrypted_tdea_192\000pai_crypto\000KMF ENCRYPTED TDEA 192\000event=0x1029\000\00000\000KMF-Encrypted-TDEA-192 function ending with CC=0\000"
/* offset=56505 */ "kmf_aes_128\000pai_crypto\000KMF AES 128\000event=0x102a\000\00000\000KMF-AES-128 function ending with CC=0\000"
/* offset=56595 */ "kmf_aes_192\000pai_crypto\000KMF AES 192\000event=0x102b\000\00000\000KMF-AES-192 function ending with CC=0\000"
/* offset=56685 */ "kmf_aes_256\000pai_crypto\000KMF AES 256\000event=0x102c\000\00000\000KMF-AES-256 function ending with CC=0\000"
/* offset=56775 */ "kmf_encrypted_aes_128\000pai_crypto\000KMF ENCRYPTED AES 128\000event=0x102d\000\00000\000KMF-Encrypted-AES-128 function ending with CC=0\000"
/* offset=56895 */ "kmf_encrypted_aes_192\000pai_crypto\000KMF ENCRYPTED AES 192\000event=0x102e\000\00000\000KMF-Encrypted-AES-192 function ending with CC=0\000"
/* offset=57015 */ "kmf_encrypted_aes_256\000pai_crypto\000KMF ENCRYPTED AES 256\000event=0x102f\000\00000\000KMF-Encrypted-AES-256 function ending with CC=0\000"
/* offset=57135 */ "kmctr_dea\000pai_crypto\000KMCTR DEA\000event=0x1030\000\00000\000KMCTR-DEA function ending with CC=0\000"
/* offset=57219 */ "kmctr_tdea_128\000pai_crypto\000KMCTR TDEA 128\000event=0x1031\000\00000\000KMCTR-TDEA-128 function ending with CC=0\000"
/* offset=57318 */ "kmctr_tdea_192\000pai_crypto\000KMCTR TDEA 192\000event=0x1032\000\00000\000KMCTR-TDEA-192 function ending with CC=0\000"
/* offset=57417 */ "kmctr_encrypted_dea\000pai_crypto\000KMCTR ENCRYPTED DEA\000event=0x1033\000\00000\000KMCTR-Encrypted-DEA function ending with CC=0\000"
/* offset=57531 */ "kmctr_encrypted_tdea_128\000pai_crypto\000KMCTR ENCRYPTED TDEA 128\000event=0x1034\000\00000\000KMCTR-Encrypted-TDEA-128 function ending with CC=0\000"
/* offset=57660 */ "kmctr_encrypted_tdea_192\000pai_crypto\000KMCTR ENCRYPTED TDEA 192\000event=0x1035\000\00000\000KMCTR-Encrypted-TDEA-192 function ending with CC=0\000"
/* offset=57789 */ "kmctr_aes_128\000pai_crypto\000KMCTR AES 128\000event=0x1036\000\00000\000KMCTR-AES-128 function ending with CC=0\000"
/* offset=57885 */ "kmctr_aes_192\000pai_crypto\000KMCTR AES 192\000event=0x1037\000\00000\000KMCTR-AES-192 function ending with CC=0\000"
/* offset=57981 */ "kmctr_aes_256\000pai_crypto\000KMCTR AES 256\000event=0x1038\000\00000\000KMCTR-AES-256 function ending with CC=0\000"
/* offset=58077 */ "kmctr_encrypted_aes_128\000pai_crypto\000KMCTR ENCRYPTED AES 128\000event=0x1039\000\00000\000KMCTR-Encrypted-AES-128 function ending with CC=0\000"
/* offset=58203 */ "kmctr_encrypted_aes_192\000pai_crypto\000KMCTR ENCRYPTED AES 192\000event=0x103a\000\00000\000KMCTR-Encrypted-AES-192 function ending with CC=0\000"
/* offset=58329 */ "kmctr_encrypted_aes_256\000pai_crypto\000KMCTR ENCRYPTED AES 256\000event=0x103b\000\00000\000KMCTR-Encrypted-AES-256 function ending with CC=0\000"
/* offset=58455 */ "kmo_dea\000pai_crypto\000KMO DEA\000event=0x103c\000\00000\000KMO-DEA function ending with CC=0\000"
/* offset=58533 */ "kmo_tdea_128\000pai_crypto\000KMO TDEA 128\000event=0x103d\000\00000\000KMO-TDEA-128 function ending with CC=0\000"
/* offset=58626 */ "kmo_tdea_192\000pai_crypto\000KMO TDEA 192\000event=0x103e\000\00000\000KMO-TDEA-192 function ending with CC=0\000"
/* offset=58719 */ "kmo_encrypted_dea\000pai_crypto\000KMO ENCRYPTED DEA\000event=0x103f\000\00000\000KMO-Encrypted-DEA function ending with CC=0\000"
/* offset=58827 */ "kmo_encrypted_tdea_128\000pai_crypto\000KMO ENCRYPTED TDEA 128\000event=0x1040\000\00000\000KMO-Encrypted-TDEA-128 function ending with CC=0\000"
/* offset=58950 */ "kmo_encrypted_tdea_192\000pai_crypto\000KMO ENCRYPTED TDEA 192\000event=0x1041\000\00000\000KMO-Encrypted-TDEA-192 function ending with CC=0\000"
/* offset=59073 */ "kmo_aes_128\000pai_crypto\000KMO AES 128\000event=0x1042\000\00000\000KMO-AES-128 function ending with CC=0\000"
/* offset=59163 */ "kmo_aes_192\000pai_crypto\000KMO AES 192\000event=0x1043\000\00000\000KMO-AES-192 function ending with CC=0\000"
/* offset=59253 */ "kmo_aes_256\000pai_crypto\000KMO AES 256\000event=0x1044\000\00000\000KMO-AES-256 function ending with CC=0\000"
/* offset=59343 */ "kmo_encrypted_aes_128\000pai_crypto\000KMO ENCRYPTED AES 128\000event=0x1045\000\00000\000KMO-Encrypted-AES-128 function ending with CC=0\000"
/* offset=59463 */ "kmo_encrypted_aes_192\000pai_crypto\000KMO ENCRYPTED AES 192\000event=0x1046\000\00000\000KMO-Encrypted-AES-192 function ending with CC=0\000"
/* offset=59583 */ "kmo_encrypted_aes_256\000pai_crypto\000KMO ENCRYPTED AES 256\000event=0x1047\000\00000\000KMO-Encrypted-AES-256 function ending with CC=0\000"
/* offset=59703 */ "kimd_sha_1\000pai_crypto\000KIMD SHA 1\000event=0x1048\000\00000\000KIMD-SHA-1 function ending with CC=0\000"
/* offset=59790 */ "kimd_sha_256\000pai_crypto\000KIMD SHA 256\000event=0x1049\000\00000\000KIMD-SHA-256 function ending with CC=0\000"
/* offset=59883 */ "kimd_sha_512\000pai_crypto\000KIMD SHA 512\000event=0x104a\000\00000\000KIMD-SHA-512 function ending with CC=0\000"
/* offset=59976 */ "kimd_sha3_224\000pai_crypto\000KIMD SHA3 224\000event=0x104b\000\00000\000KIMD-SHA3-224 function ending with CC=0\000"
/* offset=60072 */ "kimd_sha3_256\000pai_crypto\000KIMD SHA3 256\000event=0x104c\000\00000\000KIMD-SHA3-256 function ending with CC=0\000"
/* offset=60168 */ "kimd_sha3_384\000pai_crypto\000KIMD SHA3 384\000event=0x104d\000\00000\000KIMD-SHA3-384 function ending with CC=0\000"
/* offset=60264 */ "kimd_sha3_512\000pai_crypto\000KIMD SHA3 512\000event=0x104e\000\00000\000KIMD-SHA3-512 function ending with CC=0\000"
/* offset=60360 */ "kimd_shake_128\000pai_crypto\000KIMD SHAKE 128\000event=0x104f\000\00000\000KIMD-SHAKE-128 function ending with CC=0\000"
/* offset=60459 */ "kimd_shake_256\000pai_crypto\000KIMD SHAKE 256\000event=0x1050\000\00000\000KIMD-SHAKE-256 function ending with CC=0\000"
/* offset=60558 */ "kimd_ghash\000pai_crypto\000KIMD GHASH\000event=0x1051\000\00000\000KIMD-GHASH function ending with CC=0\000"
/* offset=60645 */ "klmd_sha_1\000pai_crypto\000KLMD SHA 1\000event=0x1052\000\00000\000KLMD-SHA-1 function ending with CC=0\000"
/* offset=60732 */ "klmd_sha_256\000pai_crypto\000KLMD SHA 256\000event=0x1053\000\00000\000KLMD-SHA-256 function ending with CC=0\000"
/* offset=60825 */ "klmd_sha_512\000pai_crypto\000KLMD SHA 512\000event=0x1054\000\00000\000KLMD-SHA-512 function ending with CC=0\000"
/* offset=60918 */ "klmd_sha3_224\000pai_crypto\000KLMD SHA3 224\000event=0x1055\000\00000\000KLMD-SHA3-224 function ending with CC=0\000"
/* offset=61014 */ "klmd_sha3_256\000pai_crypto\000KLMD SHA3 256\000event=0x1056\000\00000\000KLMD-SHA3-256 function ending with CC=0\000"
/* offset=61110 */ "klmd_sha3_384\000pai_crypto\000KLMD SHA3 384\000event=0x1057\000\00000\000KLMD-SHA3-384 function ending with CC=0\000"
/* offset=61206 */ "klmd_sha3_512\000pai_crypto\000KLMD SHA3 512\000event=0x1058\000\00000\000KLMD-SHA3-512 function ending with CC=0\000"
/* offset=61302 */ "klmd_shake_128\000pai_crypto\000KLMD SHAKE 128\000event=0x1059\000\00000\000KLMD-SHAKE-128 function ending with CC=0\000"
/* offset=61401 */ "klmd_shake_256\000pai_crypto\000KLMD SHAKE 256\000event=0x105a\000\00000\000KLMD-SHAKE-256 function ending with CC=0\000"
/* offset=61500 */ "kmac_dea\000pai_crypto\000KMAC DEA\000event=0x105b\000\00000\000KMAC-DEA function ending with CC=0\000"
/* offset=61581 */ "kmac_tdea_128\000pai_crypto\000KMAC TDEA 128\000event=0x105c\000\00000\000KMAC-TDEA-128 function ending with CC=0\000"
/* offset=61677 */ "kmac_tdea_192\000pai_crypto\000KMAC TDEA 192\000event=0x105d\000\00000\000KMAC-TDEA-192 function ending with CC=0\000"
/* offset=61773 */ "kmac_encrypted_dea\000pai_crypto\000KMAC ENCRYPTED DEA\000event=0x105e\000\00000\000KMAC-Encrypted-DEA function ending with CC=0\000"
/* offset=61884 */ "kmac_encrypted_tdea_128\000pai_crypto\000KMAC ENCRYPTED TDEA 128\000event=0x105f\000\00000\000KMAC-Encrypted-TDEA-128 function ending with CC=0\000"
/* offset=62010 */ "kmac_encrypted_tdea_192\000pai_crypto\000KMAC ENCRYPTED TDEA 192\000event=0x1060\000\00000\000KMAC-Encrypted-TDEA-192 function ending with CC=0\000"
/* offset=62136 */ "kmac_aes_128\000pai_crypto\000KMAC AES 128\000event=0x1061\000\00000\000KMAC-AES-128 function ending with CC=0\000"
/* offset=62229 */ "kmac_aes_192\000pai_crypto\000KMAC AES 192\000event=0x1062\000\00000\000KMAC-AES-192 function ending with CC=0\000"
/* offset=62322 */ "kmac_aes_256\000pai_crypto\000KMAC AES 256\000event=0x1063\000\00000\000KMAC-AES-256 function ending with CC=0\000"
/* offset=62415 */ "kmac_encrypted_aes_128\000pai_crypto\000KMAC ENCRYPTED AES 128\000event=0x1064\000\00000\000KMAC-Encrypted-AES-128 function ending with CC=0\000"
/* offset=62538 */ "kmac_encrypted_aes_192\000pai_crypto\000KMAC ENCRYPTED AES 192\000event=0x1065\000\00000\000KMAC-Encrypted-AES-192 function ending with CC=0\000"
/* offset=62661 */ "kmac_encrypted_aes_256\000pai_crypto\000KMAC ENCRYPTED AES 256\000event=0x1066\000\00000\000KMAC-Encrypted-AES-256 function ending with CC=0\000"
/* offset=62784 */ "pcc_compute_last_block_cmac_using_dea\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING DEA\000event=0x1067\000\00000\000PCC-Compute-Last-Block-CMAC-Using-DEA function ending with CC=0\000"
/* offset=62952 */ "pcc_compute_last_block_cmac_using_tdea_128\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING TDEA 128\000event=0x1068\000\00000\000PCC-Compute-Last-Block-CMAC-Using-TDEA-128 function ending with CC=0\000"
/* offset=63135 */ "pcc_compute_last_block_cmac_using_tdea_192\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING TDEA 192\000event=0x1069\000\00000\000PCC-Compute-Last-Block-CMAC-Using-TDEA-192 function ending with CC=0\000"
/* offset=63318 */ "pcc_compute_last_block_cmac_using_encrypted_dea\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED DEA\000event=0x106a\000\00000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-DEA function ending with CC=0\000"
/* offset=63516 */ "pcc_compute_last_block_cmac_using_encrypted_tdea_128\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED TDEA 128\000event=0x106b\000\00000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-TDEA- 128 function ending with CC=0\000"
/* offset=63730 */ "pcc_compute_last_block_cmac_using_encrypted_tdea_192\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED TDEA 192\000event=0x106c\000\00000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-TDEA- 192 function ending with CC=0\000"
/* offset=63944 */ "pcc_compute_last_block_cmac_using_aes_128\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING AES 128\000event=0x106d\000\00000\000PCC-Compute-Last-Block-CMAC-Using-AES-128 function ending with CC=0\000"
/* offset=64124 */ "pcc_compute_last_block_cmac_using_aes_192\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING AES 192\000event=0x106e\000\00000\000PCC-Compute-Last-Block-CMAC-Using-AES-192 function ending with CC=0\000"
/* offset=64304 */ "pcc_compute_last_block_cmac_using_aes_256\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING AES 256\000event=0x106f\000\00000\000PCC-Compute-Last-Block-CMAC-Using-AES-256 function ending with CC=0\000"
/* offset=64484 */ "pcc_compute_last_block_cmac_using_encrypted_aes_128\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED AES 128\000event=0x1070\000\00000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-AES- 128 function ending with CC=0\000"
/* offset=64695 */ "pcc_compute_last_block_cmac_using_encrypted_aes_192\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED AES 192\000event=0x1071\000\00000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-AES- 192 function ending with CC=0\000"
/* offset=64906 */ "pcc_compute_last_block_cmac_using_encrypted_aes_256a\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED AES 256A\000event=0x1072\000\00000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-AES- 256A function ending with CC=0\000"
/* offset=65120 */ "pcc_compute_xts_parameter_using_aes_128\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING AES 128\000event=0x1073\000\00000\000PCC-Compute-XTS-Parameter-Using-AES-128 function ending with CC=0\000"
/* offset=65294 */ "pcc_compute_xts_parameter_using_aes_256\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING AES 256\000event=0x1074\000\00000\000PCC-Compute-XTS-Parameter-Using-AES-256 function ending with CC=0\000"
/* offset=65468 */ "pcc_compute_xts_parameter_using_encrypted_aes_128\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING ENCRYPTED AES 128\000event=0x1075\000\00000\000PCC-Compute-XTS-Parameter-Using-Encrypted-AES-128 function ending with CC=0\000"
/* offset=65672 */ "pcc_compute_xts_parameter_using_encrypted_aes_256\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING ENCRYPTED AES 256\000event=0x1076\000\00000\000PCC-Compute-XTS-Parameter-Using-Encrypted-AES-256 function ending with CC=0\000"
/* offset=65876 */ "pcc_scalar_multiply_p256\000pai_crypto\000PCC SCALAR MULTIPLY P256\000event=0x1077\000\00000\000PCC-Scalar-Multiply-P256 function ending with CC=0\000"
/* offset=66005 */ "pcc_scalar_multiply_p384\000pai_crypto\000PCC SCALAR MULTIPLY P384\000event=0x1078\000\00000\000PCC-Scalar-Multiply-P384 function ending with CC=0\000"
/* offset=66134 */ "pcc_scalar_multiply_p521\000pai_crypto\000PCC SCALAR MULTIPLY P521\000event=0x1079\000\00000\000PCC-Scalar-Multiply-P521 function ending with CC=0\000"
/* offset=66263 */ "pcc_scalar_multiply_ed25519\000pai_crypto\000PCC SCALAR MULTIPLY ED25519\000event=0x107a\000\00000\000PCC-Scalar-Multiply-Ed25519 function ending with CC=0\000"
/* offset=66401 */ "pcc_scalar_multiply_ed448\000pai_crypto\000PCC SCALAR MULTIPLY ED448\000event=0x107b\000\00000\000PCC-Scalar-Multiply-Ed448 function ending with CC=0\000"
/* offset=66533 */ "pcc_scalar_multiply_x25519\000pai_crypto\000PCC SCALAR MULTIPLY X25519\000event=0x107c\000\00000\000PCC-Scalar-Multiply-X25519 function ending with CC=0\000"
/* offset=66668 */ "pcc_scalar_multiply_x448\000pai_crypto\000PCC SCALAR MULTIPLY X448\000event=0x107d\000\00000\000PCC-Scalar-Multiply-X448 function ending with CC=0\000"
/* offset=66797 */ "prno_sha_512_drng\000pai_crypto\000PRNO SHA 512 DRNG\000event=0x107e\000\00000\000PRNO-SHA-512-DRNG function ending with CC=0\000"
/* offset=66905 */ "prno_trng_query_raw_to_conditioned_ratio\000pai_crypto\000PRNO TRNG QUERY RAW TO CONDITIONED RATIO\000event=0x107f\000\00000\000PRNO-TRNG-Query-Raw-to-Conditioned-Ratio function ending with CC=0\000"
/* offset=67082 */ "prno_trng\000pai_crypto\000PRNO TRNG\000event=0x1080\000\00000\000PRNO-TRNG function ending with CC=0\000"
/* offset=67166 */ "kdsa_ecdsa_verify_p256\000pai_crypto\000KDSA ECDSA VERIFY P256\000event=0x1081\000\00000\000KDSA-ECDSA-Verify-P256 function ending with CC=0 or CC=2\000"
/* offset=67297 */ "kdsa_ecdsa_verify_p384\000pai_crypto\000KDSA ECDSA VERIFY P384\000event=0x1082\000\00000\000KDSA-ECDSA-Verify-P384 function ending with CC=0 or CC=2\000"
/* offset=67428 */ "kdsa_ecdsa_verify_p521\000pai_crypto\000KDSA ECDSA VERIFY P521\000event=0x1083\000\00000\000KDSA-ECDSA-Verify-P521 function ending with CC=0 or CC=2\000"
/* offset=67559 */ "kdsa_ecdsa_sign_p256\000pai_crypto\000KDSA ECDSA SIGN P256\000event=0x1084\000\00000\000KDSA-ECDSA-Sign-P256 function ending with CC=0\000"
/* offset=67676 */ "kdsa_ecdsa_sign_p384\000pai_crypto\000KDSA ECDSA SIGN P384\000event=0x1085\000\00000\000KDSA-ECDSA-Sign-P384 function ending with CC=0\000"
/* offset=67793 */ "kdsa_ecdsa_sign_p521\000pai_crypto\000KDSA ECDSA SIGN P521\000event=0x1086\000\00000\000KDSA-ECDSA-Sign-P521 function ending with CC=0\000"
/* offset=67910 */ "kdsa_encrypted_ecdsa_sign_p256\000pai_crypto\000KDSA ENCRYPTED ECDSA SIGN P256\000event=0x1087\000\00000\000KDSA-Encrypted-ECDSA-Sign-P256 function ending with CC=0\000"
/* offset=68057 */ "kdsa_encrypted_ecdsa_sign_p384\000pai_crypto\000KDSA ENCRYPTED ECDSA SIGN P384\000event=0x1088\000\00000\000KDSA-Encrypted-ECDSA-Sign-P384 function ending with CC=0\000"
/* offset=68204 */ "kdsa_encrypted_ecdsa_sign_p521\000pai_crypto\000KDSA ENCRYPTED ECDSA SIGN P521\000event=0x1089\000\00000\000KDSA-Encrypted-ECDSA-Sign-P521 function ending with CC=0\000"
/* offset=68351 */ "kdsa_eddsa_verify_ed25519\000pai_crypto\000KDSA EDDSA VERIFY ED25519\000event=0x108a\000\00000\000KDSA-EdDSA-Verify-Ed25519 function ending with CC=0 or CC=2\000"
/* offset=68491 */ "kdsa_eddsa_verify_ed448\000pai_crypto\000KDSA EDDSA VERIFY ED448\000event=0x108b\000\00000\000KDSA-EdDSA-Verify-Ed448 function ending with CC=0 or CC=2\000"
/* offset=68625 */ "kdsa_eddsa_sign_ed25519\000pai_crypto\000KDSA EDDSA SIGN ED25519\000event=0x108c\000\00000\000KDSA-EdDSA-Sign-Ed25519 function ending with CC=0\000"
/* offset=68751 */ "kdsa_eddsa_sign_ed448\000pai_crypto\000KDSA EDDSA SIGN ED448\000event=0x108d\000\00000\000KDSA-EdDSA-Sign-Ed448 function ending with CC=0\000"
/* offset=68871 */ "kdsa_encrypted_eddsa_sign_ed25519\000pai_crypto\000KDSA ENCRYPTED EDDSA SIGN ED25519\000event=0x108e\000\00000\000KDSA-Encrypted-EdDSA-Sign-Ed25519 function ending with CC=0\000"
/* offset=69027 */ "kdsa_encrypted_eddsa_sign_ed448\000pai_crypto\000KDSA ENCRYPTED EDDSA SIGN ED448\000event=0x108f\000\00000\000KDSA-Encrypted-EdDSA-Sign-Ed448 function ending with CC=0\000"
/* offset=69177 */ "pckmo_encrypt_dea_key\000pai_crypto\000PCKMO ENCRYPT DEA KEY\000event=0x1090\000\00000\000PCKMO-Encrypt-DEA-key function\000"
/* offset=69280 */ "pckmo_encrypt_tdea_128_key\000pai_crypto\000PCKMO ENCRYPT TDEA 128 KEY\000event=0x1091\000\00000\000PCKMO-Encrypt-TDEA-128-key function\000"
/* offset=69398 */ "pckmo_encrypt_tdea_192_key\000pai_crypto\000PCKMO ENCRYPT TDEA 192 KEY\000event=0x1092\000\00000\000PCKMO-Encrypt-TDEA-192-key function\000"
/* offset=69516 */ "pckmo_encrypt_aes_128_key\000pai_crypto\000PCKMO ENCRYPT AES 128 KEY\000event=0x1093\000\00000\000PCKMO-Encrypt-AES-128-key function\000"
/* offset=69631 */ "pckmo_encrypt_aes_192_key\000pai_crypto\000PCKMO ENCRYPT AES 192 KEY\000event=0x1094\000\00000\000PCKMO-Encrypt-AES-192-key function\000"
/* offset=69746 */ "pckmo_encrypt_aes_256_key\000pai_crypto\000PCKMO ENCRYPT AES 256 KEY\000event=0x1095\000\00000\000PCKMO-Encrypt-AES-256-key function\000"
/* offset=69861 */ "pckmo_encrypt_ecc_p256_key\000pai_crypto\000PCKMO ENCRYPT ECC P256 KEY\000event=0x1096\000\00000\000PCKMO-Encrypt-ECC-P256-key function\000"
/* offset=69979 */ "pckmo_encrypt_ecc_p384_key\000pai_crypto\000PCKMO ENCRYPT ECC P384 KEY\000event=0x1097\000\00000\000PCKMO-Encrypt-ECC-P384-key function\000"
/* offset=70097 */ "pckmo_encrypt_ecc_p521_key\000pai_crypto\000PCKMO ENCRYPT ECC P521 KEY\000event=0x1098\000\00000\000PCKMO-Encrypt-ECC-P521-key function\000"
/* offset=70215 */ "pckmo_encrypt_ecc_ed25519_key\000pai_crypto\000PCKMO ENCRYPT ECC ED25519 KEY\000event=0x1099\000\00000\000PCKMO-Encrypt-ECC-Ed25519-key function\000"
/* offset=70342 */ "pckmo_encrypt_ecc_ed448_key\000pai_crypto\000PCKMO ENCRYPT ECC ED448 KEY\000event=0x109a\000\00000\000PCKMO-Encrypt-ECC-Ed448-key function\000"
/* offset=70463 */ "ibm_reserved_155\000pai_crypto\000IBM RESERVED_155\000event=0x109b\000\00000\000Reserved for IBM use\000"
/* offset=70546 */ "ibm_reserved_156\000pai_crypto\000IBM RESERVED_156\000event=0x109c\000\00000\000Reserved for IBM use\000"
/* offset=70629 */ "pai_ext\000"
/* offset=70637 */ "nnpa_all\000pai_ext\000NNPA ALL Sum of all non zero counters\000event=0x1800\000\00000\000Sum of all non zero NNPA (Neural Networks Processing Assist) counters\000"
/* offset=70779 */ "nnpa_add\000pai_ext\000NNPA ADD function ending with CC=0\000event=0x1801\000\00000\000\000"
/* offset=70849 */ "nnpa_sub\000pai_ext\000NNPA SUB function ending with CC=0\000event=0x1802\000\00000\000\000"
/* offset=70919 */ "nnpa_mul\000pai_ext\000NNPA MUL function ending with CC=0\000event=0x1803\000\00000\000\000"
/* offset=70989 */ "nnpa_div\000pai_ext\000NNPA DIV function ending with CC=0\000event=0x1804\000\00000\000\000"
/* offset=71059 */ "nnpa_min\000pai_ext\000NNPA MIN function ending with CC=0\000event=0x1805\000\00000\000\000"
/* offset=71129 */ "nnpa_max\000pai_ext\000NNPA MAX function ending with CC=0\000event=0x1806\000\00000\000\000"
/* offset=71199 */ "nnpa_log\000pai_ext\000NNPA LOG function ending with CC=0\000event=0x1807\000\00000\000\000"
/* offset=71269 */ "nnpa_exp\000pai_ext\000NNPA EXP function ending with CC=0\000event=0x1808\000\00000\000\000"
/* offset=71339 */ "nnpa_ibm_reserved_9\000pai_ext\000Reserved for IBM use\000event=0x1809\000\00000\000Reserved for IBM use\000"
/* offset=71426 */ "nnpa_relu\000pai_ext\000NNPA RELU function ending with CC=0\000event=0x180a\000\00000\000\000"
/* offset=71498 */ "nnpa_tanh\000pai_ext\000NNPA TANH function ending with CC=0\000event=0x180b\000\00000\000\000"
/* offset=71570 */ "nnpa_sigmoid\000pai_ext\000NNPA SIGMOID function ending with CC=0\000event=0x180c\000\00000\000\000"
/* offset=71648 */ "nnpa_softmax\000pai_ext\000NNPA SOFTMAX function ending with CC=0\000event=0x180d\000\00000\000\000"
/* offset=71726 */ "nnpa_batchnorm\000pai_ext\000NNPA BATCHNORM function ending with CC=0\000event=0x180e\000\00000\000\000"
/* offset=71808 */ "nnpa_maxpool2d\000pai_ext\000NNPA MAXPOOL2D function ending with CC=0\000event=0x180f\000\00000\000\000"
/* offset=71890 */ "nnpa_avgpool2d\000pai_ext\000NNPA AVGPOOL2D function ending with CC=0\000event=0x1810\000\00000\000\000"
/* offset=71972 */ "nnpa_lstmact\000pai_ext\000NNPA LSTMACT function ending with CC=0\000event=0x1811\000\00000\000\000"
/* offset=72050 */ "nnpa_gruact\000pai_ext\000NNPA GRUACT function ending with CC=0\000event=0x1812\000\00000\000\000"
/* offset=72126 */ "nnpa_convolution\000pai_ext\000NNPA CONVOLUTION function ending with CC=0\000event=0x1813\000\00000\000\000"
/* offset=72212 */ "nnpa_matmul_op\000pai_ext\000NNPA MATMUL OP function ending with CC=0\000event=0x1814\000\00000\000\000"
/* offset=72294 */ "nnpa_matmul_op_bcast23\000pai_ext\000NNPA NNPA MATMUL OP BCAST23 function ending with CC=0\000event=0x1815\000\00000\000\000"
/* offset=72397 */ "nnpa_smallbatch\000pai_ext\000NNPA SMALLBATCH OP function ending with CC=0\000event=0x1816\000\00000\000NNPA function with conditions as described in Common Operation\000"
/* offset=72546 */ "nnpa_largedim\000pai_ext\000NNPA LARGEDIM OP function ending with CC=0\000event=0x1817\000\00000\000NNPA function with conditions as described in Common Operation\000"
/* offset=72691 */ "nnpa_smalltensor\000pai_ext\000NNPA SMALLTENSOR OP function ending with CC=0\000event=0x1818\000\00000\000NNPA function with conditions as described in Common Operation\000"
/* offset=72842 */ "nnpa_1mframe\000pai_ext\000NNPA 1MFRAME OP function ending with CC=0\000event=0x1819\000\00000\000NNPA function with conditions as described in Common Operation\000"
/* offset=72985 */ "nnpa_2gframe\000pai_ext\000NNPA 2GFRAME OP function ending with CC=0\000event=0x181a\000\00000\000NNPA function with conditions as described in Common Operation\000"
/* offset=73128 */ "nnpa_accessexcept\000pai_ext\000NNPA ACCESSEXCEPT OP function ending with CC=0\000event=0x181b\000\00000\000NNPA function with conditions as described in Common Operation\000"
/* offset=73281 */ "l1d_l2_sourced_writes\000extended\000L1D L2 Sourced Writes\000event=0x80\000\00000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from the Level-2 cache\000"
/* offset=73468 */ "l1i_l2_sourced_writes\000extended\000L1I L2 Sourced Writes\000event=0x81\000\00000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from the Level-2 cache\000"
/* offset=73662 */ "itlb1_misses\000extended\000ITLB1 Misses\000event=0x83\000\00000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle a ITLB1 miss is in progress\000"
/* offset=73817 */ "l2c_stores_sent\000extended\000L2C Stores Sent\000event=0x85\000\00000\000Incremented by one for every store sent to Level-2 cache\000"
/* offset=73930 */ "l1d_offbook_l3_sourced_writes\000extended\000L1D Off-Book L3 Sourced Writes\000event=0x86\000\00000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an Off Book Level-3 cache\000"
/* offset=74142 */ "l1d_onbook_l4_sourced_writes\000extended\000L1D On-Book L4 Sourced Writes\000event=0x87\000\00000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an On Book Level-4 cache\000"
/* offset=74351 */ "l1i_onbook_l4_sourced_writes\000extended\000L1I On-Book L4 Sourced Writes\000event=0x88\000\00000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an On Book Level-4 cache\000"
/* offset=74567 */ "l1d_ro_excl_writes\000extended\000L1D Read-only Exclusive Writes\000event=0x89\000\00000\000A directory write to the Level-1 Data Cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000"
/* offset=74836 */ "l1d_offbook_l4_sourced_writes\000extended\000L1D Off-Book L4 Sourced Writes\000event=0x8a\000\00000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000"
/* offset=75048 */ "l1i_offbook_l4_sourced_writes\000extended\000L1I Off-Book L4 Sourced Writes\000event=0x8b\000\00000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000"
/* offset=75267 */ "dtlb1_hpage_writes\000extended\000DTLB1 One-Megabyte Page Writes\000event=0x8c\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a one-megabyte page\000"
/* offset=75451 */ "l1d_lmem_sourced_writes\000extended\000L1D Local Memory Sourced Writes\000event=0x8d\000\00000\000A directory write to the Level-1 Data Cache where the installed cache line was sourced from memory that is attached to the same book as the Data cache (Local Memory)\000"
/* offset=75697 */ "l1i_lmem_sourced_writes\000extended\000L1I Local Memory Sourced Writes\000event=0x8e\000\00000\000A directory write to the Level-1 Instruction Cache where the installed cache line was sourced from memory that is attached to the same book as the Instruction cache (Local Memory)\000"
/* offset=75957 */ "l1i_offbook_l3_sourced_writes\000extended\000L1I Off-Book L3 Sourced Writes\000event=0x8f\000\00000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an Off Book Level-3 cache\000"
/* offset=76176 */ "dtlb1_writes\000extended\000DTLB1 Writes\000event=0x90\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000"
/* offset=76320 */ "itlb1_writes\000extended\000ITLB1 Writes\000event=0x91\000\00000\000A translation entry has been written to the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000"
/* offset=76471 */ "tlb2_pte_writes\000extended\000TLB2 PTE Writes\000event=0x92\000\00000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000"
/* offset=76607 */ "tlb2_crste_hpage_writes\000extended\000TLB2 CRSTE One-Megabyte Page Writes\000event=0x93\000\00000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays for a one-megabyte large page translation\000"
/* offset=76830 */ "tlb2_crste_writes\000extended\000TLB2 CRSTE Writes\000event=0x94\000\00000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays\000"
/* offset=76987 */ "l1d_onchip_l3_sourced_writes\000extended\000L1D On-Chip L3 Sourced Writes\000event=0x96\000\00000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an On Chip Level-3 cache\000"
/* offset=77196 */ "l1d_offchip_l3_sourced_writes\000extended\000L1D Off-Chip L3 Sourced Writes\000event=0x98\000\00000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache\000"
/* offset=77416 */ "l1i_onchip_l3_sourced_writes\000extended\000L1I On-Chip L3 Sourced Writes\000event=0x99\000\00000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an On Chip Level-3 cache\000"
/* offset=77632 */ "l1i_offchip_l3_sourced_writes\000extended\000L1I Off-Chip L3 Sourced Writes\000event=0x9b\000\00000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache\000"
/* offset=77859 */ "dtlb1_misses\000extended\000DTLB1 Misses\000event=0x80\000\00000\000Level-1 Data TLB miss in progress. Incremented by one for every cycle a DTLB1 miss is in progress\000"
/* offset=78007 */ "itlb1_misses\000extended\000ITLB1 Misses\000event=0x81\000\00000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle a ITLB1 miss is in progress\000"
/* offset=78162 */ "l1d_l2i_sourced_writes\000extended\000L1D L2I Sourced Writes\000event=0x82\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000"
/* offset=78363 */ "l1i_l2i_sourced_writes\000extended\000L1I L2I Sourced Writes\000event=0x83\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000"
/* offset=78571 */ "l1d_l2d_sourced_writes\000extended\000L1D L2D Sourced Writes\000event=0x84\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache\000"
/* offset=78765 */ "dtlb1_writes\000extended\000DTLB1 Writes\000event=0x85\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000"
/* offset=78909 */ "l1d_lmem_sourced_writes\000extended\000L1D Local Memory Sourced Writes\000event=0x87\000\00000\000A directory write to the Level-1 Data cache where the installed cache line was sourced from memory that is attached to the same book as the Data cache (Local Memory)\000"
/* offset=79155 */ "l1i_lmem_sourced_writes\000extended\000L1I Local Memory Sourced Writes\000event=0x89\000\00000\000A directory write to the Level-1 Instruction cache where the installed cache line was sourced from memory that is attached to the same book as the Instruction cache (Local Memory)\000"
/* offset=79415 */ "l1d_ro_excl_writes\000extended\000L1D Read-only Exclusive Writes\000event=0x8a\000\00000\000A directory write to the Level-1 Data Cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000"
/* offset=79684 */ "dtlb1_hpage_writes\000extended\000DTLB1 One-Megabyte Page Writes\000event=0x8b\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a one-megabyte page\000"
/* offset=79868 */ "itlb1_writes\000extended\000ITLB1 Writes\000event=0x8c\000\00000\000A translation entry has been written to the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000"
/* offset=80019 */ "tlb2_pte_writes\000extended\000TLB2 PTE Writes\000event=0x8d\000\00000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000"
/* offset=80155 */ "tlb2_crste_writes\000extended\000TLB2 CRSTE Writes\000event=0x8f\000\00000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays\000"
/* offset=80312 */ "l1d_onchip_l3_sourced_writes\000extended\000L1D On-Chip L3 Sourced Writes\000event=0x90\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On Chip Level-3 cache without intervention\000"
/* offset=80542 */ "l1d_offchip_l3_sourced_writes\000extended\000L1D Off-Chip L3 Sourced Writes\000event=0x91\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache without intervention\000"
/* offset=80783 */ "l1d_offbook_l3_sourced_writes\000extended\000L1D Off-Book L3 Sourced Writes\000event=0x92\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Book Level-3 cache without intervention\000"
/* offset=81016 */ "l1d_onbook_l4_sourced_writes\000extended\000L1D On-Book L4 Sourced Writes\000event=0x93\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On Book Level-4 cache\000"
/* offset=81225 */ "l1d_offbook_l4_sourced_writes\000extended\000L1D Off-Book L4 Sourced Writes\000event=0x94\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000"
/* offset=81437 */ "tx_nc_tend\000extended\000Completed TEND instructions in non-constrained TX mode\000event=0x95\000\00000\000A TEND instruction has completed in a nonconstrained transactional-execution mode\000"
/* offset=81609 */ "l1d_onchip_l3_sourced_writes_iv\000extended\000L1D On-Chip L3 Sourced Writes with Intervention\000event=0x96\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from a On Chip Level-3 cache with intervention\000"
/* offset=81856 */ "l1d_offchip_l3_sourced_writes_iv\000extended\000L1D Off-Chip L3 Sourced Writes with Intervention\000event=0x97\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache with intervention\000"
/* offset=82115 */ "l1d_offbook_l3_sourced_writes_iv\000extended\000L1D Off-Book L3 Sourced Writes with Intervention\000event=0x98\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Book Level-3 cache with intervention\000"
/* offset=82366 */ "l1i_onchip_l3_sourced_writes\000extended\000L1I On-Chip L3 Sourced Writes\000event=0x99\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Chip Level-3 cache without intervention\000"
/* offset=82603 */ "l1i_offchip_l3_sourced_writes\000extended\000L1I Off-Chip L3 Sourced Writes\000event=0x9a\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache without intervention\000"
/* offset=82851 */ "l1i_offbook_l3_sourced_writes\000extended\000L1I Off-Book L3 Sourced Writes\000event=0x9b\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Book Level-3 cache without intervention\000"
/* offset=83091 */ "l1i_onbook_l4_sourced_writes\000extended\000L1I On-Book L4 Sourced Writes\000event=0x9c\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Book Level-4 cache\000"
/* offset=83307 */ "l1i_offbook_l4_sourced_writes\000extended\000L1I Off-Book L4 Sourced Writes\000event=0x9d\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000"
/* offset=83526 */ "tx_c_tend\000extended\000Completed TEND instructions in constrained TX mode\000event=0x9e\000\00000\000A TEND instruction has completed in a constrained transactional-execution mode\000"
/* offset=83690 */ "l1i_onchip_l3_sourced_writes_iv\000extended\000L1I On-Chip L3 Sourced Writes with Intervention\000event=0x9f\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Chip Level-3 cache with intervention\000"
/* offset=83945 */ "l1i_offchip_l3_sourced_writes_iv\000extended\000L1I Off-Chip L3 Sourced Writes with Intervention\000event=0xa0\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache with intervention\000"
/* offset=84211 */ "l1i_offbook_l3_sourced_writes_iv\000extended\000L1I Off-Book L3 Sourced Writes with Intervention\000event=0xa1\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Book Level-3 cache with intervention\000"
/* offset=84469 */ "tx_nc_tabort\000extended\000Aborted transactions in non-constrained TX mode\000event=0xb1\000\00000\000A transaction abort has occurred in a nonconstrained transactional-execution mode\000"
/* offset=84636 */ "tx_c_tabort_no_special\000extended\000Aborted transactions in constrained TX mode not using special completion logic\000event=0xb2\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000"
/* offset=84921 */ "tx_c_tabort_special\000extended\000Aborted transactions in constrained TX mode using special completion logic\000event=0xb3\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000"
/* offset=85191 */ "bp_l1_btb_correct\000branch\000L1 BTB Correction\000event=0x8a\000\00000\000\000"
/* offset=85250 */ "bp_l2_btb_correct\000branch\000L2 BTB Correction\000event=0x8b\000\00000\000\000"
/* offset=85309 */ "l3_cache_rd\000cache\000L3 cache access, read\000event=0x40\000\00000\000Attributable Level 3 cache access, read\000"
/* offset=85404 */ "segment_reg_loads.any\000other\000Number of segment register loads\000event=6,period=200000,umask=0x80\000\00000\000\000"
/* offset=85503 */ "dispatch_blocked.any\000other\000Memory cluster signals to block micro-op dispatch for any reason\000event=9,period=200000,umask=0x20\000\00000\000\000"
/* offset=85633 */ "eist_trans\000other\000Number of Enhanced Intel SpeedStep(R) Technology (EIST) transitions\000event=0x3a,period=200000\000\00000\000\000"
/* offset=85748 */ "hisi_sccl,ddrc\000"
/* offset=85763 */ "uncore_hisi_ddrc.flux_wcmd\000uncore\000DDRC write commands\000event=2\000\00000\000DDRC write commands\000"
/* offset=85849 */ "uncore_cbox\000"
/* offset=85861 */ "unc_cbo_xsnp_response.miss_eviction\000uncore\000A cross-core snoop resulted from L3 Eviction which misses in some processor core\000event=0x22,umask=0x81\000\00000\000A cross-core snoop resulted from L3 Eviction which misses in some processor core\000"
/* offset=86092 */ "event-hyphen\000uncore\000UNC_CBO_HYPHEN\000event=0xe0\000\00000\000UNC_CBO_HYPHEN\000"
/* offset=86157 */ "event-two-hyph\000uncore\000UNC_CBO_TWO_HYPH\000event=0xc0\000\00000\000UNC_CBO_TWO_HYPH\000"
/* offset=86228 */ "hisi_sccl,l3c\000"
/* offset=86242 */ "uncore_hisi_l3c.rd_hit_cpipe\000uncore\000Total read hits\000event=7\000\00000\000Total read hits\000"
/* offset=86322 */ "uncore_imc_free_running\000"
/* offset=86346 */ "uncore_imc_free_running.cache_miss\000uncore\000Total cache misses\000event=0x12\000\00000\000Total cache misses\000"
/* offset=86441 */ "uncore_imc\000"
/* offset=86452 */ "uncore_imc.cache_hits\000uncore\000Total cache hits\000event=0x34\000\00000\000Total cache hits\000"
/* offset=86530 */ "uncore_sys_ddr_pmu\000"
/* offset=86549 */ "sys_ddr_pmu.write_cycles\000uncore\000ddr write-cycles event\000event=0x2b\000v8\00000\000\000"
/* offset=86622 */ "uncore_sys_ccn_pmu\000"
/* offset=86641 */ "sys_ccn_pmu.read_cycles\000uncore\000ccn read-cycles event\000config=0x2c\0000x01\00000\000\000"
/* offset=86715 */ "uncore_sys_cmn_pmu\000"
/* offset=86734 */ "sys_cmn_pmu.hnf_cache_miss\000uncore\000Counts total cache misses in first lookup result (high priority)\000eventid=1,type=5\000(434|436|43c|43a).*\00000\000\000"
/* offset=86874 */ "default_core\000"
/* offset=86887 */ "transaction\000\000TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL\000\000Transaction count\000\000\000\000\000\00000"
/* offset=87011 */ "cpi\000\000CPU_CYCLES / INSTRUCTIONS\000\000Cycles per Instruction\000\000\000\000\000\00000"
/* offset=87073 */ "prbstate\000\000PROBLEM_STATE_INSTRUCTIONS / INSTRUCTIONS * 100\000\000Problem State Instruction Ratio\000\000\000\000\000\00000"
/* offset=87171 */ "l1mp\000\000(L1I_DIR_WRITES + L1D_DIR_WRITES) / INSTRUCTIONS * 100\000\000Level One Miss per 100 Instructions\000\000\000\000\000\00000"
/* offset=87276 */ "l2p\000\000(L1D_L2D_SOURCED_WRITES + L1I_L2I_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 2 cache\000\000\000\000\000\00000"
/* offset=87419 */ "l3p\000\000(L1D_ONCHIP_L3_SOURCED_WRITES + L1D_ONCHIP_L3_SOURCED_WRITES_IV + L1I_ONCHIP_L3_SOURCED_WRITES + L1I_ONCHIP_L3_SOURCED_WRITES_IV) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 3 on same chip cache\000\000\000\000\000\00000"
/* offset=87655 */ "l4lp\000\000(L1D_ONNODE_L4_SOURCED_WRITES + L1D_ONNODE_L3_SOURCED_WRITES_IV + L1D_ONNODE_L3_SOURCED_WRITES + L1I_ONNODE_L4_SOURCED_WRITES + L1I_ONNODE_L3_SOURCED_WRITES_IV + L1I_ONNODE_L3_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 4 Local cache on same book\000\000\000\000\000\00000"
/* offset=87960 */ "l4rp\000\000(L1D_ONDRAWER_L4_SOURCED_WRITES + L1D_ONDRAWER_L3_SOURCED_WRITES_IV + L1D_ONDRAWER_L3_SOURCED_WRITES + L1D_OFFDRAWER_SCOL_L4_SOURCED_WRITES + L1D_OFFDRAWER_SCOL_L3_SOURCED_WRITES_IV + L1D_OFFDRAWER_SCOL_L3_SOURCED_WRITES + L1D_OFFDRAWER_FCOL_L4_SOURCED_WRITES + L1D_OFFDRAWER_FCOL_L3_SOURCED_WRITES_IV + L1D_OFFDRAWER_FCOL_L3_SOURCED_WRITES + L1I_ONDRAWER_L4_SOURCED_WRITES + L1I_ONDRAWER_L3_SOURCED_WRITES_IV + L1I_ONDRAWER_L3_SOURCED_WRITES + L1I_OFFDRAWER_SCOL_L4_SOURCED_WRITES + L1I_OFFDRAWER_SCOL_L3_SOURCED_WRITES_IV + L1I_OFFDRAWER_SCOL_L3_SOURCED_WRITES + L1I_OFFDRAWER_FCOL_L4_SOURCED_WRITES + L1I_OFFDRAWER_FCOL_L3_SOURCED_WRITES_IV + L1I_OFFDRAWER_FCOL_L3_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 4 Remote cache on different book\000\000\000\000\000\00000"
/* offset=88763 */ "memp\000\000(L1D_ONNODE_MEM_SOURCED_WRITES + L1D_ONDRAWER_MEM_SOURCED_WRITES + L1D_OFFDRAWER_MEM_SOURCED_WRITES + L1D_ONCHIP_MEM_SOURCED_WRITES + L1I_ONNODE_MEM_SOURCED_WRITES + L1I_ONDRAWER_MEM_SOURCED_WRITES + L1I_OFFDRAWER_MEM_SOURCED_WRITES + L1I_ONCHIP_MEM_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from memory\000\000\000\000\000\00000"
/* offset=89116 */ "finite_cpi\000\000L1C_TLB1_MISSES / INSTRUCTIONS\000\000Cycles per Instructions from Finite cache/memory\000\000\000\000\000\00000"
/* offset=89216 */ "est_cpi\000\000CPU_CYCLES / INSTRUCTIONS - L1C_TLB1_MISSES / INSTRUCTIONS\000\000Estimated Instruction Complexity CPI infinite Level 1\000\000\000\000\000\00000"
/* offset=89346 */ "scpl1m\000\000L1C_TLB1_MISSES / (L1I_DIR_WRITES + L1D_DIR_WRITES)\000\000Estimated Sourcing Cycles per Level 1 Miss\000\000\000\000\000\00000"
/* offset=89457 */ "tlb_percent\000\000(DTLB1_MISSES + ITLB1_MISSES) / CPU_CYCLES * (L1C_TLB1_MISSES / (L1I_PENALTY_CYCLES + L1D_PENALTY_CYCLES)) * 100\000\000Estimated TLB CPU percentage of Total CPU\000\000\000\000\000\00000"
/* offset=89633 */ "tlb_miss\000\000(DTLB1_MISSES + ITLB1_MISSES) / (DTLB1_WRITES + ITLB1_WRITES) * (L1C_TLB1_MISSES / (L1I_PENALTY_CYCLES + L1D_PENALTY_CYCLES))\000\000Estimated Cycles per TLB Miss\000\000\000\000\000\00000"
/* offset=89807 */ "pte_miss\000\000TLB2_PTE_WRITES / (DTLB1_WRITES + ITLB1_WRITES) * 100\000\000Page Table Entry misses\000\000\000\000\000\00000"
/* offset=89903 */ "l4lp\000\000(L1D_ONCLUSTER_L3_SOURCED_WRITES + L1D_ONCLUSTER_L3_SOURCED_WRITES_IV + L1D_ONDRAWER_L4_SOURCED_WRITES + L1I_ONCLUSTER_L3_SOURCED_WRITES + L1I_ONCLUSTER_L3_SOURCED_WRITES_IV + L1I_ONDRAWER_L4_SOURCED_WRITES + L1D_OFFCLUSTER_L3_SOURCED_WRITES + L1D_OFFCLUSTER_L3_SOURCED_WRITES_IV + L1D_ONCHIP_L3_SOURCED_WRITES_RO + L1I_OFFCLUSTER_L3_SOURCED_WRITES + L1I_OFFCLUSTER_L3_SOURCED_WRITES_IV) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 4 Local cache on same book\000\000\000\000\000\00000"
/* offset=90404 */ "l4rp\000\000(L1D_OFFDRAWER_L3_SOURCED_WRITES + L1D_OFFDRAWER_L3_SOURCED_WRITES_IV + L1D_OFFDRAWER_L4_SOURCED_WRITES + L1I_OFFDRAWER_L3_SOURCED_WRITES + L1I_OFFDRAWER_L3_SOURCED_WRITES_IV + L1I_OFFDRAWER_L4_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 4 Remote cache on different book\000\000\000\000\000\00000"
/* offset=90733 */ "memp\000\000(L1D_ONCHIP_MEMORY_SOURCED_WRITES + L1D_ONCLUSTER_MEMORY_SOURCED_WRITES + L1D_OFFCLUSTER_MEMORY_SOURCED_WRITES + L1D_OFFDRAWER_MEMORY_SOURCED_WRITES + L1I_ONCHIP_MEMORY_SOURCED_WRITES + L1I_ONCLUSTER_MEMORY_SOURCED_WRITES + L1I_OFFCLUSTER_MEMORY_SOURCED_WRITES + L1I_OFFDRAWER_MEMORY_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from memory\000\000\000\000\000\00000"
/* offset=91120 */ "finite_cpi\000\000L1C_TLB2_MISSES / INSTRUCTIONS\000\000Cycles per Instructions from Finite cache/memory\000\000\000\000\000\00000"
/* offset=91220 */ "est_cpi\000\000CPU_CYCLES / INSTRUCTIONS - L1C_TLB2_MISSES / INSTRUCTIONS\000\000Estimated Instruction Complexity CPI infinite Level 1\000\000\000\000\000\00000"
/* offset=91350 */ "scpl1m\000\000L1C_TLB2_MISSES / (L1I_DIR_WRITES + L1D_DIR_WRITES)\000\000Estimated Sourcing Cycles per Level 1 Miss\000\000\000\000\000\00000"
/* offset=91461 */ "tlb_percent\000\000(DTLB2_MISSES + ITLB2_MISSES) / CPU_CYCLES * (L1C_TLB2_MISSES / (L1I_PENALTY_CYCLES + L1D_PENALTY_CYCLES)) * 100\000\000Estimated TLB CPU percentage of Total CPU\000\000\000\000\000\00000"
/* offset=91637 */ "tlb_miss\000\000(DTLB2_MISSES + ITLB2_MISSES) / (DTLB2_WRITES + ITLB2_WRITES) * (L1C_TLB2_MISSES / (L1I_PENALTY_CYCLES + L1D_PENALTY_CYCLES))\000\000Estimated Cycles per TLB Miss\000\000\000\000\000\00000"
/* offset=91811 */ "l2p\000\000(DCW_REQ + DCW_REQ_IV + ICW_REQ + ICW_REQ_IV) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 2 cache\000\000\000\000\000\00000"
/* offset=91950 */ "l3p\000\000(DCW_REQ_CHIP_HIT + DCW_ON_CHIP + DCW_ON_CHIP_IV + DCW_ON_CHIP_CHIP_HIT + ICW_REQ_CHIP_HIT + ICW_ON_CHIP + ICW_ON_CHIP_IV + ICW_ON_CHIP_CHIP_HIT) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 3 on same chip cache\000\000\000\000\000\00000"
/* offset=92202 */ "l4lp\000\000(DCW_REQ_DRAWER_HIT + DCW_ON_CHIP_DRAWER_HIT + DCW_ON_MODULE + DCW_ON_DRAWER + IDCW_ON_MODULE_IV + IDCW_ON_MODULE_CHIP_HIT + IDCW_ON_MODULE_DRAWER_HIT + IDCW_ON_DRAWER_IV + IDCW_ON_DRAWER_CHIP_HIT + IDCW_ON_DRAWER_DRAWER_HIT + ICW_REQ_DRAWER_HIT + ICW_ON_CHIP_DRAWER_HIT + ICW_ON_MODULE + ICW_ON_DRAWER) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 4 Local cache on same book\000\000\000\000\000\00000"
/* offset=92619 */ "l4rp\000\000(DCW_OFF_DRAWER + IDCW_OFF_DRAWER_IV + IDCW_OFF_DRAWER_CHIP_HIT + IDCW_OFF_DRAWER_DRAWER_HIT + ICW_OFF_DRAWER) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 4 Remote cache on different book\000\000\000\000\000\00000"
/* offset=92849 */ "memp\000\000(DCW_ON_CHIP_MEMORY + DCW_ON_MODULE_MEMORY + DCW_ON_DRAWER_MEMORY + DCW_OFF_DRAWER_MEMORY + ICW_ON_CHIP_MEMORY + ICW_ON_MODULE_MEMORY + ICW_ON_DRAWER_MEMORY + ICW_OFF_DRAWER_MEMORY) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from memory\000\000\000\000\000\00000"
/* offset=93118 */ "CPI\000\0001 / IPC\000\000\000\000\000\000\000\00000"
/* offset=93140 */ "IPC\000group1\000inst_retired.any / cpu_clk_unhalted.thread\000\000\000\000\000\000\000\00000"
/* offset=93203 */ "Frontend_Bound_SMT\000\000idq_uops_not_delivered.core / (4 * (cpu_clk_unhalted.thread / 2 * (1 + cpu_clk_unhalted.one_thread_active / cpu_clk_unhalted.ref_xclk)))\000\000\000\000\000\000\000\00000"
/* offset=93369 */ "dcache_miss_cpi\000\000l1d\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000\000\00000"
/* offset=93433 */ "icache_miss_cycles\000\000l1i\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000\000\00000"
/* offset=93500 */ "cache_miss_cycles\000group1\000dcache_miss_cpi + icache_miss_cycles\000\000\000\000\000\000\000\00000"
/* offset=93571 */ "DCache_L2_All_Hits\000\000l2_rqsts.demand_data_rd_hit + l2_rqsts.pf_hit + l2_rqsts.rfo_hit\000\000\000\000\000\000\000\00000"
/* offset=93665 */ "DCache_L2_All_Miss\000\000max(l2_rqsts.all_demand_data_rd - l2_rqsts.demand_data_rd_hit, 0) + l2_rqsts.pf_miss + l2_rqsts.rfo_miss\000\000\000\000\000\000\000\00000"
/* offset=93799 */ "DCache_L2_All\000\000DCache_L2_All_Hits + DCache_L2_All_Miss\000\000\000\000\000\000\000\00000"
/* offset=93863 */ "DCache_L2_Hits\000\000d_ratio(DCache_L2_All_Hits, DCache_L2_All)\000\000\000\000\000\000\000\00000"
/* offset=93931 */ "DCache_L2_Misses\000\000d_ratio(DCache_L2_All_Miss, DCache_L2_All)\000\000\000\000\000\000\000\00000"
/* offset=94001 */ "M1\000\000ipc + M2\000\000\000\000\000\000\000\00000"
/* offset=94023 */ "M2\000\000ipc + M1\000\000\000\000\000\000\000\00000"
/* offset=94045 */ "M3\000\0001 / M3\000\000\000\000\000\000\000\00000"
/* offset=94065 */ "L1D_Cache_Fill_BW\000\00064 * l1d.replacement / 1e9 / duration_time\000\000\000\000\000\000\000\00000"
;

static const struct compact_pmu_event pmu_events__cf_z10_cpum_cf[] = {
{ 5403 }, /* aes_blocked_cycles\000crypto\000AES Blocked Cycle Count\000event=0x4f\000\00000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 5147 }, /* aes_blocked_functions\000crypto\000AES Blocked Function Count\000event=0x4e\000\00000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 4963 }, /* aes_cycles\000crypto\000AES Cycle Count\000event=0x4d\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000 */
{ 4832 }, /* aes_functions\000crypto\000AES Function Count\000event=0x4c\000\00000\000This counter counts the total number of the AES functions issued by the CPU\000 */
{ 8 }, /* cpu_cycles\000basic\000Cycle Count\000event=0\000\00000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000 */
{ 4584 }, /* dea_blocked_cycles\000crypto\000DEA Blocked Cycle Count\000event=0x4b\000\00000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 4328 }, /* dea_blocked_functions\000crypto\000DEA Blocked Function Count\000event=0x4a\000\00000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 4144 }, /* dea_cycles\000crypto\000DEA Cycle Count\000event=0x49\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000 */
{ 4013 }, /* dea_functions\000crypto\000DEA Function Count\000event=0x48\000\00000\000This counter counts the total number of the DEA functions issued by the CPU\000 */
{ 9018 }, /* dtlb1_misses\000extended\000DTLB1 Misses\000event=0x92\000\00000\000Level-1 Data TLB miss in progress. Incremented by one for every cycle an DTLB1 miss is in progress\000 */
{ 8202 }, /* dtlb1_writes\000extended\000DTLB1 Writes\000event=0x8b\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000 */
{ 167 }, /* instructions\000basic\000Instruction Count\000event=1\000\00000\000This counter counts the total number of instructions executed by the CPU\000 */
{ 8862 }, /* itlb1_misses\000extended\000ITLB1 Misses\000event=0x91\000\00000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle an ITLB1 miss is in progress\000 */
{ 8049 }, /* itlb1_writes\000extended\000ITLB1 Writes\000event=0x8a\000\00000\000A translation entry has been written into the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000 */
{ 641 }, /* l1d_dir_writes\000basic\000Level-1 D-Cache Directory Write Count\000event=4\000\00000\000This counter counts the total number of level-1 data-cache directory writes\000 */
{ 5852 }, /* l1d_l2_sourced_writes\000extended\000L1D L2 Sourced Writes\000event=0x81\000\00000\000A directory write to the Level-1 Data Cache directory where the installed cache line was sourced from the Level-2 (L1.5) cache\000 */
{ 6305 }, /* l1d_l3_local_writes\000extended\000L1D L3 Local Writes\000event=0x83\000\00000\000A directory write to the Level-1 Data Cache directory where the installed cache line was source from the Level-3 cache that is on the same book as the Data cache (Local L2 cache)\000 */
{ 6811 }, /* l1d_l3_remote_writes\000extended\000L1D L3 Remote Writes\000event=0x85\000\00000\000A directory write to the Level-1 Data Cache directory where the installed cache line was sourced from a Level-3 cache that is not on the same book as the Data cache (Remote L2 cache)\000 */
{ 7060 }, /* l1d_lmem_sourced_writes\000extended\000L1D Local Memory Sourced Writes\000event=0x86\000\00000\000A directory write to the Level-1 Data Cache directory where the installed cache line was sourced from memory that is attached to the same book as the Data cache (Local Memory)\000 */
{ 788 }, /* l1d_penalty_cycles\000basic\000Level-1 D-Cache Penalty Cycle Count\000event=5\000\00000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000 */
{ 7577 }, /* l1d_ro_excl_writes\000extended\000L1D Read-only Exclusive Writes\000event=0x88\000\00000\000A directory write to the Level-1 Data Cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000 */
{ 7846 }, /* l1i_cacheline_invalidates\000extended\000L1I Cacheline Invalidates\000event=0x89\000\00000\000A cache line in the Level-1 Instruction Cache has been invalidated by a store on the same CPU as the Level-1 Instruction Cache\000 */
{ 289 }, /* l1i_dir_writes\000basic\000Level-1 I-Cache Directory Write Count\000event=2\000\00000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000 */
{ 5651 }, /* l1i_l2_sourced_writes\000extended\000L1I L2 Sourced Writes\000event=0x80\000\00000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from the Level-2 (L1.5) cache\000 */
{ 6047 }, /* l1i_l3_local_writes\000extended\000L1I L3 Local Writes\000event=0x82\000\00000\000A directory write to the Level-1 Instruction Cache directory where the installed cache line was sourced from the Level-3 cache that is on the same book as the Instruction cache (Local L2 cache)\000 */
{ 6548 }, /* l1i_l3_remote_writes\000extended\000L1I L3 Remote Writes\000event=0x84\000\00000\000A directory write to the Level-1 Instruction Cache directory where the installed cache line was sourced from a Level-3 cache that is not on the same book as the Instruction cache (Remote L2 cache)\000 */
{ 7316 }, /* l1i_lmem_sourced_writes\000extended\000L1I Local Memory Sourced Writes\000event=0x87\000\00000\000A directory write to the Level-1 Instruction Cache where the installed cache line was sourced from memory that is attached to the s ame book as the Instruction cache (Local Memory)\000 */
{ 460 }, /* l1i_penalty_cycles\000basic\000Level-1 I-Cache Penalty Cycle Count\000event=3\000\00000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000 */
{ 9167 }, /* l2c_stores_sent\000extended\000L2C Stores Sent\000event=0x93\000\00000\000Incremented by one for every store sent to Level-2 (L1.5) cache\000 */
{ 2925 }, /* prng_blocked_cycles\000crypto\000PRNG Blocked Cycle Count\000event=0x43\000\00000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 2636 }, /* prng_blocked_functions\000crypto\000PRNG Blocked Function Count\000event=0x42\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 2418 }, /* prng_cycles\000crypto\000PRNG Cycle Count\000event=0x41\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000 */
{ 2258 }, /* prng_functions\000crypto\000PRNG Function Count\000event=0x40\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000 */
{ 945 }, /* problem_state_cpu_cycles\000basic\000Problem-State Cycle Count\000event=0x20\000\00000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000 */
{ 1172 }, /* problem_state_instructions\000basic\000Problem-State Instruction Count\000event=0x21\000\00000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000 */
{ 1822 }, /* problem_state_l1d_dir_writes\000basic\000Problem-State Level-1 D-Cache Directory Write Count\000event=0x24\000\00000\000This counter counts the total number of level-1 data-cache directory writes while the CPU is in the problem state\000 */
{ 2038 }, /* problem_state_l1d_penalty_cycles\000basic\000Problem-State Level-1 D-Cache Penalty Cycle Count\000event=0x25\000\00000\000This counter counts the total number of penalty cycles for level-1 data cache while the CPU is in the problem state\000 */
{ 1352 }, /* problem_state_l1i_dir_writes\000basic\000Problem-State Level-1 I-Cache Directory Write Count\000event=0x22\000\00000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes while the CPU is in the problem state\000 */
{ 1592 }, /* problem_state_l1i_penalty_cycles\000basic\000Level-1 I-Cache Penalty Cycle Count\000event=0x23\000\00000\000This counter counts the total number of penalty cycles for level-1 instruction cache or unified cache while the CPU is in the problem state\000 */
{ 3769 }, /* sha_blocked_cycles\000crypto\000SHA Blocked Cycle Count\000event=0x47\000\00000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 3517 }, /* sha_blocked_functions\000crypto\000SHA Blocked Function Count\000event=0x46\000\00000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 3337 }, /* sha_cycles\000crypto\000SHA Cycle Count\000event=0x45\000\00000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000 */
{ 3206 }, /* sha_functions\000crypto\000SHA Function Count\000event=0x44\000\00000\000This counter counts the total number of the SHA functions issued by the CPU\000 */
{ 8639 }, /* tlb2_crste_hpage_writes\000extended\000TLB2 CRSTE One-Megabyte Page Writes\000event=0x8e\000\00000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays for a one-megabyte large page translation\000 */
{ 8482 }, /* tlb2_crste_writes\000extended\000TLB2 CRSTE Writes\000event=0x8d\000\00000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays\000 */
{ 8346 }, /* tlb2_pte_writes\000extended\000TLB2 PTE Writes\000event=0x8c\000\00000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000 */

};

const struct pmu_table_entry pmu_events__cf_z10[] = {
{
     .entries = pmu_events__cf_z10_cpum_cf,
     .num_entries = ARRAY_SIZE(pmu_events__cf_z10_cpum_cf),
     .pmu_name = { 0 /* cpum_cf\000 */ },
},
};

static const struct compact_pmu_event pmu_events__cf_z13_cpum_cf[] = {
{ 5403 }, /* aes_blocked_cycles\000crypto\000AES Blocked Cycle Count\000event=0x4f\000\00000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 5147 }, /* aes_blocked_functions\000crypto\000AES Blocked Function Count\000event=0x4e\000\00000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 4963 }, /* aes_cycles\000crypto\000AES Cycle Count\000event=0x4d\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000 */
{ 4832 }, /* aes_functions\000crypto\000AES Function Count\000event=0x4c\000\00000\000This counter counts the total number of the AES functions issued by the CPU\000 */
{ 8 }, /* cpu_cycles\000basic\000Cycle Count\000event=0\000\00000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000 */
{ 4584 }, /* dea_blocked_cycles\000crypto\000DEA Blocked Cycle Count\000event=0x4b\000\00000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 4328 }, /* dea_blocked_functions\000crypto\000DEA Blocked Function Count\000event=0x4a\000\00000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 4144 }, /* dea_cycles\000crypto\000DEA Cycle Count\000event=0x49\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000 */
{ 4013 }, /* dea_functions\000crypto\000DEA Function Count\000event=0x48\000\00000\000This counter counts the total number of the DEA functions issued by the CPU\000 */
{ 10032 }, /* dtlb1_gpage_writes\000extended\000DTLB1 Two-Gigabyte Page Writes\000event=0x84\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a two-gigabyte page\000 */
{ 9848 }, /* dtlb1_hpage_writes\000extended\000DTLB1 One-Megabyte Page Writes\000event=0x83\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a one-megabyte page\000 */
{ 9700 }, /* dtlb1_misses\000extended\000DTLB1 Misses\000event=0x82\000\00000\000Level-1 Data TLB miss in progress. Incremented by one for every cycle a DTLB1 miss is in progress\000 */
{ 9556 }, /* dtlb1_writes\000extended\000DTLB1 Writes\000event=0x81\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000 */
{ 167 }, /* instructions\000basic\000Instruction Count\000event=1\000\00000\000This counter counts the total number of instructions executed by the CPU\000 */
{ 10561 }, /* itlb1_misses\000extended\000ITLB1 Misses\000event=0x87\000\00000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle an ITLB1 miss is in progress\000 */
{ 10410 }, /* itlb1_writes\000extended\000ITLB1 Writes\000event=0x86\000\00000\000A translation entry has been written to the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000 */
{ 11782 }, /* l1c_tlb1_misses\000extended\000L1C TLB1 Misses\000event=0x8f\000\00000\000Increments by one for any cycle where a Level-1 cache or Level-1 TLB miss is in progress\000 */
{ 641 }, /* l1d_dir_writes\000basic\000Level-1 D-Cache Directory Write Count\000event=4\000\00000\000This counter counts the total number of level-1 data-cache directory writes\000 */
{ 10216 }, /* l1d_l2d_sourced_writes\000extended\000L1D L2D Sourced Writes\000event=0x85\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache\000 */
{ 15127 }, /* l1d_offdrawer_fcol_l3_sourced_writes\000extended\000L1D Off-Drawer Far-Column L3 Sourced Writes\000event=0x9d\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache without intervention\000 */
{ 14843 }, /* l1d_offdrawer_fcol_l3_sourced_writes_iv\000extended\000L1D Off-Drawer Far-Column L3 Sourced Writes with Intervention\000event=0x9c\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache with intervention\000 */
{ 14598 }, /* l1d_offdrawer_fcol_l4_sourced_writes\000extended\000L1D Off-Drawer Far-Column L3 Sourced Writes\000event=0x9b\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-4 cache\000 */
{ 15807 }, /* l1d_offdrawer_mem_sourced_writes\000extended\000L1D Off-Drawer Memory Sourced Writes\000event=0xa0\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory\000 */
{ 14330 }, /* l1d_offdrawer_scol_l3_sourced_writes\000extended\000L1D Off-Drawer Same-Column L3 Sourced Writes\000event=0x9a\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache without intervention\000 */
{ 14044 }, /* l1d_offdrawer_scol_l3_sourced_writes_iv\000extended\000L1D Off-Drawer Same-Column L3 Sourced Writes with Intervention\000event=0x99\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache with intervention\000 */
{ 13797 }, /* l1d_offdrawer_scol_l4_sourced_writes\000extended\000L1D Off-Drawer Same-Column L4 Sourced Writes\000event=0x98\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-4 cache\000 */
{ 11927 }, /* l1d_onchip_l3_sourced_writes\000extended\000L1D On-Chip L3 Sourced Writes\000event=0x90\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention\000 */
{ 12157 }, /* l1d_onchip_l3_sourced_writes_iv\000extended\000L1D On-Chip L3 Sourced Writes with Intervention\000event=0x91\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache with intervention\000 */
{ 16020 }, /* l1d_onchip_mem_sourced_writes\000extended\000L1D On-Chip Memory Sourced Writes\000event=0xa1\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory\000 */
{ 13561 }, /* l1d_ondrawer_l3_sourced_writes\000extended\000L1D On-Drawer L3 Sourced Writes\000event=0x97\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache without intervention\000 */
{ 13307 }, /* l1d_ondrawer_l3_sourced_writes_iv\000extended\000L1D On-Drawer L3 Sourced Writes with Intervention\000event=0x96\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache with intervention\000 */
{ 13092 }, /* l1d_ondrawer_l4_sourced_writes\000extended\000L1D On-Drawer L4 Sourced Writes\000event=0x95\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-4 cache\000 */
{ 15597 }, /* l1d_ondrawer_mem_sourced_writes\000extended\000L1D On-Drawer Memory Sourced Writes\000event=0x9f\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer memory\000 */
{ 12862 }, /* l1d_onnode_l3_sourced_writes\000extended\000L1D On-Node L3 Sourced Writes\000event=0x94\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Node Level-3 cache without intervention\000 */
{ 12614 }, /* l1d_onnode_l3_sourced_writes_iv\000extended\000L1D On-Node L3 Sourced Writes with Intervention\000event=0x93\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Node Level-3 cache with intervention\000 */
{ 12405 }, /* l1d_onnode_l4_sourced_writes\000extended\000L1D On-Node L4 Sourced Writes\000event=0x92\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Node Level-4 cache\000 */
{ 15393 }, /* l1d_onnode_mem_sourced_writes\000extended\000L1D On-Node Memory Sourced Writes\000event=0x9e\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Node memory\000 */
{ 788 }, /* l1d_penalty_cycles\000basic\000Level-1 D-Cache Penalty Cycle Count\000event=5\000\00000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000 */
{ 9287 }, /* l1d_ro_excl_writes\000extended\000L1D Read-only Exclusive Writes\000event=0x80\000\00000\000A directory write to the Level-1 Data cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000 */
{ 289 }, /* l1i_dir_writes\000basic\000Level-1 I-Cache Directory Write Count\000event=2\000\00000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000 */
{ 10717 }, /* l1i_l2i_sourced_writes\000extended\000L1I L2I Sourced Writes\000event=0x88\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000 */
{ 19515 }, /* l1i_offdrawer_fcol_l3_sourced_writes\000extended\000L1I Off-Drawer Far-Column L3 Sourced Writes\000event=0xaf\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache without intervention\000 */
{ 19224 }, /* l1i_offdrawer_fcol_l3_sourced_writes_iv\000extended\000L1I Off-Drawer Far-Column L3 Sourced Writes with Intervention\000event=0xae\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-3 cache with intervention\000 */
{ 18972 }, /* l1i_offdrawer_fcol_l4_sourced_writes\000extended\000L1I Off-Drawer Far-Column L4 Sourced Writes\000event=0xad\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Far-Column Level-4 cache\000 */
{ 20216 }, /* l1i_offdrawer_mem_sourced_writes\000extended\000L1I Off-Drawer Memory Sourced Writes\000event=0xb2\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer memory\000 */
{ 18697 }, /* l1i_offdrawer_scol_l3_sourced_writes\000extended\000L1I Off-Drawer Same-Column L3 Sourced Writes\000event=0xac\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache without intervention\000 */
{ 18404 }, /* l1i_offdrawer_scol_l3_sourced_writes_iv\000extended\000L1I Off-Drawer Same-Column L3 Sourced Writes with Intervention\000event=0xab\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-3 cache with intervention\000 */
{ 18150 }, /* l1i_offdrawer_scol_l4_sourced_writes\000extended\000L1I Off-Drawer Same-Column L4 Sourced Writes\000event=0xaa\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Same-Column Level-4 cache\000 */
{ 16224 }, /* l1i_onchip_l3_sourced_writes\000extended\000L1I On-Chip L3 Sourced Writes\000event=0xa2\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention\000 */
{ 16461 }, /* l1i_onchip_l3_sourced_writes_iv\000extended\000L1I On-Chip L3 Sourced Writes with Intervention\000event=0xa3\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Chip Level-3 cache with intervention\000 */
{ 20435 }, /* l1i_onchip_mem_sourced_writes\000extended\000L1I On-Chip Memory Sourced Writes\000event=0xb3\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Chip memory\000 */
{ 17907 }, /* l1i_ondrawer_l3_sourced_writes\000extended\000L1I On-Drawer L3 Sourced Writes\000event=0xa9\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache without intervention\000 */
{ 17646 }, /* l1i_ondrawer_l3_sourced_writes_iv\000extended\000L1I On-Drawer L3 Sourced Writes with Intervention\000event=0xa8\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-3 cache with intervention\000 */
{ 17424 }, /* l1i_ondrawer_l4_sourced_writes\000extended\000L1I On-Drawer L4 Sourced Writes\000event=0xa7\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-4 cache\000 */
{ 19999 }, /* l1i_ondrawer_mem_sourced_writes\000extended\000L1I On-Drawer Memory Sourced Writes\000event=0xb1\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer memory\000 */
{ 17187 }, /* l1i_onnode_l3_sourced_writes\000extended\000L1I On-Node L3 Sourced Writes\000event=0xa6\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Node Level-3 cache without intervention\000 */
{ 16932 }, /* l1i_onnode_l3_sourced_writes_iv\000extended\000L1I On-Node L3 Sourced Writes with Intervention\000event=0xa5\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Node Level-3 cache with intervention\000 */
{ 16716 }, /* l1i_onnode_l4_sourced_writes\000extended\000L1I On-Chip L4 Sourced Writes\000event=0xa4\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Node Level-4 cache\000 */
{ 19788 }, /* l1i_onnode_mem_sourced_writes\000extended\000L1I On-Node Memory Sourced Writes\000event=0xb0\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Node memory\000 */
{ 460 }, /* l1i_penalty_cycles\000basic\000Level-1 I-Cache Penalty Cycle Count\000event=3\000\00000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000 */
{ 21369 }, /* mt_diag_cycles_one_thr_active\000extended\000Cycle count with one thread active\000event=0x1c0\000\00000\000Cycle count with one thread active\000 */
{ 21494 }, /* mt_diag_cycles_two_thr_active\000extended\000Cycle count with two threads active\000event=0x1c1\000\00000\000Cycle count with two threads active\000 */
{ 2925 }, /* prng_blocked_cycles\000crypto\000PRNG Blocked Cycle Count\000event=0x43\000\00000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 2636 }, /* prng_blocked_functions\000crypto\000PRNG Blocked Function Count\000event=0x42\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 2418 }, /* prng_cycles\000crypto\000PRNG Cycle Count\000event=0x41\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000 */
{ 2258 }, /* prng_functions\000crypto\000PRNG Function Count\000event=0x40\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000 */
{ 945 }, /* problem_state_cpu_cycles\000basic\000Problem-State Cycle Count\000event=0x20\000\00000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000 */
{ 1172 }, /* problem_state_instructions\000basic\000Problem-State Instruction Count\000event=0x21\000\00000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000 */
{ 1822 }, /* problem_state_l1d_dir_writes\000basic\000Problem-State Level-1 D-Cache Directory Write Count\000event=0x24\000\00000\000This counter counts the total number of level-1 data-cache directory writes while the CPU is in the problem state\000 */
{ 2038 }, /* problem_state_l1d_penalty_cycles\000basic\000Problem-State Level-1 D-Cache Penalty Cycle Count\000event=0x25\000\00000\000This counter counts the total number of penalty cycles for level-1 data cache while the CPU is in the problem state\000 */
{ 1352 }, /* problem_state_l1i_dir_writes\000basic\000Problem-State Level-1 I-Cache Directory Write Count\000event=0x22\000\00000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes while the CPU is in the problem state\000 */
{ 1592 }, /* problem_state_l1i_penalty_cycles\000basic\000Level-1 I-Cache Penalty Cycle Count\000event=0x23\000\00000\000This counter counts the total number of penalty cycles for level-1 instruction cache or unified cache while the CPU is in the problem state\000 */
{ 3769 }, /* sha_blocked_cycles\000crypto\000SHA Blocked Cycle Count\000event=0x47\000\00000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 3517 }, /* sha_blocked_functions\000crypto\000SHA Blocked Function Count\000event=0x46\000\00000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 3337 }, /* sha_cycles\000crypto\000SHA Cycle Count\000event=0x45\000\00000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000 */
{ 3206 }, /* sha_functions\000crypto\000SHA Function Count\000event=0x44\000\00000\000This counter counts the total number of the SHA functions issued by the CPU\000 */
{ 11061 }, /* tlb2_crste_hpage_writes\000extended\000TLB2 CRSTE One-Megabyte Page Writes\000event=0x8a\000\00000\000A translation entry has been written to the Level-2 TLB Combined Region Segment Table Entry arrays for a one-megabyte large page translation\000 */
{ 11286 }, /* tlb2_crste_writes\000extended\000TLB2 CRSTE Writes\000event=0x8b\000\00000\000A translation entry has been written to the Level-2 TLB Combined Region Segment Table Entry arrays\000 */
{ 10925 }, /* tlb2_pte_writes\000extended\000TLB2 PTE Writes\000event=0x89\000\00000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000 */
{ 20814 }, /* tx_c_tabort_no_special\000extended\000Aborted transactions in constrained TX mode not using special completion logic\000event=0xdb\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000 */
{ 21099 }, /* tx_c_tabort_special\000extended\000Aborted transactions in constrained TX mode using special completion logic\000event=0xdc\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000 */
{ 11445 }, /* tx_c_tend\000extended\000Completed TEND instructions in constrained TX mode\000event=0x8c\000\00000\000A TEND instruction has completed in a constrained transactional-execution mode\000 */
{ 20646 }, /* tx_nc_tabort\000extended\000Aborted transactions in non-constrained TX mode\000event=0xda\000\00000\000A transaction abort has occurred in a non-constrained transactional-execution mode\000 */
{ 11609 }, /* tx_nc_tend\000extended\000Completed TEND instructions in non-constrained TX mode\000event=0x8d\000\00000\000A TEND instruction has completed in a non-constrained transactional-execution mode\000 */

};

const struct pmu_table_entry pmu_events__cf_z13[] = {
{
     .entries = pmu_events__cf_z13_cpum_cf,
     .num_entries = ARRAY_SIZE(pmu_events__cf_z13_cpum_cf),
     .pmu_name = { 0 /* cpum_cf\000 */ },
},
};

static const struct compact_pmu_event pmu_metrics__cf_z13_default_core[] = {
{ 87011 }, /* cpi\000\000CPU_CYCLES / INSTRUCTIONS\000\000Cycles per Instruction\000\000\000\000\000\00000 */
{ 89216 }, /* est_cpi\000\000CPU_CYCLES / INSTRUCTIONS - L1C_TLB1_MISSES / INSTRUCTIONS\000\000Estimated Instruction Complexity CPI infinite Level 1\000\000\000\000\000\00000 */
{ 89116 }, /* finite_cpi\000\000L1C_TLB1_MISSES / INSTRUCTIONS\000\000Cycles per Instructions from Finite cache/memory\000\000\000\000\000\00000 */
{ 87171 }, /* l1mp\000\000(L1I_DIR_WRITES + L1D_DIR_WRITES) / INSTRUCTIONS * 100\000\000Level One Miss per 100 Instructions\000\000\000\000\000\00000 */
{ 87276 }, /* l2p\000\000(L1D_L2D_SOURCED_WRITES + L1I_L2I_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 2 cache\000\000\000\000\000\00000 */
{ 87419 }, /* l3p\000\000(L1D_ONCHIP_L3_SOURCED_WRITES + L1D_ONCHIP_L3_SOURCED_WRITES_IV + L1I_ONCHIP_L3_SOURCED_WRITES + L1I_ONCHIP_L3_SOURCED_WRITES_IV) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 3 on same chip cache\000\000\000\000\000\00000 */
{ 87655 }, /* l4lp\000\000(L1D_ONNODE_L4_SOURCED_WRITES + L1D_ONNODE_L3_SOURCED_WRITES_IV + L1D_ONNODE_L3_SOURCED_WRITES + L1I_ONNODE_L4_SOURCED_WRITES + L1I_ONNODE_L3_SOURCED_WRITES_IV + L1I_ONNODE_L3_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 4 Local cache on same book\000\000\000\000\000\00000 */
{ 87960 }, /* l4rp\000\000(L1D_ONDRAWER_L4_SOURCED_WRITES + L1D_ONDRAWER_L3_SOURCED_WRITES_IV + L1D_ONDRAWER_L3_SOURCED_WRITES + L1D_OFFDRAWER_SCOL_L4_SOURCED_WRITES + L1D_OFFDRAWER_SCOL_L3_SOURCED_WRITES_IV + L1D_OFFDRAWER_SCOL_L3_SOURCED_WRITES + L1D_OFFDRAWER_FCOL_L4_SOURCED_WRITES + L1D_OFFDRAWER_FCOL_L3_SOURCED_WRITES_IV + L1D_OFFDRAWER_FCOL_L3_SOURCED_WRITES + L1I_ONDRAWER_L4_SOURCED_WRITES + L1I_ONDRAWER_L3_SOURCED_WRITES_IV + L1I_ONDRAWER_L3_SOURCED_WRITES + L1I_OFFDRAWER_SCOL_L4_SOURCED_WRITES + L1I_OFFDRAWER_SCOL_L3_SOURCED_WRITES_IV + L1I_OFFDRAWER_SCOL_L3_SOURCED_WRITES + L1I_OFFDRAWER_FCOL_L4_SOURCED_WRITES + L1I_OFFDRAWER_FCOL_L3_SOURCED_WRITES_IV + L1I_OFFDRAWER_FCOL_L3_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 4 Remote cache on different book\000\000\000\000\000\00000 */
{ 88763 }, /* memp\000\000(L1D_ONNODE_MEM_SOURCED_WRITES + L1D_ONDRAWER_MEM_SOURCED_WRITES + L1D_OFFDRAWER_MEM_SOURCED_WRITES + L1D_ONCHIP_MEM_SOURCED_WRITES + L1I_ONNODE_MEM_SOURCED_WRITES + L1I_ONDRAWER_MEM_SOURCED_WRITES + L1I_OFFDRAWER_MEM_SOURCED_WRITES + L1I_ONCHIP_MEM_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from memory\000\000\000\000\000\00000 */
{ 87073 }, /* prbstate\000\000PROBLEM_STATE_INSTRUCTIONS / INSTRUCTIONS * 100\000\000Problem State Instruction Ratio\000\000\000\000\000\00000 */
{ 89807 }, /* pte_miss\000\000TLB2_PTE_WRITES / (DTLB1_WRITES + ITLB1_WRITES) * 100\000\000Page Table Entry misses\000\000\000\000\000\00000 */
{ 89346 }, /* scpl1m\000\000L1C_TLB1_MISSES / (L1I_DIR_WRITES + L1D_DIR_WRITES)\000\000Estimated Sourcing Cycles per Level 1 Miss\000\000\000\000\000\00000 */
{ 89633 }, /* tlb_miss\000\000(DTLB1_MISSES + ITLB1_MISSES) / (DTLB1_WRITES + ITLB1_WRITES) * (L1C_TLB1_MISSES / (L1I_PENALTY_CYCLES + L1D_PENALTY_CYCLES))\000\000Estimated Cycles per TLB Miss\000\000\000\000\000\00000 */
{ 89457 }, /* tlb_percent\000\000(DTLB1_MISSES + ITLB1_MISSES) / CPU_CYCLES * (L1C_TLB1_MISSES / (L1I_PENALTY_CYCLES + L1D_PENALTY_CYCLES)) * 100\000\000Estimated TLB CPU percentage of Total CPU\000\000\000\000\000\00000 */
{ 86887 }, /* transaction\000\000TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL\000\000Transaction count\000\000\000\000\000\00000 */

};

const struct pmu_table_entry pmu_metrics__cf_z13[] = {
{
     .entries = pmu_metrics__cf_z13_default_core,
     .num_entries = ARRAY_SIZE(pmu_metrics__cf_z13_default_core),
     .pmu_name = { 86874 /* default_core\000 */ },
},
};

static const struct compact_pmu_event pmu_events__cf_z14_cpum_cf[] = {
{ 5403 }, /* aes_blocked_cycles\000crypto\000AES Blocked Cycle Count\000event=0x4f\000\00000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 5147 }, /* aes_blocked_functions\000crypto\000AES Blocked Function Count\000event=0x4e\000\00000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 4963 }, /* aes_cycles\000crypto\000AES Cycle Count\000event=0x4d\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000 */
{ 4832 }, /* aes_functions\000crypto\000AES Function Count\000event=0x4c\000\00000\000This counter counts the total number of the AES functions issued by the CPU\000 */
{ 30364 }, /* bcd_dfp_execution_slots\000extended\000BCD DFP Execution Slots\000event=0xe0\000\00000\000Count of floating point execution slots used for finished Binary Coded Decimal to Decimal Floating Point conversions. Instructions: CDZT, CXZT, CZDT, CZXT\000 */
{ 8 }, /* cpu_cycles\000basic\000Cycle Count\000event=0\000\00000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000 */
{ 4584 }, /* dea_blocked_cycles\000crypto\000DEA Blocked Cycle Count\000event=0x4b\000\00000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 4328 }, /* dea_blocked_functions\000crypto\000DEA Blocked Function Count\000event=0x4a\000\00000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 4144 }, /* dea_cycles\000crypto\000DEA Cycle Count\000event=0x49\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000 */
{ 4013 }, /* dea_functions\000crypto\000DEA Function Count\000event=0x48\000\00000\000This counter counts the total number of the DEA functions issued by the CPU\000 */
{ 30884 }, /* decimal_instructions\000extended\000Decimal Instructions\000event=0xe2\000\00000\000Decimal instructions dispatched. Instructions: CVB, CVD, AP, CP, DP, ED, EDMK, MP, SRP, SP, ZAP\000 */
{ 22391 }, /* dtlb2_gpage_writes\000extended\000DTLB2 Two-Gigabyte Page Writes\000event=0x84\000\00000\000A translation entry for a two-gigabyte page was written into the Level-2 TLB\000 */
{ 22151 }, /* dtlb2_hpage_writes\000extended\000DTLB2 One-Megabyte Page Writes\000event=0x83\000\00000\000A translation entry was written into the Combined Region and Segment Table Entry array in the Level-2 TLB for a one-megabyte page or a Last Host Translation was done\000 */
{ 21868 }, /* dtlb2_misses\000extended\000DTLB2 Misses\000event=0x82\000\00000\000A TLB2 miss is in progress for a request made by the data cache. Incremented by one for every TLB2 miss in progress for the Level-1 Data cache on this cycle. This is a replacement for what was provided for the DTLB on prior machines\000 */
{ 21621 }, /* dtlb2_writes\000extended\000DTLB2 Writes\000event=0x81\000\00000\000A translation has been written into The Translation Lookaside Buffer 2 (TLB2) and the request was made by the data cache. This is a replacement for what was provided for the DTLB on prior machines\000 */
{ 167 }, /* instructions\000basic\000Instruction Count\000event=1\000\00000\000This counter counts the total number of instructions executed by the CPU\000 */
{ 22802 }, /* itlb2_misses\000extended\000ITLB2 Misses\000event=0x87\000\00000\000A TLB2 miss is in progress for a request made by the instruction cache. Incremented by one for every TLB2 miss in progress for the Level-1 Instruction cache in a cycle. This is a replacement for what was provided for the ITLB on prior machines\000 */
{ 22542 }, /* itlb2_writes\000extended\000ITLB2 Writes\000event=0x86\000\00000\000A translation entry has been written into the Translation Lookaside Buffer 2 (TLB2) and the request was made by the instruction cache. This is a replacement for what was provided for the ITLB on prior machines\000 */
{ 23555 }, /* l1c_tlb2_misses\000extended\000L1C TLB2 Misses\000event=0x8f\000\00000\000Increments by one for any cycle where a level-1 cache or level-2 TLB miss is in progress\000 */
{ 641 }, /* l1d_dir_writes\000basic\000Level-1 D-Cache Directory Write Count\000event=4\000\00000\000This counter counts the total number of level-1 data-cache directory writes\000 */
{ 10216 }, /* l1d_l2d_sourced_writes\000extended\000L1D L2D Sourced Writes\000event=0x85\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache\000 */
{ 24867 }, /* l1d_offcluster_l3_sourced_writes\000extended\000L1D Off-Cluster L3 Sourced Writes\000event=0x96\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention\000 */
{ 25328 }, /* l1d_offcluster_l3_sourced_writes_iv\000extended\000L1D Off-Cluster L3 Sourced Writes with Intervention\000event=0x98\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention\000 */
{ 25109 }, /* l1d_offcluster_memory_sourced_writes\000extended\000L1D Off-Cluster Memory Sourced Writes\000event=0x97\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Cluster memory\000 */
{ 25588 }, /* l1d_offdrawer_l3_sourced_writes\000extended\000L1D Off-Drawer L3 Sourced Writes\000event=0x99\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention\000 */
{ 26043 }, /* l1d_offdrawer_l3_sourced_writes_iv\000extended\000L1D Off-Drawer L3 Sourced Writes with Intervention\000event=0x9b\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention\000 */
{ 26512 }, /* l1d_offdrawer_l4_sourced_writes\000extended\000L1D Off-Drawer L4 Sourced Writes\000event=0x9d\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache\000 */
{ 25827 }, /* l1d_offdrawer_memory_sourced_writes\000extended\000L1D Off-Drawer Memory Sourced Writes\000event=0x9a\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory\000 */
{ 11927 }, /* l1d_onchip_l3_sourced_writes\000extended\000L1D On-Chip L3 Sourced Writes\000event=0x90\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention\000 */
{ 23907 }, /* l1d_onchip_l3_sourced_writes_iv\000extended\000L1D On-Chip L3 Sourced Writes with Intervention\000event=0x92\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache with intervention\000 */
{ 26727 }, /* l1d_onchip_l3_sourced_writes_ro\000extended\000L1D On-Chip L3 Sourced Writes read-only\000event=0x9e\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip L3 but a read-only invalidate was done to remove other copies of the cache line\000 */
{ 23700 }, /* l1d_onchip_memory_sourced_writes\000extended\000L1D On-Chip Memory Sourced Writes\000event=0x91\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory\000 */
{ 24155 }, /* l1d_oncluster_l3_sourced_writes\000extended\000L1D On-Cluster L3 Sourced Writes\000event=0x93\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Cluster Level-3 cache without intervention\000 */
{ 24610 }, /* l1d_oncluster_l3_sourced_writes_iv\000extended\000L1D On-Cluster L3 Sourced Writes with Intervention\000event=0x95\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache with intervention\000 */
{ 24391 }, /* l1d_oncluster_memory_sourced_writes\000extended\000L1D On-Cluster Memory Sourced Writes\000event=0x94\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster memory\000 */
{ 26300 }, /* l1d_ondrawer_l4_sourced_writes\000extended\000L1D On-Drawer L4 Sourced Writes\000event=0x9c\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer Level-4 cache\000 */
{ 788 }, /* l1d_penalty_cycles\000basic\000Level-1 D-Cache Penalty Cycle Count\000event=5\000\00000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000 */
{ 9287 }, /* l1d_ro_excl_writes\000extended\000L1D Read-only Exclusive Writes\000event=0x80\000\00000\000A directory write to the Level-1 Data cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000 */
{ 289 }, /* l1i_dir_writes\000basic\000Level-1 I-Cache Directory Write Count\000event=2\000\00000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000 */
{ 10717 }, /* l1i_l2i_sourced_writes\000extended\000L1I L2I Sourced Writes\000event=0x88\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000 */
{ 28448 }, /* l1i_offcluster_l3_sourced_writes\000extended\000L1I Off-Cluster L3 Sourced Writes\000event=0xa8\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention\000 */
{ 28923 }, /* l1i_offcluster_l3_sourced_writes_iv\000extended\000L1I Off-Cluster L3 Sourced Writes with Intervention\000event=0xaa\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention\000 */
{ 28697 }, /* l1i_offcluster_memory_sourced_writes\000extended\000L1I Off-Cluster Memory Sourced Writes\000event=0xa9\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Cluster memory\000 */
{ 29190 }, /* l1i_offdrawer_l3_sourced_writes\000extended\000L1I Off-Drawer L3 Sourced Writes\000event=0xab\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention\000 */
{ 29659 }, /* l1i_offdrawer_l3_sourced_writes_iv\000extended\000L1I Off-Drawer L3 Sourced Writes with Intervention\000event=0xad\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention\000 */
{ 30142 }, /* l1i_offdrawer_l4_sourced_writes\000extended\000L1I Off-Drawer L4 Sourced Writes\000event=0xaf\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache\000 */
{ 29436 }, /* l1i_offdrawer_memory_sourced_writes\000extended\000L1I Off-Drawer Memory Sourced Writes\000event=0xac\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer memory\000 */
{ 27012 }, /* l1i_onchip_l3_sourced_writes\000extended\000L1I On-Chip L3 Sourced Writes\000event=0xa2\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache without intervention\000 */
{ 27461 }, /* l1i_onchip_l3_sourced_writes_iv\000extended\000L1I On-Chip L3 Sourced Writes with Intervention\000event=0xa4\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache with intervention\000 */
{ 27248 }, /* l1i_onchip_memory_sourced_writes\000extended\000L1I On-Chip Memory Sourced Writes\000event=0xa3\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from On-Chip memory\000 */
{ 27715 }, /* l1i_oncluster_l3_sourced_writes\000extended\000L1I On-Cluster L3 Sourced Writes\000event=0xa5\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache without intervention\000 */
{ 28187 }, /* l1i_oncluster_l3_sourced_writes_iv\000extended\000L1I On-Cluster L3 Sourced Writes with Intervention\000event=0xa7\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Cluster Level-3 cache with intervention\000 */
{ 27961 }, /* l1i_oncluster_memory_sourced_writes\000extended\000L1I On-Cluster Memory Sourced Writes\000event=0xa6\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster memory\000 */
{ 29923 }, /* l1i_ondrawer_l4_sourced_writes\000extended\000L1I On-Drawer L4 Sourced Writes\000event=0xae\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer Level-4 cache\000 */
{ 460 }, /* l1i_penalty_cycles\000basic\000Level-1 I-Cache Penalty Cycle Count\000event=3\000\00000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000 */
{ 31046 }, /* last_host_translations\000extended\000Last host translation done\000event=0xe8\000\00000\000Last Host Translation done\000 */
{ 21369 }, /* mt_diag_cycles_one_thr_active\000extended\000Cycle count with one thread active\000event=0x1c0\000\00000\000Cycle count with one thread active\000 */
{ 21494 }, /* mt_diag_cycles_two_thr_active\000extended\000Cycle count with two threads active\000event=0x1c1\000\00000\000Cycle count with two threads active\000 */
{ 2925 }, /* prng_blocked_cycles\000crypto\000PRNG Blocked Cycle Count\000event=0x43\000\00000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 2636 }, /* prng_blocked_functions\000crypto\000PRNG Blocked Function Count\000event=0x42\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 2418 }, /* prng_cycles\000crypto\000PRNG Cycle Count\000event=0x41\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000 */
{ 2258 }, /* prng_functions\000crypto\000PRNG Function Count\000event=0x40\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000 */
{ 945 }, /* problem_state_cpu_cycles\000basic\000Problem-State Cycle Count\000event=0x20\000\00000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000 */
{ 1172 }, /* problem_state_instructions\000basic\000Problem-State Instruction Count\000event=0x21\000\00000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000 */
{ 3769 }, /* sha_blocked_cycles\000crypto\000SHA Blocked Cycle Count\000event=0x47\000\00000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 3517 }, /* sha_blocked_functions\000crypto\000SHA Blocked Function Count\000event=0x46\000\00000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 3337 }, /* sha_cycles\000crypto\000SHA Cycle Count\000event=0x45\000\00000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000 */
{ 3206 }, /* sha_functions\000crypto\000SHA Function Count\000event=0x44\000\00000\000This counter counts the total number of the SHA functions issued by the CPU\000 */
{ 23235 }, /* tlb2_crste_writes\000extended\000TLB2 CRSTE Writes\000event=0x8a\000\00000\000Translation entries were written into the Combined Region and Segment Table Entry array and the Page Table Entry array in the Level-2 TLB\000 */
{ 23433 }, /* tlb2_engines_busy\000extended\000TLB2 Engines Busy\000event=0x8b\000\00000\000The number of Level-2 TLB translation engines busy in a cycle\000 */
{ 23096 }, /* tlb2_pte_writes\000extended\000TLB2 PTE Writes\000event=0x89\000\00000\000A translation entry was written into the Page Table Entry array in the Level-2 TLB\000 */
{ 31315 }, /* tx_c_tabort_no_special\000extended\000Aborted transactions in constrained TX mode not using special completion logic\000event=0xf4\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000 */
{ 31600 }, /* tx_c_tabort_special\000extended\000Aborted transactions in constrained TX mode using special completion logic\000event=0xf5\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000 */
{ 11445 }, /* tx_c_tend\000extended\000Completed TEND instructions in constrained TX mode\000event=0x8c\000\00000\000A TEND instruction has completed in a constrained transactional-execution mode\000 */
{ 31147 }, /* tx_nc_tabort\000extended\000Aborted transactions in non-constrained TX mode\000event=0xf3\000\00000\000A transaction abort has occurred in a non-constrained transactional-execution mode\000 */
{ 11609 }, /* tx_nc_tend\000extended\000Completed TEND instructions in non-constrained TX mode\000event=0x8d\000\00000\000A TEND instruction has completed in a non-constrained transactional-execution mode\000 */
{ 30591 }, /* vx_bcd_execution_slots\000extended\000VX BCD Execution Slots\000event=0xe1\000\00000\000Count of floating point execution slots used for finished vector arithmetic Binary Coded Decimal instructions. Instructions: VAP, VSP, VMPVMSP, VDP, VSDP, VRP, VLIP, VSRP, VPSOPVCP, VTP, VPKZ, VUPKZ, VCVB, VCVBG, VCVDVCVDG\000 */

};

const struct pmu_table_entry pmu_events__cf_z14[] = {
{
     .entries = pmu_events__cf_z14_cpum_cf,
     .num_entries = ARRAY_SIZE(pmu_events__cf_z14_cpum_cf),
     .pmu_name = { 0 /* cpum_cf\000 */ },
},
};

static const struct compact_pmu_event pmu_metrics__cf_z14_default_core[] = {
{ 87011 }, /* cpi\000\000CPU_CYCLES / INSTRUCTIONS\000\000Cycles per Instruction\000\000\000\000\000\00000 */
{ 91220 }, /* est_cpi\000\000CPU_CYCLES / INSTRUCTIONS - L1C_TLB2_MISSES / INSTRUCTIONS\000\000Estimated Instruction Complexity CPI infinite Level 1\000\000\000\000\000\00000 */
{ 91120 }, /* finite_cpi\000\000L1C_TLB2_MISSES / INSTRUCTIONS\000\000Cycles per Instructions from Finite cache/memory\000\000\000\000\000\00000 */
{ 87171 }, /* l1mp\000\000(L1I_DIR_WRITES + L1D_DIR_WRITES) / INSTRUCTIONS * 100\000\000Level One Miss per 100 Instructions\000\000\000\000\000\00000 */
{ 87276 }, /* l2p\000\000(L1D_L2D_SOURCED_WRITES + L1I_L2I_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 2 cache\000\000\000\000\000\00000 */
{ 87419 }, /* l3p\000\000(L1D_ONCHIP_L3_SOURCED_WRITES + L1D_ONCHIP_L3_SOURCED_WRITES_IV + L1I_ONCHIP_L3_SOURCED_WRITES + L1I_ONCHIP_L3_SOURCED_WRITES_IV) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 3 on same chip cache\000\000\000\000\000\00000 */
{ 89903 }, /* l4lp\000\000(L1D_ONCLUSTER_L3_SOURCED_WRITES + L1D_ONCLUSTER_L3_SOURCED_WRITES_IV + L1D_ONDRAWER_L4_SOURCED_WRITES + L1I_ONCLUSTER_L3_SOURCED_WRITES + L1I_ONCLUSTER_L3_SOURCED_WRITES_IV + L1I_ONDRAWER_L4_SOURCED_WRITES + L1D_OFFCLUSTER_L3_SOURCED_WRITES + L1D_OFFCLUSTER_L3_SOURCED_WRITES_IV + L1D_ONCHIP_L3_SOURCED_WRITES_RO + L1I_OFFCLUSTER_L3_SOURCED_WRITES + L1I_OFFCLUSTER_L3_SOURCED_WRITES_IV) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 4 Local cache on same book\000\000\000\000\000\00000 */
{ 90404 }, /* l4rp\000\000(L1D_OFFDRAWER_L3_SOURCED_WRITES + L1D_OFFDRAWER_L3_SOURCED_WRITES_IV + L1D_OFFDRAWER_L4_SOURCED_WRITES + L1I_OFFDRAWER_L3_SOURCED_WRITES + L1I_OFFDRAWER_L3_SOURCED_WRITES_IV + L1I_OFFDRAWER_L4_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 4 Remote cache on different book\000\000\000\000\000\00000 */
{ 90733 }, /* memp\000\000(L1D_ONCHIP_MEMORY_SOURCED_WRITES + L1D_ONCLUSTER_MEMORY_SOURCED_WRITES + L1D_OFFCLUSTER_MEMORY_SOURCED_WRITES + L1D_OFFDRAWER_MEMORY_SOURCED_WRITES + L1I_ONCHIP_MEMORY_SOURCED_WRITES + L1I_ONCLUSTER_MEMORY_SOURCED_WRITES + L1I_OFFCLUSTER_MEMORY_SOURCED_WRITES + L1I_OFFDRAWER_MEMORY_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from memory\000\000\000\000\000\00000 */
{ 87073 }, /* prbstate\000\000PROBLEM_STATE_INSTRUCTIONS / INSTRUCTIONS * 100\000\000Problem State Instruction Ratio\000\000\000\000\000\00000 */
{ 91350 }, /* scpl1m\000\000L1C_TLB2_MISSES / (L1I_DIR_WRITES + L1D_DIR_WRITES)\000\000Estimated Sourcing Cycles per Level 1 Miss\000\000\000\000\000\00000 */
{ 91637 }, /* tlb_miss\000\000(DTLB2_MISSES + ITLB2_MISSES) / (DTLB2_WRITES + ITLB2_WRITES) * (L1C_TLB2_MISSES / (L1I_PENALTY_CYCLES + L1D_PENALTY_CYCLES))\000\000Estimated Cycles per TLB Miss\000\000\000\000\000\00000 */
{ 91461 }, /* tlb_percent\000\000(DTLB2_MISSES + ITLB2_MISSES) / CPU_CYCLES * (L1C_TLB2_MISSES / (L1I_PENALTY_CYCLES + L1D_PENALTY_CYCLES)) * 100\000\000Estimated TLB CPU percentage of Total CPU\000\000\000\000\000\00000 */
{ 86887 }, /* transaction\000\000TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL\000\000Transaction count\000\000\000\000\000\00000 */

};

const struct pmu_table_entry pmu_metrics__cf_z14[] = {
{
     .entries = pmu_metrics__cf_z14_default_core,
     .num_entries = ARRAY_SIZE(pmu_metrics__cf_z14_default_core),
     .pmu_name = { 86874 /* default_core\000 */ },
},
};

static const struct compact_pmu_event pmu_events__cf_z15_cpum_cf[] = {
{ 35030 }, /* aes_blocked_cycles\000crypto6\000AES Blocked Cycle Count\000event=0x4f\000\00000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 34773 }, /* aes_blocked_functions\000crypto6\000AES Blocked Function Count\000event=0x4e\000\00000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 34588 }, /* aes_cycles\000crypto6\000AES Cycle Count\000event=0x4d\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000 */
{ 34456 }, /* aes_functions\000crypto6\000AES Function Count\000event=0x4c\000\00000\000This counter counts the total number of the AES functions issued by the CPU\000 */
{ 30364 }, /* bcd_dfp_execution_slots\000extended\000BCD DFP Execution Slots\000event=0xe0\000\00000\000Count of floating point execution slots used for finished Binary Coded Decimal to Decimal Floating Point conversions. Instructions: CDZT, CXZT, CZDT, CZXT\000 */
{ 8 }, /* cpu_cycles\000basic\000Cycle Count\000event=0\000\00000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000 */
{ 34207 }, /* dea_blocked_cycles\000crypto6\000DEA Blocked Cycle Count\000event=0x4b\000\00000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 33950 }, /* dea_blocked_functions\000crypto6\000DEA Blocked Function Count\000event=0x4a\000\00000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 33765 }, /* dea_cycles\000crypto6\000DEA Cycle Count\000event=0x49\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000 */
{ 33633 }, /* dea_functions\000crypto6\000DEA Function Count\000event=0x48\000\00000\000This counter counts the total number of the DEA functions issued by the CPU\000 */
{ 30884 }, /* decimal_instructions\000extended\000Decimal Instructions\000event=0xe2\000\00000\000Decimal instructions dispatched. Instructions: CVB, CVD, AP, CP, DP, ED, EDMK, MP, SRP, SP, ZAP\000 */
{ 36438 }, /* dflt_access\000extended\000Cycles CPU spent obtaining access to Deflate unit\000event=0xf7\000\00000\000Cycles CPU spent obtaining access to Deflate unit\000 */
{ 36676 }, /* dflt_cc\000extended\000Increments DEFLATE CONVERSION CALL\000event=0x108\000\00000\000Increments by one for every DEFLATE CONVERSION CALL instruction executed\000 */
{ 36817 }, /* dflt_ccfinish\000extended\000Increments completed DEFLATE CONVERSION CALL\000event=0x109\000\00000\000 Increments by one for every DEFLATE CONVERSION CALL instruction executed that ended in Condition Codes 0, 1 or 2 complete\000 */
{ 36574 }, /* dflt_cycles\000extended\000Cycles CPU is using Deflate unit\000event=0xfc\000\00000\000Cycles CPU is using Deflate unit\000 */
{ 22391 }, /* dtlb2_gpage_writes\000extended\000DTLB2 Two-Gigabyte Page Writes\000event=0x84\000\00000\000A translation entry for a two-gigabyte page was written into the Level-2 TLB\000 */
{ 36234 }, /* dtlb2_hpage_writes\000extended\000DTLB2 One-Megabyte Page Writes\000event=0x83\000\00000\000A translation entry was written into the Combined Region and Segment Table Entry array in the Level-2 TLB for a one-megabyte page\000 */
{ 21868 }, /* dtlb2_misses\000extended\000DTLB2 Misses\000event=0x82\000\00000\000A TLB2 miss is in progress for a request made by the data cache. Incremented by one for every TLB2 miss in progress for the Level-1 Data cache on this cycle. This is a replacement for what was provided for the DTLB on prior machines\000 */
{ 21621 }, /* dtlb2_writes\000extended\000DTLB2 Writes\000event=0x81\000\00000\000A translation has been written into The Translation Lookaside Buffer 2 (TLB2) and the request was made by the data cache. This is a replacement for what was provided for the DTLB on prior machines\000 */
{ 35952 }, /* ecc_blocked_cycles_count\000crypto6\000ECC Blocked Cycles Count\000event=0x53\000\00000\000This counter counts the total number of CPU cycles blocked for the elliptic-curve cryptography (ECC) functions issued by the CPU because the ECC coprocessor is busy performing a function issued by another CPU\000 */
{ 35664 }, /* ecc_blocked_function_count\000crypto6\000Ecc Blocked Function Count\000event=0x52\000\00000\000This counter counts the total number of the elliptic-curve cryptography (ECC) functions that are issued by the CPU and are blocked because the ECC coprocessor is busy performing a function issued by another CPU\000 */
{ 35446 }, /* ecc_cycles_count\000crypto6\000ECC Cycles Count\000event=0x51\000\00000\000This counter counts the total number of CPU cycles when the ECC coprocessor is busy performing the elliptic-curve cryptography (ECC) functions issued by the CPU\000 */
{ 35279 }, /* ecc_function_count\000crypto6\000ECC Function Count\000event=0x50\000\00000\000This counter counts the total number of the elliptic-curve cryptography (ECC) functions issued by the CPU\000 */
{ 167 }, /* instructions\000basic\000Instruction Count\000event=1\000\00000\000This counter counts the total number of instructions executed by the CPU\000 */
{ 22802 }, /* itlb2_misses\000extended\000ITLB2 Misses\000event=0x87\000\00000\000A TLB2 miss is in progress for a request made by the instruction cache. Incremented by one for every TLB2 miss in progress for the Level-1 Instruction cache in a cycle. This is a replacement for what was provided for the ITLB on prior machines\000 */
{ 22542 }, /* itlb2_writes\000extended\000ITLB2 Writes\000event=0x86\000\00000\000A translation entry has been written into the Translation Lookaside Buffer 2 (TLB2) and the request was made by the instruction cache. This is a replacement for what was provided for the ITLB on prior machines\000 */
{ 23555 }, /* l1c_tlb2_misses\000extended\000L1C TLB2 Misses\000event=0x8f\000\00000\000Increments by one for any cycle where a level-1 cache or level-2 TLB miss is in progress\000 */
{ 641 }, /* l1d_dir_writes\000basic\000Level-1 D-Cache Directory Write Count\000event=4\000\00000\000This counter counts the total number of level-1 data-cache directory writes\000 */
{ 10216 }, /* l1d_l2d_sourced_writes\000extended\000L1D L2D Sourced Writes\000event=0x85\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache\000 */
{ 24867 }, /* l1d_offcluster_l3_sourced_writes\000extended\000L1D Off-Cluster L3 Sourced Writes\000event=0x96\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention\000 */
{ 25328 }, /* l1d_offcluster_l3_sourced_writes_iv\000extended\000L1D Off-Cluster L3 Sourced Writes with Intervention\000event=0x98\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention\000 */
{ 25109 }, /* l1d_offcluster_memory_sourced_writes\000extended\000L1D Off-Cluster Memory Sourced Writes\000event=0x97\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Cluster memory\000 */
{ 25588 }, /* l1d_offdrawer_l3_sourced_writes\000extended\000L1D Off-Drawer L3 Sourced Writes\000event=0x99\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention\000 */
{ 26043 }, /* l1d_offdrawer_l3_sourced_writes_iv\000extended\000L1D Off-Drawer L3 Sourced Writes with Intervention\000event=0x9b\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention\000 */
{ 26512 }, /* l1d_offdrawer_l4_sourced_writes\000extended\000L1D Off-Drawer L4 Sourced Writes\000event=0x9d\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache\000 */
{ 25827 }, /* l1d_offdrawer_memory_sourced_writes\000extended\000L1D Off-Drawer Memory Sourced Writes\000event=0x9a\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory\000 */
{ 11927 }, /* l1d_onchip_l3_sourced_writes\000extended\000L1D On-Chip L3 Sourced Writes\000event=0x90\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache without intervention\000 */
{ 23907 }, /* l1d_onchip_l3_sourced_writes_iv\000extended\000L1D On-Chip L3 Sourced Writes with Intervention\000event=0x92\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-3 cache with intervention\000 */
{ 26727 }, /* l1d_onchip_l3_sourced_writes_ro\000extended\000L1D On-Chip L3 Sourced Writes read-only\000event=0x9e\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip L3 but a read-only invalidate was done to remove other copies of the cache line\000 */
{ 23700 }, /* l1d_onchip_memory_sourced_writes\000extended\000L1D On-Chip Memory Sourced Writes\000event=0x91\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory\000 */
{ 24155 }, /* l1d_oncluster_l3_sourced_writes\000extended\000L1D On-Cluster L3 Sourced Writes\000event=0x93\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Cluster Level-3 cache without intervention\000 */
{ 24610 }, /* l1d_oncluster_l3_sourced_writes_iv\000extended\000L1D On-Cluster L3 Sourced Writes with Intervention\000event=0x95\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache with intervention\000 */
{ 24391 }, /* l1d_oncluster_memory_sourced_writes\000extended\000L1D On-Cluster Memory Sourced Writes\000event=0x94\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Cluster memory\000 */
{ 26300 }, /* l1d_ondrawer_l4_sourced_writes\000extended\000L1D On-Drawer L4 Sourced Writes\000event=0x9c\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer Level-4 cache\000 */
{ 788 }, /* l1d_penalty_cycles\000basic\000Level-1 D-Cache Penalty Cycle Count\000event=5\000\00000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000 */
{ 9287 }, /* l1d_ro_excl_writes\000extended\000L1D Read-only Exclusive Writes\000event=0x80\000\00000\000A directory write to the Level-1 Data cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000 */
{ 289 }, /* l1i_dir_writes\000basic\000Level-1 I-Cache Directory Write Count\000event=2\000\00000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000 */
{ 10717 }, /* l1i_l2i_sourced_writes\000extended\000L1I L2I Sourced Writes\000event=0x88\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000 */
{ 28448 }, /* l1i_offcluster_l3_sourced_writes\000extended\000L1I Off-Cluster L3 Sourced Writes\000event=0xa8\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache without intervention\000 */
{ 28923 }, /* l1i_offcluster_l3_sourced_writes_iv\000extended\000L1I Off-Cluster L3 Sourced Writes with Intervention\000event=0xaa\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Cluster Level-3 cache with intervention\000 */
{ 28697 }, /* l1i_offcluster_memory_sourced_writes\000extended\000L1I Off-Cluster Memory Sourced Writes\000event=0xa9\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Cluster memory\000 */
{ 29190 }, /* l1i_offdrawer_l3_sourced_writes\000extended\000L1I Off-Drawer L3 Sourced Writes\000event=0xab\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache without intervention\000 */
{ 29659 }, /* l1i_offdrawer_l3_sourced_writes_iv\000extended\000L1I Off-Drawer L3 Sourced Writes with Intervention\000event=0xad\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-3 cache with intervention\000 */
{ 30142 }, /* l1i_offdrawer_l4_sourced_writes\000extended\000L1I Off-Drawer L4 Sourced Writes\000event=0xaf\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer Level-4 cache\000 */
{ 29436 }, /* l1i_offdrawer_memory_sourced_writes\000extended\000L1I Off-Drawer Memory Sourced Writes\000event=0xac\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer memory\000 */
{ 27012 }, /* l1i_onchip_l3_sourced_writes\000extended\000L1I On-Chip L3 Sourced Writes\000event=0xa2\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache without intervention\000 */
{ 27461 }, /* l1i_onchip_l3_sourced_writes_iv\000extended\000L1I On-Chip L3 Sourced Writes with Intervention\000event=0xa4\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from an On-Chip Level-3 cache with intervention\000 */
{ 27248 }, /* l1i_onchip_memory_sourced_writes\000extended\000L1I On-Chip Memory Sourced Writes\000event=0xa3\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache ine was sourced from On-Chip memory\000 */
{ 27715 }, /* l1i_oncluster_l3_sourced_writes\000extended\000L1I On-Cluster L3 Sourced Writes\000event=0xa5\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster Level-3 cache without intervention\000 */
{ 28187 }, /* l1i_oncluster_l3_sourced_writes_iv\000extended\000L1I On-Cluster L3 Sourced Writes with Intervention\000event=0xa7\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Cluster Level-3 cache with intervention\000 */
{ 27961 }, /* l1i_oncluster_memory_sourced_writes\000extended\000L1I On-Cluster Memory Sourced Writes\000event=0xa6\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Cluster memory\000 */
{ 29923 }, /* l1i_ondrawer_l4_sourced_writes\000extended\000L1I On-Drawer L4 Sourced Writes\000event=0xae\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer Level-4 cache\000 */
{ 460 }, /* l1i_penalty_cycles\000basic\000Level-1 I-Cache Penalty Cycle Count\000event=3\000\00000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000 */
{ 31046 }, /* last_host_translations\000extended\000Last host translation done\000event=0xe8\000\00000\000Last Host Translation done\000 */
{ 21369 }, /* mt_diag_cycles_one_thr_active\000extended\000Cycle count with one thread active\000event=0x1c0\000\00000\000Cycle count with one thread active\000 */
{ 21494 }, /* mt_diag_cycles_two_thr_active\000extended\000Cycle count with two threads active\000event=0x1c1\000\00000\000Cycle count with two threads active\000 */
{ 32540 }, /* prng_blocked_cycles\000crypto6\000PRNG Blocked Cycle Count\000event=0x43\000\00000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 32250 }, /* prng_blocked_functions\000crypto6\000PRNG Blocked Function Count\000event=0x42\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 32031 }, /* prng_cycles\000crypto6\000PRNG Cycle Count\000event=0x41\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000 */
{ 31870 }, /* prng_functions\000crypto6\000PRNG Function Count\000event=0x40\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000 */
{ 945 }, /* problem_state_cpu_cycles\000basic\000Problem-State Cycle Count\000event=0x20\000\00000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000 */
{ 1172 }, /* problem_state_instructions\000basic\000Problem-State Instruction Count\000event=0x21\000\00000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000 */
{ 33388 }, /* sha_blocked_cycles\000crypto6\000SHA Blocked Cycle Count\000event=0x47\000\00000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 33135 }, /* sha_blocked_functions\000crypto6\000SHA Blocked Function Count\000event=0x46\000\00000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 32954 }, /* sha_cycles\000crypto6\000SHA Cycle Count\000event=0x45\000\00000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000 */
{ 32822 }, /* sha_functions\000crypto6\000SHA Function Count\000event=0x44\000\00000\000This counter counts the total number of the SHA functions issued by the CPU\000 */
{ 23235 }, /* tlb2_crste_writes\000extended\000TLB2 CRSTE Writes\000event=0x8a\000\00000\000Translation entries were written into the Combined Region and Segment Table Entry array and the Page Table Entry array in the Level-2 TLB\000 */
{ 23433 }, /* tlb2_engines_busy\000extended\000TLB2 Engines Busy\000event=0x8b\000\00000\000The number of Level-2 TLB translation engines busy in a cycle\000 */
{ 23096 }, /* tlb2_pte_writes\000extended\000TLB2 PTE Writes\000event=0x89\000\00000\000A translation entry was written into the Page Table Entry array in the Level-2 TLB\000 */
{ 31315 }, /* tx_c_tabort_no_special\000extended\000Aborted transactions in constrained TX mode not using special completion logic\000event=0xf4\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000 */
{ 31600 }, /* tx_c_tabort_special\000extended\000Aborted transactions in constrained TX mode using special completion logic\000event=0xf5\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000 */
{ 11445 }, /* tx_c_tend\000extended\000Completed TEND instructions in constrained TX mode\000event=0x8c\000\00000\000A TEND instruction has completed in a constrained transactional-execution mode\000 */
{ 31147 }, /* tx_nc_tabort\000extended\000Aborted transactions in non-constrained TX mode\000event=0xf3\000\00000\000A transaction abort has occurred in a non-constrained transactional-execution mode\000 */
{ 11609 }, /* tx_nc_tend\000extended\000Completed TEND instructions in non-constrained TX mode\000event=0x8d\000\00000\000A TEND instruction has completed in a non-constrained transactional-execution mode\000 */
{ 30591 }, /* vx_bcd_execution_slots\000extended\000VX BCD Execution Slots\000event=0xe1\000\00000\000Count of floating point execution slots used for finished vector arithmetic Binary Coded Decimal instructions. Instructions: VAP, VSP, VMPVMSP, VDP, VSDP, VRP, VLIP, VSRP, VPSOPVCP, VTP, VPKZ, VUPKZ, VCVB, VCVBG, VCVDVCVDG\000 */

};

const struct pmu_table_entry pmu_events__cf_z15[] = {
{
     .entries = pmu_events__cf_z15_cpum_cf,
     .num_entries = ARRAY_SIZE(pmu_events__cf_z15_cpum_cf),
     .pmu_name = { 0 /* cpum_cf\000 */ },
},
};

static const struct compact_pmu_event pmu_metrics__cf_z15_default_core[] = {
{ 87011 }, /* cpi\000\000CPU_CYCLES / INSTRUCTIONS\000\000Cycles per Instruction\000\000\000\000\000\00000 */
{ 91220 }, /* est_cpi\000\000CPU_CYCLES / INSTRUCTIONS - L1C_TLB2_MISSES / INSTRUCTIONS\000\000Estimated Instruction Complexity CPI infinite Level 1\000\000\000\000\000\00000 */
{ 91120 }, /* finite_cpi\000\000L1C_TLB2_MISSES / INSTRUCTIONS\000\000Cycles per Instructions from Finite cache/memory\000\000\000\000\000\00000 */
{ 87171 }, /* l1mp\000\000(L1I_DIR_WRITES + L1D_DIR_WRITES) / INSTRUCTIONS * 100\000\000Level One Miss per 100 Instructions\000\000\000\000\000\00000 */
{ 87276 }, /* l2p\000\000(L1D_L2D_SOURCED_WRITES + L1I_L2I_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 2 cache\000\000\000\000\000\00000 */
{ 87419 }, /* l3p\000\000(L1D_ONCHIP_L3_SOURCED_WRITES + L1D_ONCHIP_L3_SOURCED_WRITES_IV + L1I_ONCHIP_L3_SOURCED_WRITES + L1I_ONCHIP_L3_SOURCED_WRITES_IV) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 3 on same chip cache\000\000\000\000\000\00000 */
{ 89903 }, /* l4lp\000\000(L1D_ONCLUSTER_L3_SOURCED_WRITES + L1D_ONCLUSTER_L3_SOURCED_WRITES_IV + L1D_ONDRAWER_L4_SOURCED_WRITES + L1I_ONCLUSTER_L3_SOURCED_WRITES + L1I_ONCLUSTER_L3_SOURCED_WRITES_IV + L1I_ONDRAWER_L4_SOURCED_WRITES + L1D_OFFCLUSTER_L3_SOURCED_WRITES + L1D_OFFCLUSTER_L3_SOURCED_WRITES_IV + L1D_ONCHIP_L3_SOURCED_WRITES_RO + L1I_OFFCLUSTER_L3_SOURCED_WRITES + L1I_OFFCLUSTER_L3_SOURCED_WRITES_IV) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 4 Local cache on same book\000\000\000\000\000\00000 */
{ 90404 }, /* l4rp\000\000(L1D_OFFDRAWER_L3_SOURCED_WRITES + L1D_OFFDRAWER_L3_SOURCED_WRITES_IV + L1D_OFFDRAWER_L4_SOURCED_WRITES + L1I_OFFDRAWER_L3_SOURCED_WRITES + L1I_OFFDRAWER_L3_SOURCED_WRITES_IV + L1I_OFFDRAWER_L4_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 4 Remote cache on different book\000\000\000\000\000\00000 */
{ 90733 }, /* memp\000\000(L1D_ONCHIP_MEMORY_SOURCED_WRITES + L1D_ONCLUSTER_MEMORY_SOURCED_WRITES + L1D_OFFCLUSTER_MEMORY_SOURCED_WRITES + L1D_OFFDRAWER_MEMORY_SOURCED_WRITES + L1I_ONCHIP_MEMORY_SOURCED_WRITES + L1I_ONCLUSTER_MEMORY_SOURCED_WRITES + L1I_OFFCLUSTER_MEMORY_SOURCED_WRITES + L1I_OFFDRAWER_MEMORY_SOURCED_WRITES) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from memory\000\000\000\000\000\00000 */
{ 87073 }, /* prbstate\000\000PROBLEM_STATE_INSTRUCTIONS / INSTRUCTIONS * 100\000\000Problem State Instruction Ratio\000\000\000\000\000\00000 */
{ 91350 }, /* scpl1m\000\000L1C_TLB2_MISSES / (L1I_DIR_WRITES + L1D_DIR_WRITES)\000\000Estimated Sourcing Cycles per Level 1 Miss\000\000\000\000\000\00000 */
{ 91637 }, /* tlb_miss\000\000(DTLB2_MISSES + ITLB2_MISSES) / (DTLB2_WRITES + ITLB2_WRITES) * (L1C_TLB2_MISSES / (L1I_PENALTY_CYCLES + L1D_PENALTY_CYCLES))\000\000Estimated Cycles per TLB Miss\000\000\000\000\000\00000 */
{ 91461 }, /* tlb_percent\000\000(DTLB2_MISSES + ITLB2_MISSES) / CPU_CYCLES * (L1C_TLB2_MISSES / (L1I_PENALTY_CYCLES + L1D_PENALTY_CYCLES)) * 100\000\000Estimated TLB CPU percentage of Total CPU\000\000\000\000\000\00000 */
{ 86887 }, /* transaction\000\000TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL\000\000Transaction count\000\000\000\000\000\00000 */

};

const struct pmu_table_entry pmu_metrics__cf_z15[] = {
{
     .entries = pmu_metrics__cf_z15_default_core,
     .num_entries = ARRAY_SIZE(pmu_metrics__cf_z15_default_core),
     .pmu_name = { 86874 /* default_core\000 */ },
},
};

static const struct compact_pmu_event pmu_events__cf_z16_cpum_cf[] = {
{ 35030 }, /* aes_blocked_cycles\000crypto6\000AES Blocked Cycle Count\000event=0x4f\000\00000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 34773 }, /* aes_blocked_functions\000crypto6\000AES Blocked Function Count\000event=0x4e\000\00000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 34588 }, /* aes_cycles\000crypto6\000AES Cycle Count\000event=0x4d\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000 */
{ 34456 }, /* aes_functions\000crypto6\000AES Function Count\000event=0x4c\000\00000\000This counter counts the total number of the AES functions issued by the CPU\000 */
{ 49323 }, /* bcd_dfp_execution_slots\000extended\000Binary Coded Decimal to Decimal Floating Point conversions\000event=0xe0\000\00000\000Count of floating point execution slots used for finished Binary Coded Decimal to Decimal Floating Point conversions. Instructions: CDZT, CXZT, CZDT, CZXT\000 */
{ 8 }, /* cpu_cycles\000basic\000Cycle Count\000event=0\000\00000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000 */
{ 37586 }, /* crste_1mb_writes\000extended\000One Megabyte CRSTE writes\000event=0x83\000\00000\000A translation entry was written into the Combined Region and Segment Table Entry array in the Level-2 TLB for a one-megabyte page\000 */
{ 41337 }, /* dcw_off_drawer\000extended\000Directory Write Level 1 Data Cache from Off-Drawer L2-Cache\000event=0x9b\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache\000 */
{ 42219 }, /* dcw_off_drawer_memory\000extended\000Directory Write Level 1 Data Cache from Off-Drawer Memory\000event=0x9f\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from Off-Drawer memory\000 */
{ 39800 }, /* dcw_on_chip\000extended\000Directory Write Level 1 Data Cache from On-Chip L2-Cache\000event=0x95\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache\000 */
{ 40277 }, /* dcw_on_chip_chip_hit\000extended\000Directory Write Level 1 Data Cache from On-Chip L2-Cache with Chip HP Hit\000event=0x97\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache after using chip level horizontal persistence, Chip-HP hit\000 */
{ 40581 }, /* dcw_on_chip_drawer_hit\000extended\000Directory Write Level 1 Data Cache from On-Chip L2-Cache with Drawer HP Hit\000event=0x98\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000 */
{ 40019 }, /* dcw_on_chip_iv\000extended\000Directory Write Level 1 Data Cache from On-Chip L2-Cache with Intervention\000event=0x96\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Chip Level-2 cache with intervention\000 */
{ 41565 }, /* dcw_on_chip_memory\000extended\000Directory Write Level 1 Data Cache from On-Chip Memory\000event=0x9c\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Chip memory\000 */
{ 41112 }, /* dcw_on_drawer\000extended\000Directory Write Level 1 Data Cache from On-Drawer L2-Cache\000event=0x9a\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache\000 */
{ 41999 }, /* dcw_on_drawer_memory\000extended\000Directory Write Level 1 Data Cache from On-Drawer Memory\000event=0x9e\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Drawer memory\000 */
{ 40887 }, /* dcw_on_module\000extended\000Directory Write Level 1 Data Cache from On-Module L2-Cache\000event=0x99\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On-Module Level-2 cache\000 */
{ 41779 }, /* dcw_on_module_memory\000extended\000Directory Write Level 1 Data Cache from On-Module Memory\000event=0x9d\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from On-Module memory\000 */
{ 38739 }, /* dcw_req\000extended\000Directory Write Level 1 Data Cache from L2-Cache\000event=0x91\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestors Level-2 cache\000 */
{ 39200 }, /* dcw_req_chip_hit\000extended\000Directory Write Level 1 Data Cache from L2-Cache with Chip HP Hit\000event=0x93\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestors Level-2 cache after using chip level horizontal persistence, Chip-HP hit\000 */
{ 39496 }, /* dcw_req_drawer_hit\000extended\000Directory Write Level 1 Data Cache from L2-Cache with Drawer HP Hit\000event=0x94\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestors Level-2 cache after using drawer level horizontal persistence, Drawer-HP hit\000 */
{ 38950 }, /* dcw_req_iv\000extended\000Directory Write Level 1 Data Cache from L2-Cache with Intervention\000event=0x92\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the requestors Level-2 cache with intervention\000 */
{ 34207 }, /* dea_blocked_cycles\000crypto6\000DEA Blocked Cycle Count\000event=0x4b\000\00000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 33950 }, /* dea_blocked_functions\000crypto6\000DEA Blocked Function Count\000event=0x4a\000\00000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 33765 }, /* dea_cycles\000crypto6\000DEA Cycle Count\000event=0x49\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000 */
{ 33633 }, /* dea_functions\000crypto6\000DEA Function Count\000event=0x48\000\00000\000This counter counts the total number of the DEA functions issued by the CPU\000 */
{ 49928 }, /* decimal_instructions\000extended\000Decimal instruction dispatched\000event=0xe2\000\00000\000Decimal instruction dispatched. Instructions: CVB, CVD, AP, CP, DP, ED, EDMK, MP, SRP, SP, ZAP\000 */
{ 50785 }, /* dflt_access\000extended\000Cycles CPU spent obtaining access to Deflate unit\000event=0xf8\000\00000\000Cycles CPU spent obtaining access to Deflate unit\000 */
{ 51139 }, /* dflt_cc\000extended\000Increments DEFLATE CONVERSION CALL\000event=0x109\000\00000\000Increments by one for every DEFLATE CONVERSION CALL instruction executed\000 */
{ 51280 }, /* dflt_ccfinish\000extended\000Increments completed DEFLATE CONVERSION CALL\000event=0x10a\000\00000\000Increments by one for every DEFLATE CONVERSION CALL instruction executed that ended in Condition Codes 0, 1 or 2\000 */
{ 50921 }, /* dflt_cycles\000extended\000Cycles CPU is using Deflate unit\000event=0xfd\000\00000\000Cycles CPU is using Deflate unit\000 */
{ 22391 }, /* dtlb2_gpage_writes\000extended\000DTLB2 Two-Gigabyte Page Writes\000event=0x84\000\00000\000A translation entry for a two-gigabyte page was written into the Level-2 TLB\000 */
{ 37287 }, /* dtlb2_misses\000extended\000DTLB2 Misses\000event=0x82\000\00000\000A TLB2 miss is in progress for a request made by the Level-1 Data cache. Incremented by one for every TLB2 miss in progress for the Level-1 Data cache on this cycle. This is a replacement for what was provided for the DTLB on z13 and prior machines\000 */
{ 37024 }, /* dtlb2_writes\000extended\000DTLB2 Writes\000event=0x81\000\00000\000A translation has been written into The Translation Lookaside Buffer 2 (TLB2) and the request was made by the Level-1 Data cache. This is a replacement for what was provided for the DTLB on z13 and prior machines\000 */
{ 35952 }, /* ecc_blocked_cycles_count\000crypto6\000ECC Blocked Cycles Count\000event=0x53\000\00000\000This counter counts the total number of CPU cycles blocked for the elliptic-curve cryptography (ECC) functions issued by the CPU because the ECC coprocessor is busy performing a function issued by another CPU\000 */
{ 35664 }, /* ecc_blocked_function_count\000crypto6\000Ecc Blocked Function Count\000event=0x52\000\00000\000This counter counts the total number of the elliptic-curve cryptography (ECC) functions that are issued by the CPU and are blocked because the ECC coprocessor is busy performing a function issued by another CPU\000 */
{ 35446 }, /* ecc_cycles_count\000crypto6\000ECC Cycles Count\000event=0x51\000\00000\000This counter counts the total number of CPU cycles when the ECC coprocessor is busy performing the elliptic-curve cryptography (ECC) functions issued by the CPU\000 */
{ 35279 }, /* ecc_function_count\000crypto6\000ECC Function Count\000event=0x50\000\00000\000This counter counts the total number of the elliptic-curve cryptography (ECC) functions issued by the CPU\000 */
{ 48153 }, /* icw_off_drawer\000extended\000Directory Write Level 1 Instruction Cache from Off-Drawer L2-Cache\000event=0xb3\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced an Off-Drawer Level-2 cache\000 */
{ 49086 }, /* icw_off_drawer_memory\000extended\000Directory Write Level 1 Instruction Cache from Off-Drawer Memory\000event=0xb7\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from Off-Drawer memory\000 */
{ 46548 }, /* icw_on_chip\000extended\000Directory Write Level 1 Instruction Cache from On-Chip L2-Cache\000event=0xad\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip Level-2 cache\000 */
{ 47048 }, /* icw_on_chip_chip_hit\000extended\000Directory Write Level 1 Instruction Cache from On-Chip L2-Cache with Chip HP Hit\000event=0xaf\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip Level-2 cache using chip level horizontal persistence, Chip-HP hit\000 */
{ 47360 }, /* icw_on_chip_drawer_hit\000extended\000Directory Write Level 1 Instruction Cache from On-Chip L2-Cache with Drawer HP Hit\000event=0xb0\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Chip level 2 cache using drawer level horizontal persistence, Drawer-HP hit\000 */
{ 46781 }, /* icw_on_chip_iv\000extended\000Directory Write Level 1 Instruction Cache from On-Chip L2-Cache with Intervention\000event=0xae\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced an On-Chip Level-2 cache with intervention\000 */
{ 48390 }, /* icw_on_chip_memory\000extended\000Directory Write Level 1 Instruction Cache from On-Chip Memory\000event=0xb4\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Chip memory\000 */
{ 47919 }, /* icw_on_drawer\000extended\000Directory Write Level 1 Instruction Cache from On-Drawer L2-Cache\000event=0xb2\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced an On-Drawer Level-2 cache\000 */
{ 48852 }, /* icw_on_drawer_memory\000extended\000Directory Write Level 1 Instruction Cache from On-Drawer Memory\000event=0xb6\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Drawer memory\000 */
{ 47680 }, /* icw_on_module\000extended\000Directory Write Level 1 Instruction Cache from On-Module L2-Cache\000event=0xb1\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache\000 */
{ 48618 }, /* icw_on_module_memory\000extended\000Directory Write Level 1 Instruction Cache from On-Module Memory\000event=0xb5\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from On-Module memory\000 */
{ 45448 }, /* icw_req\000extended\000Directory Write Level 1 Instruction Cache from L2-Cache\000event=0xa9\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced the requestors Level-2 cache\000 */
{ 45932 }, /* icw_req_chip_hit\000extended\000Directory Write Level 1 Instruction Cache from L2-Cache with Chip HP Hit\000event=0xab\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the requestors Level-2 cache using chip level horizontal persistence, Chip-HP hit\000 */
{ 46236 }, /* icw_req_drawer_hit\000extended\000Directory Write Level 1 Instruction Cache from L2-Cache with Drawer HP Hit\000event=0xac\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the requestors Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000 */
{ 45668 }, /* icw_req_iv\000extended\000Directory Write Level 1 Instruction Cache from L2-Cache with Intervention\000event=0xaa\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the requestors Level-2 cache with intervention\000 */
{ 44752 }, /* idcw_off_drawer_chip_hit\000extended\000Directory Write Level 1 Instruction and Data Cache from Off-Drawer L2-Cache with Chip Hit\000event=0xa7\000\00000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache using chip level horizontal persistence, Chip-HP hit\000 */
{ 45096 }, /* idcw_off_drawer_drawer_hit\000extended\000Directory Write Level 1 Instruction and Data Cache from Off-Drawer L2-Cache with Drawer Hit\000event=0xa8\000\00000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000 */
{ 44445 }, /* idcw_off_drawer_iv\000extended\000Directory Write Level 1 Instruction and Data Cache from Off-Drawer L2-Cache with Intervention\000event=0xa6\000\00000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an Off-Drawer Level-2 cache with intervention\000 */
{ 43755 }, /* idcw_on_drawer_chip_hit\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Drawer L2-Cache with Chip Hit\000event=0xa4\000\00000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache using chip level horizontal persistence, Chip-HP hit\000 */
{ 44096 }, /* idcw_on_drawer_drawer_hit\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Drawer L2-Cache with Drawer Hit\000event=0xa5\000\00000\000A directory write to the Level-1 Data or Level-1 instruction cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000 */
{ 43451 }, /* idcw_on_drawer_iv\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Drawer L2-Cache with Intervention\000event=0xa3\000\00000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Drawer Level-2 cache with intervention\000 */
{ 42753 }, /* idcw_on_module_chip_hit\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Module Memory L2-Cache with Chip Hit\000event=0xa1\000\00000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache using chip horizontal persistence, Chip-HP hit\000 */
{ 43095 }, /* idcw_on_module_drawer_hit\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Module Memory L2-Cache with Drawer Hit\000event=0xa2\000\00000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache using drawer level horizontal persistence, Drawer-HP hit\000 */
{ 42442 }, /* idcw_on_module_iv\000extended\000Directory Write Level 1 Instruction and Data Cache from On-Module Memory L2-Cache with Intervention\000event=0xa0\000\00000\000A directory write to the Level-1 Data or Level-1 Instruction cache directory where the returned cache line was sourced from an On-Module Level-2 cache with intervention\000 */
{ 167 }, /* instructions\000basic\000Instruction Count\000event=1\000\00000\000This counter counts the total number of instructions executed by the CPU\000 */
{ 38051 }, /* itlb2_misses\000extended\000ITLB2 Misses\000event=0x87\000\00000\000A TLB2 miss is in progress for a request made by the Level-1 Instruction cache. Incremented by one for every TLB2 miss in progress for the Level-1 Instruction cache in a cycle. This is a replacement for what was provided for the ITLB on z13 and prior machines\000 */
{ 37783 }, /* itlb2_writes\000extended\000ITLB2 Writes\000event=0x86\000\00000\000A translation entry has been written into the Translation Lookaside Buffer 2 (TLB2) and the request was made by the instruction cache. This is a replacement for what was provided for the ITLB on z13 and prior machines\000 */
{ 23555 }, /* l1c_tlb2_misses\000extended\000L1C TLB2 Misses\000event=0x8f\000\00000\000Increments by one for any cycle where a level-1 cache or level-2 TLB miss is in progress\000 */
{ 641 }, /* l1d_dir_writes\000basic\000Level-1 D-Cache Directory Write Count\000event=4\000\00000\000This counter counts the total number of level-1 data-cache directory writes\000 */
{ 788 }, /* l1d_penalty_cycles\000basic\000Level-1 D-Cache Penalty Cycle Count\000event=5\000\00000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000 */
{ 9287 }, /* l1d_ro_excl_writes\000extended\000L1D Read-only Exclusive Writes\000event=0x80\000\00000\000A directory write to the Level-1 Data cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000 */
{ 289 }, /* l1i_dir_writes\000basic\000Level-1 I-Cache Directory Write Count\000event=2\000\00000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000 */
{ 460 }, /* l1i_penalty_cycles\000basic\000Level-1 I-Cache Penalty Cycle Count\000event=3\000\00000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000 */
{ 31046 }, /* last_host_translations\000extended\000Last host translation done\000event=0xe8\000\00000\000Last Host Translation done\000 */
{ 21369 }, /* mt_diag_cycles_one_thr_active\000extended\000Cycle count with one thread active\000event=0x1c0\000\00000\000Cycle count with one thread active\000 */
{ 21494 }, /* mt_diag_cycles_two_thr_active\000extended\000Cycle count with two threads active\000event=0x1c1\000\00000\000Cycle count with two threads active\000 */
{ 51624 }, /* nnpa_completions\000extended\000NNPA Total completions\000event=0x10c\000\00000\000Increments by one for every Neural Network Processing Assist instruction executed that ended in Condition Codes 0, 1 or 2\000 */
{ 51957 }, /* nnpa_hold_lock\000extended\000Cycles spent holding NNPA lock\000event=0x10e\000\00000\000Cycles CPU is using IBM Z Integrated Accelerator for AI\000 */
{ 51477 }, /* nnpa_invocations\000extended\000NNPA Total invocations\000event=0x10b\000\00000\000Increments by one for every Neural Network Processing Assist instruction executed\000 */
{ 51811 }, /* nnpa_wait_lock\000extended\000Cycles spent obtaining NNPA lock\000event=0x10d\000\00000\000Cycles CPU spent obtaining access to IBM Z Integrated Accelerator for AI\000 */
{ 32540 }, /* prng_blocked_cycles\000crypto6\000PRNG Blocked Cycle Count\000event=0x43\000\00000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 32250 }, /* prng_blocked_functions\000crypto6\000PRNG Blocked Function Count\000event=0x42\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 32031 }, /* prng_cycles\000crypto6\000PRNG Cycle Count\000event=0x41\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000 */
{ 31870 }, /* prng_functions\000crypto6\000PRNG Function Count\000event=0x40\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000 */
{ 945 }, /* problem_state_cpu_cycles\000basic\000Problem-State Cycle Count\000event=0x20\000\00000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000 */
{ 1172 }, /* problem_state_instructions\000basic\000Problem-State Instruction Count\000event=0x21\000\00000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000 */
{ 33388 }, /* sha_blocked_cycles\000crypto6\000SHA Blocked Cycle Count\000event=0x47\000\00000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 33135 }, /* sha_blocked_functions\000crypto6\000SHA Blocked Function Count\000event=0x46\000\00000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 32954 }, /* sha_cycles\000crypto6\000SHA Cycle Count\000event=0x45\000\00000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000 */
{ 32822 }, /* sha_functions\000crypto6\000SHA Function Count\000event=0x44\000\00000\000This counter counts the total number of the SHA functions issued by the CPU\000 */
{ 51023 }, /* sortl\000extended\000Count SORTL instructions\000event=0x100\000\00000\000Increments by one for every SORT LISTS instruction executed\000 */
{ 38513 }, /* tlb2_crste_writes\000extended\000TLB2 Combined Region and Segment Entry Writes\000event=0x8a\000\00000\000Translation entries were written into the Combined Region and Segment Table Entry array and the Page Table Entry array in the Level-2 TLB\000 */
{ 23433 }, /* tlb2_engines_busy\000extended\000TLB2 Engines Busy\000event=0x8b\000\00000\000The number of Level-2 TLB translation engines busy in a cycle\000 */
{ 38361 }, /* tlb2_pte_writes\000extended\000TLB2 Page Table Entry Writes\000event=0x89\000\00000\000A translation entry was written into the Page Table Entry array in the Level-2 TLB\000 */
{ 50265 }, /* tx_c_tabort_no_special\000extended\000Aborted transactions in constrained TX mode\000event=0xf5\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000 */
{ 50515 }, /* tx_c_tabort_special\000extended\000Aborted transactions in constrained TX mode using special completion logic\000event=0xf6\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000 */
{ 11445 }, /* tx_c_tend\000extended\000Completed TEND instructions in constrained TX mode\000event=0x8c\000\00000\000A TEND instruction has completed in a constrained transactional-execution mode\000 */
{ 50099 }, /* tx_nc_tabort\000extended\000Aborted transactions in unconstrained TX mode\000event=0xf4\000\00000\000A transaction abort has occurred in a non-constrained transactional-execution mode\000 */
{ 11609 }, /* tx_nc_tend\000extended\000Completed TEND instructions in non-constrained TX mode\000event=0x8d\000\00000\000A TEND instruction has completed in a non-constrained transactional-execution mode\000 */
{ 49585 }, /* vx_bcd_execution_slots\000extended\000Count finished vector arithmetic Binary Coded Decimal instructions\000event=0xe1\000\00000\000Count of floating point execution slots used for finished vector arithmetic Binary Coded Decimal instructions. Instructions: VAP, VSP, VMP, VMSP, VDP, VSDP, VRP, VLIP, VSRP, VPSOP, VCP, VTP, VPKZ, VUPKZ, VCVB, VCVBG, VCVD, VCVDG\000 */
};
static const struct compact_pmu_event pmu_events__cf_z16_pai_crypto[] = {
{ 52095 }, /* crypto_all\000pai_crypto\000CRYPTO ALL\000event=0x1000\000\00000\000Sums of all non zero cryptography counters\000 */
{ 70463 }, /* ibm_reserved_155\000pai_crypto\000IBM RESERVED_155\000event=0x109b\000\00000\000Reserved for IBM use\000 */
{ 70546 }, /* ibm_reserved_156\000pai_crypto\000IBM RESERVED_156\000event=0x109c\000\00000\000Reserved for IBM use\000 */
{ 67559 }, /* kdsa_ecdsa_sign_p256\000pai_crypto\000KDSA ECDSA SIGN P256\000event=0x1084\000\00000\000KDSA-ECDSA-Sign-P256 function ending with CC=0\000 */
{ 67676 }, /* kdsa_ecdsa_sign_p384\000pai_crypto\000KDSA ECDSA SIGN P384\000event=0x1085\000\00000\000KDSA-ECDSA-Sign-P384 function ending with CC=0\000 */
{ 67793 }, /* kdsa_ecdsa_sign_p521\000pai_crypto\000KDSA ECDSA SIGN P521\000event=0x1086\000\00000\000KDSA-ECDSA-Sign-P521 function ending with CC=0\000 */
{ 67166 }, /* kdsa_ecdsa_verify_p256\000pai_crypto\000KDSA ECDSA VERIFY P256\000event=0x1081\000\00000\000KDSA-ECDSA-Verify-P256 function ending with CC=0 or CC=2\000 */
{ 67297 }, /* kdsa_ecdsa_verify_p384\000pai_crypto\000KDSA ECDSA VERIFY P384\000event=0x1082\000\00000\000KDSA-ECDSA-Verify-P384 function ending with CC=0 or CC=2\000 */
{ 67428 }, /* kdsa_ecdsa_verify_p521\000pai_crypto\000KDSA ECDSA VERIFY P521\000event=0x1083\000\00000\000KDSA-ECDSA-Verify-P521 function ending with CC=0 or CC=2\000 */
{ 68625 }, /* kdsa_eddsa_sign_ed25519\000pai_crypto\000KDSA EDDSA SIGN ED25519\000event=0x108c\000\00000\000KDSA-EdDSA-Sign-Ed25519 function ending with CC=0\000 */
{ 68751 }, /* kdsa_eddsa_sign_ed448\000pai_crypto\000KDSA EDDSA SIGN ED448\000event=0x108d\000\00000\000KDSA-EdDSA-Sign-Ed448 function ending with CC=0\000 */
{ 68351 }, /* kdsa_eddsa_verify_ed25519\000pai_crypto\000KDSA EDDSA VERIFY ED25519\000event=0x108a\000\00000\000KDSA-EdDSA-Verify-Ed25519 function ending with CC=0 or CC=2\000 */
{ 68491 }, /* kdsa_eddsa_verify_ed448\000pai_crypto\000KDSA EDDSA VERIFY ED448\000event=0x108b\000\00000\000KDSA-EdDSA-Verify-Ed448 function ending with CC=0 or CC=2\000 */
{ 67910 }, /* kdsa_encrypted_ecdsa_sign_p256\000pai_crypto\000KDSA ENCRYPTED ECDSA SIGN P256\000event=0x1087\000\00000\000KDSA-Encrypted-ECDSA-Sign-P256 function ending with CC=0\000 */
{ 68057 }, /* kdsa_encrypted_ecdsa_sign_p384\000pai_crypto\000KDSA ENCRYPTED ECDSA SIGN P384\000event=0x1088\000\00000\000KDSA-Encrypted-ECDSA-Sign-P384 function ending with CC=0\000 */
{ 68204 }, /* kdsa_encrypted_ecdsa_sign_p521\000pai_crypto\000KDSA ENCRYPTED ECDSA SIGN P521\000event=0x1089\000\00000\000KDSA-Encrypted-ECDSA-Sign-P521 function ending with CC=0\000 */
{ 68871 }, /* kdsa_encrypted_eddsa_sign_ed25519\000pai_crypto\000KDSA ENCRYPTED EDDSA SIGN ED25519\000event=0x108e\000\00000\000KDSA-Encrypted-EdDSA-Sign-Ed25519 function ending with CC=0\000 */
{ 69027 }, /* kdsa_encrypted_eddsa_sign_ed448\000pai_crypto\000KDSA ENCRYPTED EDDSA SIGN ED448\000event=0x108f\000\00000\000KDSA-Encrypted-EdDSA-Sign-Ed448 function ending with CC=0\000 */
{ 60558 }, /* kimd_ghash\000pai_crypto\000KIMD GHASH\000event=0x1051\000\00000\000KIMD-GHASH function ending with CC=0\000 */
{ 59976 }, /* kimd_sha3_224\000pai_crypto\000KIMD SHA3 224\000event=0x104b\000\00000\000KIMD-SHA3-224 function ending with CC=0\000 */
{ 60072 }, /* kimd_sha3_256\000pai_crypto\000KIMD SHA3 256\000event=0x104c\000\00000\000KIMD-SHA3-256 function ending with CC=0\000 */
{ 60168 }, /* kimd_sha3_384\000pai_crypto\000KIMD SHA3 384\000event=0x104d\000\00000\000KIMD-SHA3-384 function ending with CC=0\000 */
{ 60264 }, /* kimd_sha3_512\000pai_crypto\000KIMD SHA3 512\000event=0x104e\000\00000\000KIMD-SHA3-512 function ending with CC=0\000 */
{ 59703 }, /* kimd_sha_1\000pai_crypto\000KIMD SHA 1\000event=0x1048\000\00000\000KIMD-SHA-1 function ending with CC=0\000 */
{ 59790 }, /* kimd_sha_256\000pai_crypto\000KIMD SHA 256\000event=0x1049\000\00000\000KIMD-SHA-256 function ending with CC=0\000 */
{ 59883 }, /* kimd_sha_512\000pai_crypto\000KIMD SHA 512\000event=0x104a\000\00000\000KIMD-SHA-512 function ending with CC=0\000 */
{ 60360 }, /* kimd_shake_128\000pai_crypto\000KIMD SHAKE 128\000event=0x104f\000\00000\000KIMD-SHAKE-128 function ending with CC=0\000 */
{ 60459 }, /* kimd_shake_256\000pai_crypto\000KIMD SHAKE 256\000event=0x1050\000\00000\000KIMD-SHAKE-256 function ending with CC=0\000 */
{ 60918 }, /* klmd_sha3_224\000pai_crypto\000KLMD SHA3 224\000event=0x1055\000\00000\000KLMD-SHA3-224 function ending with CC=0\000 */
{ 61014 }, /* klmd_sha3_256\000pai_crypto\000KLMD SHA3 256\000event=0x1056\000\00000\000KLMD-SHA3-256 function ending with CC=0\000 */
{ 61110 }, /* klmd_sha3_384\000pai_crypto\000KLMD SHA3 384\000event=0x1057\000\00000\000KLMD-SHA3-384 function ending with CC=0\000 */
{ 61206 }, /* klmd_sha3_512\000pai_crypto\000KLMD SHA3 512\000event=0x1058\000\00000\000KLMD-SHA3-512 function ending with CC=0\000 */
{ 60645 }, /* klmd_sha_1\000pai_crypto\000KLMD SHA 1\000event=0x1052\000\00000\000KLMD-SHA-1 function ending with CC=0\000 */
{ 60732 }, /* klmd_sha_256\000pai_crypto\000KLMD SHA 256\000event=0x1053\000\00000\000KLMD-SHA-256 function ending with CC=0\000 */
{ 60825 }, /* klmd_sha_512\000pai_crypto\000KLMD SHA 512\000event=0x1054\000\00000\000KLMD-SHA-512 function ending with CC=0\000 */
{ 61302 }, /* klmd_shake_128\000pai_crypto\000KLMD SHAKE 128\000event=0x1059\000\00000\000KLMD-SHAKE-128 function ending with CC=0\000 */
{ 61401 }, /* klmd_shake_256\000pai_crypto\000KLMD SHAKE 256\000event=0x105a\000\00000\000KLMD-SHAKE-256 function ending with CC=0\000 */
{ 52788 }, /* km_aes_128\000pai_crypto\000KM AES 128\000event=0x1007\000\00000\000KM-AES-128 function ending with CC=0\000 */
{ 52875 }, /* km_aes_192\000pai_crypto\000KM AES 192\000event=0x1008\000\00000\000KM-AES-192 function ending with CC=0\000 */
{ 52962 }, /* km_aes_256\000pai_crypto\000KM AES 256\000event=0x1009\000\00000\000KM-AES-256 function ending with CC=0\000 */
{ 52188 }, /* km_dea\000pai_crypto\000KM DEA\000event=0x1001\000\00000\000KM-DEA function ending with CC=0\000 */
{ 53049 }, /* km_encrypted_aes_128\000pai_crypto\000KM ENCRYPTED AES 128\000event=0x100a\000\00000\000KM-Encrypted-AES-128 function ending with CC=0\000 */
{ 53166 }, /* km_encrypted_aes_192\000pai_crypto\000KM ENCRYPTED AES 192\000event=0x100b\000\00000\000KM-Encrypted-AES-192 function ending with CC=0\000 */
{ 53283 }, /* km_encrypted_aes_256\000pai_crypto\000KM ENCRYPTED AES 256\000event=0x100c\000\00000\000KM-Encrypted-AES-256 function ending with CC=0\000 */
{ 52443 }, /* km_encrypted_dea\000pai_crypto\000KM ENCRYPTED DEA\000event=0x1004\000\00000\000KM-Encrypted-DEA function ending with CC=0\000 */
{ 52548 }, /* km_encrypted_tdea_128\000pai_crypto\000KM ENCRYPTED TDEA 128\000event=0x1005\000\00000\000KM-Encrypted-TDEA-128 function ending with CC=0\000 */
{ 52668 }, /* km_encrypted_tdea_192\000pai_crypto\000KM ENCRYPTED TDEA 192\000event=0x1006\000\00000\000KM-Encrypted-TDEA-192 function ending with CC=0\000 */
{ 52263 }, /* km_tdea_128\000pai_crypto\000KM TDEA 128\000event=0x1002\000\00000\000KM-TDEA-128 function ending with CC=0\000 */
{ 52353 }, /* km_tdea_192\000pai_crypto\000KM TDEA 192\000event=0x1003\000\00000\000KM-TDEA-192 function ending with CC=0\000 */
{ 53400 }, /* km_xts_aes_128\000pai_crypto\000KM XTS AES 128\000event=0x100d\000\00000\000KM-XTS-AES-128 function ending with CC=0\000 */
{ 53499 }, /* km_xts_aes_256\000pai_crypto\000KM XTS AES 256\000event=0x100e\000\00000\000KM-XTS-AES-256 function ending with CC=0\000 */
{ 53598 }, /* km_xts_encrypted_aes_128\000pai_crypto\000KM XTS ENCRYPTED AES 128\000event=0x100f\000\00000\000KM-XTS-Encrypted-AES-128 function ending with CC=0\000 */
{ 53727 }, /* km_xts_encrypted_aes_256\000pai_crypto\000KM XTS ENCRYPTED AES 256\000event=0x1010\000\00000\000KM-XTS-Encrypted-AES-256 function ending with CC=0\000 */
{ 55185 }, /* kma_gcm_aes_128\000pai_crypto\000KMA GCM AES 128\000event=0x101e\000\00000\000KMA-GCM-AES-128 function ending with CC=0\000 */
{ 55287 }, /* kma_gcm_aes_192\000pai_crypto\000KMA GCM AES 192\000event=0x101f\000\00000\000KMA-GCM-AES-192 function ending with CC=0\000 */
{ 55389 }, /* kma_gcm_aes_256\000pai_crypto\000KMA GCM AES 256\000event=0x1020\000\00000\000KMA-GCM-AES-256 function ending with CC=0\000 */
{ 55491 }, /* kma_gcm_encrypted_aes_128\000pai_crypto\000KMA GCM ENCRYPTED AES 128\000event=0x1021\000\00000\000KMA-GCM-Encrypted-AES-128 function ending with CC=0\000 */
{ 55623 }, /* kma_gcm_encrypted_aes_192\000pai_crypto\000KMA GCM ENCRYPTED AES 192\000event=0x1022\000\00000\000KMA-GCM-Encrypted-AES-192 function ending with CC=0\000 */
{ 55755 }, /* kma_gcm_encrypted_aes_256\000pai_crypto\000KMA GCM ENCRYPTED AES 256\000event=0x1023\000\00000\000KMA-GCM-Encrypted-AES-256 function ending with CC=0\000 */
{ 62136 }, /* kmac_aes_128\000pai_crypto\000KMAC AES 128\000event=0x1061\000\00000\000KMAC-AES-128 function ending with CC=0\000 */
{ 62229 }, /* kmac_aes_192\000pai_crypto\000KMAC AES 192\000event=0x1062\000\00000\000KMAC-AES-192 function ending with CC=0\000 */
{ 62322 }, /* kmac_aes_256\000pai_crypto\000KMAC AES 256\000event=0x1063\000\00000\000KMAC-AES-256 function ending with CC=0\000 */
{ 61500 }, /* kmac_dea\000pai_crypto\000KMAC DEA\000event=0x105b\000\00000\000KMAC-DEA function ending with CC=0\000 */
{ 62415 }, /* kmac_encrypted_aes_128\000pai_crypto\000KMAC ENCRYPTED AES 128\000event=0x1064\000\00000\000KMAC-Encrypted-AES-128 function ending with CC=0\000 */
{ 62538 }, /* kmac_encrypted_aes_192\000pai_crypto\000KMAC ENCRYPTED AES 192\000event=0x1065\000\00000\000KMAC-Encrypted-AES-192 function ending with CC=0\000 */
{ 62661 }, /* kmac_encrypted_aes_256\000pai_crypto\000KMAC ENCRYPTED AES 256\000event=0x1066\000\00000\000KMAC-Encrypted-AES-256 function ending with CC=0\000 */
{ 61773 }, /* kmac_encrypted_dea\000pai_crypto\000KMAC ENCRYPTED DEA\000event=0x105e\000\00000\000KMAC-Encrypted-DEA function ending with CC=0\000 */
{ 61884 }, /* kmac_encrypted_tdea_128\000pai_crypto\000KMAC ENCRYPTED TDEA 128\000event=0x105f\000\00000\000KMAC-Encrypted-TDEA-128 function ending with CC=0\000 */
{ 62010 }, /* kmac_encrypted_tdea_192\000pai_crypto\000KMAC ENCRYPTED TDEA 192\000event=0x1060\000\00000\000KMAC-Encrypted-TDEA-192 function ending with CC=0\000 */
{ 61581 }, /* kmac_tdea_128\000pai_crypto\000KMAC TDEA 128\000event=0x105c\000\00000\000KMAC-TDEA-128 function ending with CC=0\000 */
{ 61677 }, /* kmac_tdea_192\000pai_crypto\000KMAC TDEA 192\000event=0x105d\000\00000\000KMAC-TDEA-192 function ending with CC=0\000 */
{ 54474 }, /* kmc_aes_128\000pai_crypto\000KMC AES 128\000event=0x1017\000\00000\000KMC-AES-128 function ending with CC=0\000 */
{ 54564 }, /* kmc_aes_192\000pai_crypto\000KMC AES 192\000event=0x1018\000\00000\000KMC-AES-192 function ending with CC=0\000 */
{ 54654 }, /* kmc_aes_256\000pai_crypto\000KMC AES 256\000event=0x1019\000\00000\000KMC-AES-256 function ending with CC=0\000 */
{ 53856 }, /* kmc_dea\000pai_crypto\000KMC DEA\000event=0x1011\000\00000\000KMC-DEA function ending with CC=0\000 */
{ 54744 }, /* kmc_encrypted_aes_128\000pai_crypto\000KMC ENCRYPTED AES 128\000event=0x101a\000\00000\000KMC-Encrypted-AES-128 function ending with CC=0\000 */
{ 54864 }, /* kmc_encrypted_aes_192\000pai_crypto\000KMC ENCRYPTED AES 192\000event=0x101b\000\00000\000KMC-Encrypted-AES-192 function ending with CC=0\000 */
{ 54984 }, /* kmc_encrypted_aes_256\000pai_crypto\000KMC ENCRYPTED AES 256\000event=0x101c\000\00000\000KMC-Encrypted-AES-256 function ending with CC=0\000 */
{ 54120 }, /* kmc_encrypted_dea\000pai_crypto\000KMC ENCRYPTED DEA\000event=0x1014\000\00000\000KMC-Encrypted-DEA function ending with CC=0\000 */
{ 54228 }, /* kmc_encrypted_tdea_128\000pai_crypto\000KMC ENCRYPTED TDEA 128\000event=0x1015\000\00000\000KMC-Encrypted-TDEA-128 function ending with CC=0\000 */
{ 54351 }, /* kmc_encrypted_tdea_192\000pai_crypto\000KMC ENCRYPTED TDEA 192\000event=0x1016\000\00000\000KMC-Encrypted-TDEA-192 function ending with CC=0\000 */
{ 55104 }, /* kmc_prng\000pai_crypto\000KMC PRNG\000event=0x101d\000\00000\000KMC-PRNG function ending with CC=0\000 */
{ 53934 }, /* kmc_tdea_128\000pai_crypto\000KMC TDEA 128\000event=0x1012\000\00000\000KMC-TDEA-128 function ending with CC=0\000 */
{ 54027 }, /* kmc_tdea_192\000pai_crypto\000KMC TDEA 192\000event=0x1013\000\00000\000KMC-TDEA-192 function ending with CC=0\000 */
{ 57789 }, /* kmctr_aes_128\000pai_crypto\000KMCTR AES 128\000event=0x1036\000\00000\000KMCTR-AES-128 function ending with CC=0\000 */
{ 57885 }, /* kmctr_aes_192\000pai_crypto\000KMCTR AES 192\000event=0x1037\000\00000\000KMCTR-AES-192 function ending with CC=0\000 */
{ 57981 }, /* kmctr_aes_256\000pai_crypto\000KMCTR AES 256\000event=0x1038\000\00000\000KMCTR-AES-256 function ending with CC=0\000 */
{ 57135 }, /* kmctr_dea\000pai_crypto\000KMCTR DEA\000event=0x1030\000\00000\000KMCTR-DEA function ending with CC=0\000 */
{ 58077 }, /* kmctr_encrypted_aes_128\000pai_crypto\000KMCTR ENCRYPTED AES 128\000event=0x1039\000\00000\000KMCTR-Encrypted-AES-128 function ending with CC=0\000 */
{ 58203 }, /* kmctr_encrypted_aes_192\000pai_crypto\000KMCTR ENCRYPTED AES 192\000event=0x103a\000\00000\000KMCTR-Encrypted-AES-192 function ending with CC=0\000 */
{ 58329 }, /* kmctr_encrypted_aes_256\000pai_crypto\000KMCTR ENCRYPTED AES 256\000event=0x103b\000\00000\000KMCTR-Encrypted-AES-256 function ending with CC=0\000 */
{ 57417 }, /* kmctr_encrypted_dea\000pai_crypto\000KMCTR ENCRYPTED DEA\000event=0x1033\000\00000\000KMCTR-Encrypted-DEA function ending with CC=0\000 */
{ 57531 }, /* kmctr_encrypted_tdea_128\000pai_crypto\000KMCTR ENCRYPTED TDEA 128\000event=0x1034\000\00000\000KMCTR-Encrypted-TDEA-128 function ending with CC=0\000 */
{ 57660 }, /* kmctr_encrypted_tdea_192\000pai_crypto\000KMCTR ENCRYPTED TDEA 192\000event=0x1035\000\00000\000KMCTR-Encrypted-TDEA-192 function ending with CC=0\000 */
{ 57219 }, /* kmctr_tdea_128\000pai_crypto\000KMCTR TDEA 128\000event=0x1031\000\00000\000KMCTR-TDEA-128 function ending with CC=0\000 */
{ 57318 }, /* kmctr_tdea_192\000pai_crypto\000KMCTR TDEA 192\000event=0x1032\000\00000\000KMCTR-TDEA-192 function ending with CC=0\000 */
{ 56505 }, /* kmf_aes_128\000pai_crypto\000KMF AES 128\000event=0x102a\000\00000\000KMF-AES-128 function ending with CC=0\000 */
{ 56595 }, /* kmf_aes_192\000pai_crypto\000KMF AES 192\000event=0x102b\000\00000\000KMF-AES-192 function ending with CC=0\000 */
{ 56685 }, /* kmf_aes_256\000pai_crypto\000KMF AES 256\000event=0x102c\000\00000\000KMF-AES-256 function ending with CC=0\000 */
{ 55887 }, /* kmf_dea\000pai_crypto\000KMF DEA\000event=0x1024\000\00000\000KMF-DEA function ending with CC=0\000 */
{ 56775 }, /* kmf_encrypted_aes_128\000pai_crypto\000KMF ENCRYPTED AES 128\000event=0x102d\000\00000\000KMF-Encrypted-AES-128 function ending with CC=0\000 */
{ 56895 }, /* kmf_encrypted_aes_192\000pai_crypto\000KMF ENCRYPTED AES 192\000event=0x102e\000\00000\000KMF-Encrypted-AES-192 function ending with CC=0\000 */
{ 57015 }, /* kmf_encrypted_aes_256\000pai_crypto\000KMF ENCRYPTED AES 256\000event=0x102f\000\00000\000KMF-Encrypted-AES-256 function ending with CC=0\000 */
{ 56151 }, /* kmf_encrypted_dea\000pai_crypto\000KMF ENCRYPTED DEA\000event=0x1027\000\00000\000KMF-Encrypted-DEA function ending with CC=0\000 */
{ 56259 }, /* kmf_encrypted_tdea_128\000pai_crypto\000KMF ENCRYPTED TDEA 128\000event=0x1028\000\00000\000KMF-Encrypted-TDEA-128 function ending with CC=0\000 */
{ 56382 }, /* kmf_encrypted_tdea_192\000pai_crypto\000KMF ENCRYPTED TDEA 192\000event=0x1029\000\00000\000KMF-Encrypted-TDEA-192 function ending with CC=0\000 */
{ 55965 }, /* kmf_tdea_128\000pai_crypto\000KMF TDEA 128\000event=0x1025\000\00000\000KMF-TDEA-128 function ending with CC=0\000 */
{ 56058 }, /* kmf_tdea_192\000pai_crypto\000KMF TDEA 192\000event=0x1026\000\00000\000KMF-TDEA-192 function ending with CC=0\000 */
{ 59073 }, /* kmo_aes_128\000pai_crypto\000KMO AES 128\000event=0x1042\000\00000\000KMO-AES-128 function ending with CC=0\000 */
{ 59163 }, /* kmo_aes_192\000pai_crypto\000KMO AES 192\000event=0x1043\000\00000\000KMO-AES-192 function ending with CC=0\000 */
{ 59253 }, /* kmo_aes_256\000pai_crypto\000KMO AES 256\000event=0x1044\000\00000\000KMO-AES-256 function ending with CC=0\000 */
{ 58455 }, /* kmo_dea\000pai_crypto\000KMO DEA\000event=0x103c\000\00000\000KMO-DEA function ending with CC=0\000 */
{ 59343 }, /* kmo_encrypted_aes_128\000pai_crypto\000KMO ENCRYPTED AES 128\000event=0x1045\000\00000\000KMO-Encrypted-AES-128 function ending with CC=0\000 */
{ 59463 }, /* kmo_encrypted_aes_192\000pai_crypto\000KMO ENCRYPTED AES 192\000event=0x1046\000\00000\000KMO-Encrypted-AES-192 function ending with CC=0\000 */
{ 59583 }, /* kmo_encrypted_aes_256\000pai_crypto\000KMO ENCRYPTED AES 256\000event=0x1047\000\00000\000KMO-Encrypted-AES-256 function ending with CC=0\000 */
{ 58719 }, /* kmo_encrypted_dea\000pai_crypto\000KMO ENCRYPTED DEA\000event=0x103f\000\00000\000KMO-Encrypted-DEA function ending with CC=0\000 */
{ 58827 }, /* kmo_encrypted_tdea_128\000pai_crypto\000KMO ENCRYPTED TDEA 128\000event=0x1040\000\00000\000KMO-Encrypted-TDEA-128 function ending with CC=0\000 */
{ 58950 }, /* kmo_encrypted_tdea_192\000pai_crypto\000KMO ENCRYPTED TDEA 192\000event=0x1041\000\00000\000KMO-Encrypted-TDEA-192 function ending with CC=0\000 */
{ 58533 }, /* kmo_tdea_128\000pai_crypto\000KMO TDEA 128\000event=0x103d\000\00000\000KMO-TDEA-128 function ending with CC=0\000 */
{ 58626 }, /* kmo_tdea_192\000pai_crypto\000KMO TDEA 192\000event=0x103e\000\00000\000KMO-TDEA-192 function ending with CC=0\000 */
{ 63944 }, /* pcc_compute_last_block_cmac_using_aes_128\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING AES 128\000event=0x106d\000\00000\000PCC-Compute-Last-Block-CMAC-Using-AES-128 function ending with CC=0\000 */
{ 64124 }, /* pcc_compute_last_block_cmac_using_aes_192\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING AES 192\000event=0x106e\000\00000\000PCC-Compute-Last-Block-CMAC-Using-AES-192 function ending with CC=0\000 */
{ 64304 }, /* pcc_compute_last_block_cmac_using_aes_256\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING AES 256\000event=0x106f\000\00000\000PCC-Compute-Last-Block-CMAC-Using-AES-256 function ending with CC=0\000 */
{ 62784 }, /* pcc_compute_last_block_cmac_using_dea\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING DEA\000event=0x1067\000\00000\000PCC-Compute-Last-Block-CMAC-Using-DEA function ending with CC=0\000 */
{ 64484 }, /* pcc_compute_last_block_cmac_using_encrypted_aes_128\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED AES 128\000event=0x1070\000\00000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-AES- 128 function ending with CC=0\000 */
{ 64695 }, /* pcc_compute_last_block_cmac_using_encrypted_aes_192\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED AES 192\000event=0x1071\000\00000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-AES- 192 function ending with CC=0\000 */
{ 64906 }, /* pcc_compute_last_block_cmac_using_encrypted_aes_256a\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED AES 256A\000event=0x1072\000\00000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-AES- 256A function ending with CC=0\000 */
{ 63318 }, /* pcc_compute_last_block_cmac_using_encrypted_dea\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED DEA\000event=0x106a\000\00000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-DEA function ending with CC=0\000 */
{ 63516 }, /* pcc_compute_last_block_cmac_using_encrypted_tdea_128\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED TDEA 128\000event=0x106b\000\00000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-TDEA- 128 function ending with CC=0\000 */
{ 63730 }, /* pcc_compute_last_block_cmac_using_encrypted_tdea_192\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING ENCRYPTED TDEA 192\000event=0x106c\000\00000\000PCC-Compute-Last-Block-CMAC-Using-Encrypted-TDEA- 192 function ending with CC=0\000 */
{ 62952 }, /* pcc_compute_last_block_cmac_using_tdea_128\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING TDEA 128\000event=0x1068\000\00000\000PCC-Compute-Last-Block-CMAC-Using-TDEA-128 function ending with CC=0\000 */
{ 63135 }, /* pcc_compute_last_block_cmac_using_tdea_192\000pai_crypto\000PCC COMPUTE LAST BLOCK CMAC USING TDEA 192\000event=0x1069\000\00000\000PCC-Compute-Last-Block-CMAC-Using-TDEA-192 function ending with CC=0\000 */
{ 65120 }, /* pcc_compute_xts_parameter_using_aes_128\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING AES 128\000event=0x1073\000\00000\000PCC-Compute-XTS-Parameter-Using-AES-128 function ending with CC=0\000 */
{ 65294 }, /* pcc_compute_xts_parameter_using_aes_256\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING AES 256\000event=0x1074\000\00000\000PCC-Compute-XTS-Parameter-Using-AES-256 function ending with CC=0\000 */
{ 65468 }, /* pcc_compute_xts_parameter_using_encrypted_aes_128\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING ENCRYPTED AES 128\000event=0x1075\000\00000\000PCC-Compute-XTS-Parameter-Using-Encrypted-AES-128 function ending with CC=0\000 */
{ 65672 }, /* pcc_compute_xts_parameter_using_encrypted_aes_256\000pai_crypto\000PCC COMPUTE XTS PARAMETER USING ENCRYPTED AES 256\000event=0x1076\000\00000\000PCC-Compute-XTS-Parameter-Using-Encrypted-AES-256 function ending with CC=0\000 */
{ 66263 }, /* pcc_scalar_multiply_ed25519\000pai_crypto\000PCC SCALAR MULTIPLY ED25519\000event=0x107a\000\00000\000PCC-Scalar-Multiply-Ed25519 function ending with CC=0\000 */
{ 66401 }, /* pcc_scalar_multiply_ed448\000pai_crypto\000PCC SCALAR MULTIPLY ED448\000event=0x107b\000\00000\000PCC-Scalar-Multiply-Ed448 function ending with CC=0\000 */
{ 65876 }, /* pcc_scalar_multiply_p256\000pai_crypto\000PCC SCALAR MULTIPLY P256\000event=0x1077\000\00000\000PCC-Scalar-Multiply-P256 function ending with CC=0\000 */
{ 66005 }, /* pcc_scalar_multiply_p384\000pai_crypto\000PCC SCALAR MULTIPLY P384\000event=0x1078\000\00000\000PCC-Scalar-Multiply-P384 function ending with CC=0\000 */
{ 66134 }, /* pcc_scalar_multiply_p521\000pai_crypto\000PCC SCALAR MULTIPLY P521\000event=0x1079\000\00000\000PCC-Scalar-Multiply-P521 function ending with CC=0\000 */
{ 66533 }, /* pcc_scalar_multiply_x25519\000pai_crypto\000PCC SCALAR MULTIPLY X25519\000event=0x107c\000\00000\000PCC-Scalar-Multiply-X25519 function ending with CC=0\000 */
{ 66668 }, /* pcc_scalar_multiply_x448\000pai_crypto\000PCC SCALAR MULTIPLY X448\000event=0x107d\000\00000\000PCC-Scalar-Multiply-X448 function ending with CC=0\000 */
{ 69516 }, /* pckmo_encrypt_aes_128_key\000pai_crypto\000PCKMO ENCRYPT AES 128 KEY\000event=0x1093\000\00000\000PCKMO-Encrypt-AES-128-key function\000 */
{ 69631 }, /* pckmo_encrypt_aes_192_key\000pai_crypto\000PCKMO ENCRYPT AES 192 KEY\000event=0x1094\000\00000\000PCKMO-Encrypt-AES-192-key function\000 */
{ 69746 }, /* pckmo_encrypt_aes_256_key\000pai_crypto\000PCKMO ENCRYPT AES 256 KEY\000event=0x1095\000\00000\000PCKMO-Encrypt-AES-256-key function\000 */
{ 69177 }, /* pckmo_encrypt_dea_key\000pai_crypto\000PCKMO ENCRYPT DEA KEY\000event=0x1090\000\00000\000PCKMO-Encrypt-DEA-key function\000 */
{ 70215 }, /* pckmo_encrypt_ecc_ed25519_key\000pai_crypto\000PCKMO ENCRYPT ECC ED25519 KEY\000event=0x1099\000\00000\000PCKMO-Encrypt-ECC-Ed25519-key function\000 */
{ 70342 }, /* pckmo_encrypt_ecc_ed448_key\000pai_crypto\000PCKMO ENCRYPT ECC ED448 KEY\000event=0x109a\000\00000\000PCKMO-Encrypt-ECC-Ed448-key function\000 */
{ 69861 }, /* pckmo_encrypt_ecc_p256_key\000pai_crypto\000PCKMO ENCRYPT ECC P256 KEY\000event=0x1096\000\00000\000PCKMO-Encrypt-ECC-P256-key function\000 */
{ 69979 }, /* pckmo_encrypt_ecc_p384_key\000pai_crypto\000PCKMO ENCRYPT ECC P384 KEY\000event=0x1097\000\00000\000PCKMO-Encrypt-ECC-P384-key function\000 */
{ 70097 }, /* pckmo_encrypt_ecc_p521_key\000pai_crypto\000PCKMO ENCRYPT ECC P521 KEY\000event=0x1098\000\00000\000PCKMO-Encrypt-ECC-P521-key function\000 */
{ 69280 }, /* pckmo_encrypt_tdea_128_key\000pai_crypto\000PCKMO ENCRYPT TDEA 128 KEY\000event=0x1091\000\00000\000PCKMO-Encrypt-TDEA-128-key function\000 */
{ 69398 }, /* pckmo_encrypt_tdea_192_key\000pai_crypto\000PCKMO ENCRYPT TDEA 192 KEY\000event=0x1092\000\00000\000PCKMO-Encrypt-TDEA-192-key function\000 */
{ 66797 }, /* prno_sha_512_drng\000pai_crypto\000PRNO SHA 512 DRNG\000event=0x107e\000\00000\000PRNO-SHA-512-DRNG function ending with CC=0\000 */
{ 67082 }, /* prno_trng\000pai_crypto\000PRNO TRNG\000event=0x1080\000\00000\000PRNO-TRNG function ending with CC=0\000 */
{ 66905 }, /* prno_trng_query_raw_to_conditioned_ratio\000pai_crypto\000PRNO TRNG QUERY RAW TO CONDITIONED RATIO\000event=0x107f\000\00000\000PRNO-TRNG-Query-Raw-to-Conditioned-Ratio function ending with CC=0\000 */
};
static const struct compact_pmu_event pmu_events__cf_z16_pai_ext[] = {
{ 72842 }, /* nnpa_1mframe\000pai_ext\000NNPA 1MFRAME OP function ending with CC=0\000event=0x1819\000\00000\000NNPA function with conditions as described in Common Operation\000 */
{ 72985 }, /* nnpa_2gframe\000pai_ext\000NNPA 2GFRAME OP function ending with CC=0\000event=0x181a\000\00000\000NNPA function with conditions as described in Common Operation\000 */
{ 73128 }, /* nnpa_accessexcept\000pai_ext\000NNPA ACCESSEXCEPT OP function ending with CC=0\000event=0x181b\000\00000\000NNPA function with conditions as described in Common Operation\000 */
{ 70779 }, /* nnpa_add\000pai_ext\000NNPA ADD function ending with CC=0\000event=0x1801\000\00000\000\000 */
{ 70637 }, /* nnpa_all\000pai_ext\000NNPA ALL Sum of all non zero counters\000event=0x1800\000\00000\000Sum of all non zero NNPA (Neural Networks Processing Assist) counters\000 */
{ 71890 }, /* nnpa_avgpool2d\000pai_ext\000NNPA AVGPOOL2D function ending with CC=0\000event=0x1810\000\00000\000\000 */
{ 71726 }, /* nnpa_batchnorm\000pai_ext\000NNPA BATCHNORM function ending with CC=0\000event=0x180e\000\00000\000\000 */
{ 72126 }, /* nnpa_convolution\000pai_ext\000NNPA CONVOLUTION function ending with CC=0\000event=0x1813\000\00000\000\000 */
{ 70989 }, /* nnpa_div\000pai_ext\000NNPA DIV function ending with CC=0\000event=0x1804\000\00000\000\000 */
{ 71269 }, /* nnpa_exp\000pai_ext\000NNPA EXP function ending with CC=0\000event=0x1808\000\00000\000\000 */
{ 72050 }, /* nnpa_gruact\000pai_ext\000NNPA GRUACT function ending with CC=0\000event=0x1812\000\00000\000\000 */
{ 71339 }, /* nnpa_ibm_reserved_9\000pai_ext\000Reserved for IBM use\000event=0x1809\000\00000\000Reserved for IBM use\000 */
{ 72546 }, /* nnpa_largedim\000pai_ext\000NNPA LARGEDIM OP function ending with CC=0\000event=0x1817\000\00000\000NNPA function with conditions as described in Common Operation\000 */
{ 71199 }, /* nnpa_log\000pai_ext\000NNPA LOG function ending with CC=0\000event=0x1807\000\00000\000\000 */
{ 71972 }, /* nnpa_lstmact\000pai_ext\000NNPA LSTMACT function ending with CC=0\000event=0x1811\000\00000\000\000 */
{ 72212 }, /* nnpa_matmul_op\000pai_ext\000NNPA MATMUL OP function ending with CC=0\000event=0x1814\000\00000\000\000 */
{ 72294 }, /* nnpa_matmul_op_bcast23\000pai_ext\000NNPA NNPA MATMUL OP BCAST23 function ending with CC=0\000event=0x1815\000\00000\000\000 */
{ 71129 }, /* nnpa_max\000pai_ext\000NNPA MAX function ending with CC=0\000event=0x1806\000\00000\000\000 */
{ 71808 }, /* nnpa_maxpool2d\000pai_ext\000NNPA MAXPOOL2D function ending with CC=0\000event=0x180f\000\00000\000\000 */
{ 71059 }, /* nnpa_min\000pai_ext\000NNPA MIN function ending with CC=0\000event=0x1805\000\00000\000\000 */
{ 70919 }, /* nnpa_mul\000pai_ext\000NNPA MUL function ending with CC=0\000event=0x1803\000\00000\000\000 */
{ 71426 }, /* nnpa_relu\000pai_ext\000NNPA RELU function ending with CC=0\000event=0x180a\000\00000\000\000 */
{ 71570 }, /* nnpa_sigmoid\000pai_ext\000NNPA SIGMOID function ending with CC=0\000event=0x180c\000\00000\000\000 */
{ 72397 }, /* nnpa_smallbatch\000pai_ext\000NNPA SMALLBATCH OP function ending with CC=0\000event=0x1816\000\00000\000NNPA function with conditions as described in Common Operation\000 */
{ 72691 }, /* nnpa_smalltensor\000pai_ext\000NNPA SMALLTENSOR OP function ending with CC=0\000event=0x1818\000\00000\000NNPA function with conditions as described in Common Operation\000 */
{ 71648 }, /* nnpa_softmax\000pai_ext\000NNPA SOFTMAX function ending with CC=0\000event=0x180d\000\00000\000\000 */
{ 70849 }, /* nnpa_sub\000pai_ext\000NNPA SUB function ending with CC=0\000event=0x1802\000\00000\000\000 */
{ 71498 }, /* nnpa_tanh\000pai_ext\000NNPA TANH function ending with CC=0\000event=0x180b\000\00000\000\000 */

};

const struct pmu_table_entry pmu_events__cf_z16[] = {
{
     .entries = pmu_events__cf_z16_cpum_cf,
     .num_entries = ARRAY_SIZE(pmu_events__cf_z16_cpum_cf),
     .pmu_name = { 0 /* cpum_cf\000 */ },
},
{
     .entries = pmu_events__cf_z16_pai_crypto,
     .num_entries = ARRAY_SIZE(pmu_events__cf_z16_pai_crypto),
     .pmu_name = { 52084 /* pai_crypto\000 */ },
},
{
     .entries = pmu_events__cf_z16_pai_ext,
     .num_entries = ARRAY_SIZE(pmu_events__cf_z16_pai_ext),
     .pmu_name = { 70629 /* pai_ext\000 */ },
},
};

static const struct compact_pmu_event pmu_metrics__cf_z16_default_core[] = {
{ 87011 }, /* cpi\000\000CPU_CYCLES / INSTRUCTIONS\000\000Cycles per Instruction\000\000\000\000\000\00000 */
{ 91220 }, /* est_cpi\000\000CPU_CYCLES / INSTRUCTIONS - L1C_TLB2_MISSES / INSTRUCTIONS\000\000Estimated Instruction Complexity CPI infinite Level 1\000\000\000\000\000\00000 */
{ 91120 }, /* finite_cpi\000\000L1C_TLB2_MISSES / INSTRUCTIONS\000\000Cycles per Instructions from Finite cache/memory\000\000\000\000\000\00000 */
{ 87171 }, /* l1mp\000\000(L1I_DIR_WRITES + L1D_DIR_WRITES) / INSTRUCTIONS * 100\000\000Level One Miss per 100 Instructions\000\000\000\000\000\00000 */
{ 91811 }, /* l2p\000\000(DCW_REQ + DCW_REQ_IV + ICW_REQ + ICW_REQ_IV) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 2 cache\000\000\000\000\000\00000 */
{ 91950 }, /* l3p\000\000(DCW_REQ_CHIP_HIT + DCW_ON_CHIP + DCW_ON_CHIP_IV + DCW_ON_CHIP_CHIP_HIT + ICW_REQ_CHIP_HIT + ICW_ON_CHIP + ICW_ON_CHIP_IV + ICW_ON_CHIP_CHIP_HIT) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 3 on same chip cache\000\000\000\000\000\00000 */
{ 92202 }, /* l4lp\000\000(DCW_REQ_DRAWER_HIT + DCW_ON_CHIP_DRAWER_HIT + DCW_ON_MODULE + DCW_ON_DRAWER + IDCW_ON_MODULE_IV + IDCW_ON_MODULE_CHIP_HIT + IDCW_ON_MODULE_DRAWER_HIT + IDCW_ON_DRAWER_IV + IDCW_ON_DRAWER_CHIP_HIT + IDCW_ON_DRAWER_DRAWER_HIT + ICW_REQ_DRAWER_HIT + ICW_ON_CHIP_DRAWER_HIT + ICW_ON_MODULE + ICW_ON_DRAWER) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 4 Local cache on same book\000\000\000\000\000\00000 */
{ 92619 }, /* l4rp\000\000(DCW_OFF_DRAWER + IDCW_OFF_DRAWER_IV + IDCW_OFF_DRAWER_CHIP_HIT + IDCW_OFF_DRAWER_DRAWER_HIT + ICW_OFF_DRAWER) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from Level 4 Remote cache on different book\000\000\000\000\000\00000 */
{ 92849 }, /* memp\000\000(DCW_ON_CHIP_MEMORY + DCW_ON_MODULE_MEMORY + DCW_ON_DRAWER_MEMORY + DCW_OFF_DRAWER_MEMORY + ICW_ON_CHIP_MEMORY + ICW_ON_MODULE_MEMORY + ICW_ON_DRAWER_MEMORY + ICW_OFF_DRAWER_MEMORY) / (L1I_DIR_WRITES + L1D_DIR_WRITES) * 100\000\000Percentage sourced from memory\000\000\000\000\000\00000 */
{ 87073 }, /* prbstate\000\000PROBLEM_STATE_INSTRUCTIONS / INSTRUCTIONS * 100\000\000Problem State Instruction Ratio\000\000\000\000\000\00000 */
{ 91350 }, /* scpl1m\000\000L1C_TLB2_MISSES / (L1I_DIR_WRITES + L1D_DIR_WRITES)\000\000Estimated Sourcing Cycles per Level 1 Miss\000\000\000\000\000\00000 */
{ 91637 }, /* tlb_miss\000\000(DTLB2_MISSES + ITLB2_MISSES) / (DTLB2_WRITES + ITLB2_WRITES) * (L1C_TLB2_MISSES / (L1I_PENALTY_CYCLES + L1D_PENALTY_CYCLES))\000\000Estimated Cycles per TLB Miss\000\000\000\000\000\00000 */
{ 91461 }, /* tlb_percent\000\000(DTLB2_MISSES + ITLB2_MISSES) / CPU_CYCLES * (L1C_TLB2_MISSES / (L1I_PENALTY_CYCLES + L1D_PENALTY_CYCLES)) * 100\000\000Estimated TLB CPU percentage of Total CPU\000\000\000\000\000\00000 */
{ 86887 }, /* transaction\000\000TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL\000\000Transaction count\000\000\000\000\000\00000 */

};

const struct pmu_table_entry pmu_metrics__cf_z16[] = {
{
     .entries = pmu_metrics__cf_z16_default_core,
     .num_entries = ARRAY_SIZE(pmu_metrics__cf_z16_default_core),
     .pmu_name = { 86874 /* default_core\000 */ },
},
};

static const struct compact_pmu_event pmu_events__cf_z196_cpum_cf[] = {
{ 5403 }, /* aes_blocked_cycles\000crypto\000AES Blocked Cycle Count\000event=0x4f\000\00000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 5147 }, /* aes_blocked_functions\000crypto\000AES Blocked Function Count\000event=0x4e\000\00000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 4963 }, /* aes_cycles\000crypto\000AES Cycle Count\000event=0x4d\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000 */
{ 4832 }, /* aes_functions\000crypto\000AES Function Count\000event=0x4c\000\00000\000This counter counts the total number of the AES functions issued by the CPU\000 */
{ 8 }, /* cpu_cycles\000basic\000Cycle Count\000event=0\000\00000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000 */
{ 4584 }, /* dea_blocked_cycles\000crypto\000DEA Blocked Cycle Count\000event=0x4b\000\00000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 4328 }, /* dea_blocked_functions\000crypto\000DEA Blocked Function Count\000event=0x4a\000\00000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 4144 }, /* dea_cycles\000crypto\000DEA Cycle Count\000event=0x49\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000 */
{ 4013 }, /* dea_functions\000crypto\000DEA Function Count\000event=0x48\000\00000\000This counter counts the total number of the DEA functions issued by the CPU\000 */
{ 75267 }, /* dtlb1_hpage_writes\000extended\000DTLB1 One-Megabyte Page Writes\000event=0x8c\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a one-megabyte page\000 */
{ 9700 }, /* dtlb1_misses\000extended\000DTLB1 Misses\000event=0x82\000\00000\000Level-1 Data TLB miss in progress. Incremented by one for every cycle a DTLB1 miss is in progress\000 */
{ 76176 }, /* dtlb1_writes\000extended\000DTLB1 Writes\000event=0x90\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000 */
{ 167 }, /* instructions\000basic\000Instruction Count\000event=1\000\00000\000This counter counts the total number of instructions executed by the CPU\000 */
{ 73662 }, /* itlb1_misses\000extended\000ITLB1 Misses\000event=0x83\000\00000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle a ITLB1 miss is in progress\000 */
{ 76320 }, /* itlb1_writes\000extended\000ITLB1 Writes\000event=0x91\000\00000\000A translation entry has been written to the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000 */
{ 641 }, /* l1d_dir_writes\000basic\000Level-1 D-Cache Directory Write Count\000event=4\000\00000\000This counter counts the total number of level-1 data-cache directory writes\000 */
{ 73281 }, /* l1d_l2_sourced_writes\000extended\000L1D L2 Sourced Writes\000event=0x80\000\00000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from the Level-2 cache\000 */
{ 75451 }, /* l1d_lmem_sourced_writes\000extended\000L1D Local Memory Sourced Writes\000event=0x8d\000\00000\000A directory write to the Level-1 Data Cache where the installed cache line was sourced from memory that is attached to the same book as the Data cache (Local Memory)\000 */
{ 73930 }, /* l1d_offbook_l3_sourced_writes\000extended\000L1D Off-Book L3 Sourced Writes\000event=0x86\000\00000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an Off Book Level-3 cache\000 */
{ 74836 }, /* l1d_offbook_l4_sourced_writes\000extended\000L1D Off-Book L4 Sourced Writes\000event=0x8a\000\00000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000 */
{ 77196 }, /* l1d_offchip_l3_sourced_writes\000extended\000L1D Off-Chip L3 Sourced Writes\000event=0x98\000\00000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache\000 */
{ 74142 }, /* l1d_onbook_l4_sourced_writes\000extended\000L1D On-Book L4 Sourced Writes\000event=0x87\000\00000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an On Book Level-4 cache\000 */
{ 76987 }, /* l1d_onchip_l3_sourced_writes\000extended\000L1D On-Chip L3 Sourced Writes\000event=0x96\000\00000\000A directory write to the Level-1 Data Cache directory where the returned cache line was sourced from an On Chip Level-3 cache\000 */
{ 788 }, /* l1d_penalty_cycles\000basic\000Level-1 D-Cache Penalty Cycle Count\000event=5\000\00000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000 */
{ 74567 }, /* l1d_ro_excl_writes\000extended\000L1D Read-only Exclusive Writes\000event=0x89\000\00000\000A directory write to the Level-1 Data Cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000 */
{ 289 }, /* l1i_dir_writes\000basic\000Level-1 I-Cache Directory Write Count\000event=2\000\00000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000 */
{ 73468 }, /* l1i_l2_sourced_writes\000extended\000L1I L2 Sourced Writes\000event=0x81\000\00000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from the Level-2 cache\000 */
{ 75697 }, /* l1i_lmem_sourced_writes\000extended\000L1I Local Memory Sourced Writes\000event=0x8e\000\00000\000A directory write to the Level-1 Instruction Cache where the installed cache line was sourced from memory that is attached to the same book as the Instruction cache (Local Memory)\000 */
{ 75957 }, /* l1i_offbook_l3_sourced_writes\000extended\000L1I Off-Book L3 Sourced Writes\000event=0x8f\000\00000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an Off Book Level-3 cache\000 */
{ 75048 }, /* l1i_offbook_l4_sourced_writes\000extended\000L1I Off-Book L4 Sourced Writes\000event=0x8b\000\00000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000 */
{ 77632 }, /* l1i_offchip_l3_sourced_writes\000extended\000L1I Off-Chip L3 Sourced Writes\000event=0x9b\000\00000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache\000 */
{ 74351 }, /* l1i_onbook_l4_sourced_writes\000extended\000L1I On-Book L4 Sourced Writes\000event=0x88\000\00000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an On Book Level-4 cache\000 */
{ 77416 }, /* l1i_onchip_l3_sourced_writes\000extended\000L1I On-Chip L3 Sourced Writes\000event=0x99\000\00000\000A directory write to the Level-1 Instruction Cache directory where the returned cache line was sourced from an On Chip Level-3 cache\000 */
{ 460 }, /* l1i_penalty_cycles\000basic\000Level-1 I-Cache Penalty Cycle Count\000event=3\000\00000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000 */
{ 73817 }, /* l2c_stores_sent\000extended\000L2C Stores Sent\000event=0x85\000\00000\000Incremented by one for every store sent to Level-2 cache\000 */
{ 2925 }, /* prng_blocked_cycles\000crypto\000PRNG Blocked Cycle Count\000event=0x43\000\00000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 2636 }, /* prng_blocked_functions\000crypto\000PRNG Blocked Function Count\000event=0x42\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 2418 }, /* prng_cycles\000crypto\000PRNG Cycle Count\000event=0x41\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000 */
{ 2258 }, /* prng_functions\000crypto\000PRNG Function Count\000event=0x40\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000 */
{ 945 }, /* problem_state_cpu_cycles\000basic\000Problem-State Cycle Count\000event=0x20\000\00000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000 */
{ 1172 }, /* problem_state_instructions\000basic\000Problem-State Instruction Count\000event=0x21\000\00000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000 */
{ 1822 }, /* problem_state_l1d_dir_writes\000basic\000Problem-State Level-1 D-Cache Directory Write Count\000event=0x24\000\00000\000This counter counts the total number of level-1 data-cache directory writes while the CPU is in the problem state\000 */
{ 2038 }, /* problem_state_l1d_penalty_cycles\000basic\000Problem-State Level-1 D-Cache Penalty Cycle Count\000event=0x25\000\00000\000This counter counts the total number of penalty cycles for level-1 data cache while the CPU is in the problem state\000 */
{ 1352 }, /* problem_state_l1i_dir_writes\000basic\000Problem-State Level-1 I-Cache Directory Write Count\000event=0x22\000\00000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes while the CPU is in the problem state\000 */
{ 1592 }, /* problem_state_l1i_penalty_cycles\000basic\000Level-1 I-Cache Penalty Cycle Count\000event=0x23\000\00000\000This counter counts the total number of penalty cycles for level-1 instruction cache or unified cache while the CPU is in the problem state\000 */
{ 3769 }, /* sha_blocked_cycles\000crypto\000SHA Blocked Cycle Count\000event=0x47\000\00000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 3517 }, /* sha_blocked_functions\000crypto\000SHA Blocked Function Count\000event=0x46\000\00000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 3337 }, /* sha_cycles\000crypto\000SHA Cycle Count\000event=0x45\000\00000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000 */
{ 3206 }, /* sha_functions\000crypto\000SHA Function Count\000event=0x44\000\00000\000This counter counts the total number of the SHA functions issued by the CPU\000 */
{ 76607 }, /* tlb2_crste_hpage_writes\000extended\000TLB2 CRSTE One-Megabyte Page Writes\000event=0x93\000\00000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays for a one-megabyte large page translation\000 */
{ 76830 }, /* tlb2_crste_writes\000extended\000TLB2 CRSTE Writes\000event=0x94\000\00000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays\000 */
{ 76471 }, /* tlb2_pte_writes\000extended\000TLB2 PTE Writes\000event=0x92\000\00000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000 */

};

const struct pmu_table_entry pmu_events__cf_z196[] = {
{
     .entries = pmu_events__cf_z196_cpum_cf,
     .num_entries = ARRAY_SIZE(pmu_events__cf_z196_cpum_cf),
     .pmu_name = { 0 /* cpum_cf\000 */ },
},
};

static const struct compact_pmu_event pmu_events__cf_zec12_cpum_cf[] = {
{ 5403 }, /* aes_blocked_cycles\000crypto\000AES Blocked Cycle Count\000event=0x4f\000\00000\000This counter counts the total number of CPU cycles blocked for the AES functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 5147 }, /* aes_blocked_functions\000crypto\000AES Blocked Function Count\000event=0x4e\000\00000\000This counter counts the total number of the AES functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 4963 }, /* aes_cycles\000crypto\000AES Cycle Count\000event=0x4d\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the AES functions issued by the CPU\000 */
{ 4832 }, /* aes_functions\000crypto\000AES Function Count\000event=0x4c\000\00000\000This counter counts the total number of the AES functions issued by the CPU\000 */
{ 8 }, /* cpu_cycles\000basic\000Cycle Count\000event=0\000\00000\000This counter counts the total number of CPU cycles, excluding the number of cycles while the CPU is in the wait state\000 */
{ 4584 }, /* dea_blocked_cycles\000crypto\000DEA Blocked Cycle Count\000event=0x4b\000\00000\000This counter counts the total number of CPU cycles blocked for the DEA functions issued by the CPU because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 4328 }, /* dea_blocked_functions\000crypto\000DEA Blocked Function Count\000event=0x4a\000\00000\000This counter counts the total number of the DEA functions that are issued by the CPU and are blocked because the DEA/AES coprocessor is busy performing a function issued by another CPU\000 */
{ 4144 }, /* dea_cycles\000crypto\000DEA Cycle Count\000event=0x49\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES coprocessor is busy performing the DEA functions issued by the CPU\000 */
{ 4013 }, /* dea_functions\000crypto\000DEA Function Count\000event=0x48\000\00000\000This counter counts the total number of the DEA functions issued by the CPU\000 */
{ 79684 }, /* dtlb1_hpage_writes\000extended\000DTLB1 One-Megabyte Page Writes\000event=0x8b\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer for a one-megabyte page\000 */
{ 77859 }, /* dtlb1_misses\000extended\000DTLB1 Misses\000event=0x80\000\00000\000Level-1 Data TLB miss in progress. Incremented by one for every cycle a DTLB1 miss is in progress\000 */
{ 78765 }, /* dtlb1_writes\000extended\000DTLB1 Writes\000event=0x85\000\00000\000A translation entry has been written to the Level-1 Data Translation Lookaside Buffer (DTLB1)\000 */
{ 167 }, /* instructions\000basic\000Instruction Count\000event=1\000\00000\000This counter counts the total number of instructions executed by the CPU\000 */
{ 78007 }, /* itlb1_misses\000extended\000ITLB1 Misses\000event=0x81\000\00000\000Level-1 Instruction TLB miss in progress. Incremented by one for every cycle a ITLB1 miss is in progress\000 */
{ 79868 }, /* itlb1_writes\000extended\000ITLB1 Writes\000event=0x8c\000\00000\000A translation entry has been written to the Level-1 Instruction Translation Lookaside Buffer (ITLB1)\000 */
{ 641 }, /* l1d_dir_writes\000basic\000Level-1 D-Cache Directory Write Count\000event=4\000\00000\000This counter counts the total number of level-1 data-cache directory writes\000 */
{ 78571 }, /* l1d_l2d_sourced_writes\000extended\000L1D L2D Sourced Writes\000event=0x84\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Data cache\000 */
{ 78162 }, /* l1d_l2i_sourced_writes\000extended\000L1D L2I Sourced Writes\000event=0x82\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000 */
{ 78909 }, /* l1d_lmem_sourced_writes\000extended\000L1D Local Memory Sourced Writes\000event=0x87\000\00000\000A directory write to the Level-1 Data cache where the installed cache line was sourced from memory that is attached to the same book as the Data cache (Local Memory)\000 */
{ 80783 }, /* l1d_offbook_l3_sourced_writes\000extended\000L1D Off-Book L3 Sourced Writes\000event=0x92\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Book Level-3 cache without intervention\000 */
{ 82115 }, /* l1d_offbook_l3_sourced_writes_iv\000extended\000L1D Off-Book L3 Sourced Writes with Intervention\000event=0x98\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Book Level-3 cache with intervention\000 */
{ 81225 }, /* l1d_offbook_l4_sourced_writes\000extended\000L1D Off-Book L4 Sourced Writes\000event=0x94\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000 */
{ 80542 }, /* l1d_offchip_l3_sourced_writes\000extended\000L1D Off-Chip L3 Sourced Writes\000event=0x91\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache without intervention\000 */
{ 81856 }, /* l1d_offchip_l3_sourced_writes_iv\000extended\000L1D Off-Chip L3 Sourced Writes with Intervention\000event=0x97\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache with intervention\000 */
{ 81016 }, /* l1d_onbook_l4_sourced_writes\000extended\000L1D On-Book L4 Sourced Writes\000event=0x93\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On Book Level-4 cache\000 */
{ 80312 }, /* l1d_onchip_l3_sourced_writes\000extended\000L1D On-Chip L3 Sourced Writes\000event=0x90\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from an On Chip Level-3 cache without intervention\000 */
{ 81609 }, /* l1d_onchip_l3_sourced_writes_iv\000extended\000L1D On-Chip L3 Sourced Writes with Intervention\000event=0x96\000\00000\000A directory write to the Level-1 Data cache directory where the returned cache line was sourced from a On Chip Level-3 cache with intervention\000 */
{ 788 }, /* l1d_penalty_cycles\000basic\000Level-1 D-Cache Penalty Cycle Count\000event=5\000\00000\000This counter counts the total number of cache penalty cycles for level-1 data cache\000 */
{ 79415 }, /* l1d_ro_excl_writes\000extended\000L1D Read-only Exclusive Writes\000event=0x8a\000\00000\000A directory write to the Level-1 Data Cache where the line was originally in a Read-Only state in the cache but has been updated to be in the Exclusive state that allows stores to the cache line\000 */
{ 289 }, /* l1i_dir_writes\000basic\000Level-1 I-Cache Directory Write Count\000event=2\000\00000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes\000 */
{ 78363 }, /* l1i_l2i_sourced_writes\000extended\000L1I L2I Sourced Writes\000event=0x83\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from the Level-2 Instruction cache\000 */
{ 79155 }, /* l1i_lmem_sourced_writes\000extended\000L1I Local Memory Sourced Writes\000event=0x89\000\00000\000A directory write to the Level-1 Instruction cache where the installed cache line was sourced from memory that is attached to the same book as the Instruction cache (Local Memory)\000 */
{ 82851 }, /* l1i_offbook_l3_sourced_writes\000extended\000L1I Off-Book L3 Sourced Writes\000event=0x9b\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Book Level-3 cache without intervention\000 */
{ 84211 }, /* l1i_offbook_l3_sourced_writes_iv\000extended\000L1I Off-Book L3 Sourced Writes with Intervention\000event=0xa1\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Book Level-3 cache with intervention\000 */
{ 83307 }, /* l1i_offbook_l4_sourced_writes\000extended\000L1I Off-Book L4 Sourced Writes\000event=0x9d\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Book Level-4 cache\000 */
{ 82603 }, /* l1i_offchip_l3_sourced_writes\000extended\000L1I Off-Chip L3 Sourced Writes\000event=0x9a\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache without intervention\000 */
{ 83945 }, /* l1i_offchip_l3_sourced_writes_iv\000extended\000L1I Off-Chip L3 Sourced Writes with Intervention\000event=0xa0\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an Off Chip/On Book Level-3 cache with intervention\000 */
{ 83091 }, /* l1i_onbook_l4_sourced_writes\000extended\000L1I On-Book L4 Sourced Writes\000event=0x9c\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Book Level-4 cache\000 */
{ 82366 }, /* l1i_onchip_l3_sourced_writes\000extended\000L1I On-Chip L3 Sourced Writes\000event=0x99\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Chip Level-3 cache without intervention\000 */
{ 83690 }, /* l1i_onchip_l3_sourced_writes_iv\000extended\000L1I On-Chip L3 Sourced Writes with Intervention\000event=0x9f\000\00000\000A directory write to the Level-1 Instruction cache directory where the returned cache line was sourced from an On Chip Level-3 cache with intervention\000 */
{ 460 }, /* l1i_penalty_cycles\000basic\000Level-1 I-Cache Penalty Cycle Count\000event=3\000\00000\000This counter counts the total number of cache penalty cycles for level-1 instruction cache or unified cache\000 */
{ 2925 }, /* prng_blocked_cycles\000crypto\000PRNG Blocked Cycle Count\000event=0x43\000\00000\000This counter counts the total number of CPU cycles blocked for the pseudorandom-number-generation functions issued by the CPU because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 2636 }, /* prng_blocked_functions\000crypto\000PRNG Blocked Function Count\000event=0x42\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions that are issued by the CPU and are blocked because the DEA/AES/SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 2418 }, /* prng_cycles\000crypto\000PRNG Cycle Count\000event=0x41\000\00000\000This counter counts the total number of CPU cycles when the DEA/AES/SHA coprocessor is busy performing the pseudorandom- number-generation functions issued by the CPU\000 */
{ 2258 }, /* prng_functions\000crypto\000PRNG Function Count\000event=0x40\000\00000\000This counter counts the total number of the pseudorandom-number-generation functions issued by the CPU\000 */
{ 945 }, /* problem_state_cpu_cycles\000basic\000Problem-State Cycle Count\000event=0x20\000\00000\000This counter counts the total number of CPU cycles when the CPU is in the problem state, excluding the number of cycles while the CPU is in the wait state\000 */
{ 1172 }, /* problem_state_instructions\000basic\000Problem-State Instruction Count\000event=0x21\000\00000\000This counter counts the total number of instructions executed by the CPU while in the problem state\000 */
{ 1822 }, /* problem_state_l1d_dir_writes\000basic\000Problem-State Level-1 D-Cache Directory Write Count\000event=0x24\000\00000\000This counter counts the total number of level-1 data-cache directory writes while the CPU is in the problem state\000 */
{ 2038 }, /* problem_state_l1d_penalty_cycles\000basic\000Problem-State Level-1 D-Cache Penalty Cycle Count\000event=0x25\000\00000\000This counter counts the total number of penalty cycles for level-1 data cache while the CPU is in the problem state\000 */
{ 1352 }, /* problem_state_l1i_dir_writes\000basic\000Problem-State Level-1 I-Cache Directory Write Count\000event=0x22\000\00000\000This counter counts the total number of level-1 instruction-cache or unified-cache directory writes while the CPU is in the problem state\000 */
{ 1592 }, /* problem_state_l1i_penalty_cycles\000basic\000Level-1 I-Cache Penalty Cycle Count\000event=0x23\000\00000\000This counter counts the total number of penalty cycles for level-1 instruction cache or unified cache while the CPU is in the problem state\000 */
{ 3769 }, /* sha_blocked_cycles\000crypto\000SHA Blocked Cycle Count\000event=0x47\000\00000\000This counter counts the total number of CPU cycles blocked for the SHA functions issued by the CPU because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 3517 }, /* sha_blocked_functions\000crypto\000SHA Blocked Function Count\000event=0x46\000\00000\000This counter counts the total number of the SHA functions that are issued by the CPU and are blocked because the SHA coprocessor is busy performing a function issued by another CPU\000 */
{ 3337 }, /* sha_cycles\000crypto\000SHA Cycle Count\000event=0x45\000\00000\000This counter counts the total number of CPU cycles when the SHA coprocessor is busy performing the SHA functions issued by the CPU\000 */
{ 3206 }, /* sha_functions\000crypto\000SHA Function Count\000event=0x44\000\00000\000This counter counts the total number of the SHA functions issued by the CPU\000 */
{ 8639 }, /* tlb2_crste_hpage_writes\000extended\000TLB2 CRSTE One-Megabyte Page Writes\000event=0x8e\000\00000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays for a one-megabyte large page translation\000 */
{ 80155 }, /* tlb2_crste_writes\000extended\000TLB2 CRSTE Writes\000event=0x8f\000\00000\000A translation entry has been written to the Level-2 TLB Common Region Segment Table Entry arrays\000 */
{ 80019 }, /* tlb2_pte_writes\000extended\000TLB2 PTE Writes\000event=0x8d\000\00000\000A translation entry has been written to the Level-2 TLB Page Table Entry arrays\000 */
{ 84636 }, /* tx_c_tabort_no_special\000extended\000Aborted transactions in constrained TX mode not using special completion logic\000event=0xb2\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is not using any special logic to allow the transaction to complete\000 */
{ 84921 }, /* tx_c_tabort_special\000extended\000Aborted transactions in constrained TX mode using special completion logic\000event=0xb3\000\00000\000A transaction abort has occurred in a constrained transactional-execution mode and the CPU is using special logic to allow the transaction to complete\000 */
{ 83526 }, /* tx_c_tend\000extended\000Completed TEND instructions in constrained TX mode\000event=0x9e\000\00000\000A TEND instruction has completed in a constrained transactional-execution mode\000 */
{ 84469 }, /* tx_nc_tabort\000extended\000Aborted transactions in non-constrained TX mode\000event=0xb1\000\00000\000A transaction abort has occurred in a nonconstrained transactional-execution mode\000 */
{ 81437 }, /* tx_nc_tend\000extended\000Completed TEND instructions in non-constrained TX mode\000event=0x95\000\00000\000A TEND instruction has completed in a nonconstrained transactional-execution mode\000 */

};

const struct pmu_table_entry pmu_events__cf_zec12[] = {
{
     .entries = pmu_events__cf_zec12_cpum_cf,
     .num_entries = ARRAY_SIZE(pmu_events__cf_zec12_cpum_cf),
     .pmu_name = { 0 /* cpum_cf\000 */ },
},
};

static const struct compact_pmu_event pmu_metrics__cf_zec12_default_core[] = {
{ 86887 }, /* transaction\000\000TX_C_TEND + TX_NC_TEND + TX_NC_TABORT + TX_C_TABORT_SPECIAL + TX_C_TABORT_NO_SPECIAL\000\000Transaction count\000\000\000\000\000\00000 */

};

const struct pmu_table_entry pmu_metrics__cf_zec12[] = {
{
     .entries = pmu_metrics__cf_zec12_default_core,
     .num_entries = ARRAY_SIZE(pmu_metrics__cf_zec12_default_core),
     .pmu_name = { 86874 /* default_core\000 */ },
},
};

static const struct compact_pmu_event pmu_events__test_soc_cpu_default_core[] = {
{ 85191 }, /* bp_l1_btb_correct\000branch\000L1 BTB Correction\000event=0x8a\000\00000\000\000 */
{ 85250 }, /* bp_l2_btb_correct\000branch\000L2 BTB Correction\000event=0x8b\000\00000\000\000 */
{ 85503 }, /* dispatch_blocked.any\000other\000Memory cluster signals to block micro-op dispatch for any reason\000event=9,period=200000,umask=0x20\000\00000\000\000 */
{ 85633 }, /* eist_trans\000other\000Number of Enhanced Intel SpeedStep(R) Technology (EIST) transitions\000event=0x3a,period=200000\000\00000\000\000 */
{ 85309 }, /* l3_cache_rd\000cache\000L3 cache access, read\000event=0x40\000\00000\000Attributable Level 3 cache access, read\000 */
{ 85404 }, /* segment_reg_loads.any\000other\000Number of segment register loads\000event=6,period=200000,umask=0x80\000\00000\000\000 */
};
static const struct compact_pmu_event pmu_events__test_soc_cpu_hisi_sccl_ddrc[] = {
{ 85763 }, /* uncore_hisi_ddrc.flux_wcmd\000uncore\000DDRC write commands\000event=2\000\00000\000DDRC write commands\000 */
};
static const struct compact_pmu_event pmu_events__test_soc_cpu_hisi_sccl_l3c[] = {
{ 86242 }, /* uncore_hisi_l3c.rd_hit_cpipe\000uncore\000Total read hits\000event=7\000\00000\000Total read hits\000 */
};
static const struct compact_pmu_event pmu_events__test_soc_cpu_uncore_cbox[] = {
{ 86092 }, /* event-hyphen\000uncore\000UNC_CBO_HYPHEN\000event=0xe0\000\00000\000UNC_CBO_HYPHEN\000 */
{ 86157 }, /* event-two-hyph\000uncore\000UNC_CBO_TWO_HYPH\000event=0xc0\000\00000\000UNC_CBO_TWO_HYPH\000 */
{ 85861 }, /* unc_cbo_xsnp_response.miss_eviction\000uncore\000A cross-core snoop resulted from L3 Eviction which misses in some processor core\000event=0x22,umask=0x81\000\00000\000A cross-core snoop resulted from L3 Eviction which misses in some processor core\000 */
};
static const struct compact_pmu_event pmu_events__test_soc_cpu_uncore_imc[] = {
{ 86452 }, /* uncore_imc.cache_hits\000uncore\000Total cache hits\000event=0x34\000\00000\000Total cache hits\000 */
};
static const struct compact_pmu_event pmu_events__test_soc_cpu_uncore_imc_free_running[] = {
{ 86346 }, /* uncore_imc_free_running.cache_miss\000uncore\000Total cache misses\000event=0x12\000\00000\000Total cache misses\000 */

};

const struct pmu_table_entry pmu_events__test_soc_cpu[] = {
{
     .entries = pmu_events__test_soc_cpu_default_core,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_cpu_default_core),
     .pmu_name = { 86874 /* default_core\000 */ },
},
{
     .entries = pmu_events__test_soc_cpu_hisi_sccl_ddrc,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_cpu_hisi_sccl_ddrc),
     .pmu_name = { 85748 /* hisi_sccl,ddrc\000 */ },
},
{
     .entries = pmu_events__test_soc_cpu_hisi_sccl_l3c,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_cpu_hisi_sccl_l3c),
     .pmu_name = { 86228 /* hisi_sccl,l3c\000 */ },
},
{
     .entries = pmu_events__test_soc_cpu_uncore_cbox,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_cpu_uncore_cbox),
     .pmu_name = { 85849 /* uncore_cbox\000 */ },
},
{
     .entries = pmu_events__test_soc_cpu_uncore_imc,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_cpu_uncore_imc),
     .pmu_name = { 86441 /* uncore_imc\000 */ },
},
{
     .entries = pmu_events__test_soc_cpu_uncore_imc_free_running,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_cpu_uncore_imc_free_running),
     .pmu_name = { 86322 /* uncore_imc_free_running\000 */ },
},
};

static const struct compact_pmu_event pmu_metrics__test_soc_cpu_default_core[] = {
{ 93118 }, /* CPI\000\0001 / IPC\000\000\000\000\000\000\000\00000 */
{ 93799 }, /* DCache_L2_All\000\000DCache_L2_All_Hits + DCache_L2_All_Miss\000\000\000\000\000\000\000\00000 */
{ 93571 }, /* DCache_L2_All_Hits\000\000l2_rqsts.demand_data_rd_hit + l2_rqsts.pf_hit + l2_rqsts.rfo_hit\000\000\000\000\000\000\000\00000 */
{ 93665 }, /* DCache_L2_All_Miss\000\000max(l2_rqsts.all_demand_data_rd - l2_rqsts.demand_data_rd_hit, 0) + l2_rqsts.pf_miss + l2_rqsts.rfo_miss\000\000\000\000\000\000\000\00000 */
{ 93863 }, /* DCache_L2_Hits\000\000d_ratio(DCache_L2_All_Hits, DCache_L2_All)\000\000\000\000\000\000\000\00000 */
{ 93931 }, /* DCache_L2_Misses\000\000d_ratio(DCache_L2_All_Miss, DCache_L2_All)\000\000\000\000\000\000\000\00000 */
{ 93203 }, /* Frontend_Bound_SMT\000\000idq_uops_not_delivered.core / (4 * (cpu_clk_unhalted.thread / 2 * (1 + cpu_clk_unhalted.one_thread_active / cpu_clk_unhalted.ref_xclk)))\000\000\000\000\000\000\000\00000 */
{ 93140 }, /* IPC\000group1\000inst_retired.any / cpu_clk_unhalted.thread\000\000\000\000\000\000\000\00000 */
{ 94065 }, /* L1D_Cache_Fill_BW\000\00064 * l1d.replacement / 1e9 / duration_time\000\000\000\000\000\000\000\00000 */
{ 94001 }, /* M1\000\000ipc + M2\000\000\000\000\000\000\000\00000 */
{ 94023 }, /* M2\000\000ipc + M1\000\000\000\000\000\000\000\00000 */
{ 94045 }, /* M3\000\0001 / M3\000\000\000\000\000\000\000\00000 */
{ 93500 }, /* cache_miss_cycles\000group1\000dcache_miss_cpi + icache_miss_cycles\000\000\000\000\000\000\000\00000 */
{ 93369 }, /* dcache_miss_cpi\000\000l1d\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000\000\00000 */
{ 93433 }, /* icache_miss_cycles\000\000l1i\\-loads\\-misses / inst_retired.any\000\000\000\000\000\000\000\00000 */

};

const struct pmu_table_entry pmu_metrics__test_soc_cpu[] = {
{
     .entries = pmu_metrics__test_soc_cpu_default_core,
     .num_entries = ARRAY_SIZE(pmu_metrics__test_soc_cpu_default_core),
     .pmu_name = { 86874 /* default_core\000 */ },
},
};

static const struct compact_pmu_event pmu_events__test_soc_sys_uncore_sys_ccn_pmu[] = {
{ 86641 }, /* sys_ccn_pmu.read_cycles\000uncore\000ccn read-cycles event\000config=0x2c\0000x01\00000\000\000 */
};
static const struct compact_pmu_event pmu_events__test_soc_sys_uncore_sys_cmn_pmu[] = {
{ 86734 }, /* sys_cmn_pmu.hnf_cache_miss\000uncore\000Counts total cache misses in first lookup result (high priority)\000eventid=1,type=5\000(434|436|43c|43a).*\00000\000\000 */
};
static const struct compact_pmu_event pmu_events__test_soc_sys_uncore_sys_ddr_pmu[] = {
{ 86549 }, /* sys_ddr_pmu.write_cycles\000uncore\000ddr write-cycles event\000event=0x2b\000v8\00000\000\000 */

};

const struct pmu_table_entry pmu_events__test_soc_sys[] = {
{
     .entries = pmu_events__test_soc_sys_uncore_sys_ccn_pmu,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_sys_uncore_sys_ccn_pmu),
     .pmu_name = { 86622 /* uncore_sys_ccn_pmu\000 */ },
},
{
     .entries = pmu_events__test_soc_sys_uncore_sys_cmn_pmu,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_sys_uncore_sys_cmn_pmu),
     .pmu_name = { 86715 /* uncore_sys_cmn_pmu\000 */ },
},
{
     .entries = pmu_events__test_soc_sys_uncore_sys_ddr_pmu,
     .num_entries = ARRAY_SIZE(pmu_events__test_soc_sys_uncore_sys_ddr_pmu),
     .pmu_name = { 86530 /* uncore_sys_ddr_pmu\000 */ },
},
};


/* Struct used to make the PMU event table implementation opaque to callers. */
struct pmu_events_table {
        const struct pmu_table_entry *pmus;
        uint32_t num_pmus;
};

/* Struct used to make the PMU metric table implementation opaque to callers. */
struct pmu_metrics_table {
        const struct pmu_table_entry *pmus;
        uint32_t num_pmus;
};

/*
 * Map a CPU to its table of PMU events. The CPU is identified by the
 * cpuid field, which is an arch-specific identifier for the CPU.
 * The identifier specified in tools/perf/pmu-events/arch/xxx/mapfile
 * must match the get_cpuid_str() in tools/perf/arch/xxx/util/header.c)
 *
 * The  cpuid can contain any character other than the comma.
 */
struct pmu_events_map {
        const char *arch;
        const char *cpuid;
        struct pmu_events_table event_table;
        struct pmu_metrics_table metric_table;
};

/*
 * Global table mapping each known CPU for the architecture to its
 * table of PMU events.
 */
const struct pmu_events_map pmu_events_map[] = {
{
	.arch = "s390",
	.cpuid = "^IBM.209[78].*[13]\\.[1-5].[[:xdigit:]]+$",
	.event_table = {
		.pmus = pmu_events__cf_z10,
		.num_pmus = ARRAY_SIZE(pmu_events__cf_z10)
	},
	.metric_table = {
		.pmus = NULL,
		.num_pmus = 0
	}
},
{
	.arch = "s390",
	.cpuid = "^IBM.281[78].*[13]\\.[1-5].[[:xdigit:]]+$",
	.event_table = {
		.pmus = pmu_events__cf_z196,
		.num_pmus = ARRAY_SIZE(pmu_events__cf_z196)
	},
	.metric_table = {
		.pmus = NULL,
		.num_pmus = 0
	}
},
{
	.arch = "s390",
	.cpuid = "^IBM.282[78].*[13]\\.[1-5].[[:xdigit:]]+$",
	.event_table = {
		.pmus = pmu_events__cf_zec12,
		.num_pmus = ARRAY_SIZE(pmu_events__cf_zec12)
	},
	.metric_table = {
		.pmus = pmu_metrics__cf_zec12,
		.num_pmus = ARRAY_SIZE(pmu_metrics__cf_zec12)
	}
},
{
	.arch = "s390",
	.cpuid = "^IBM.296[45].*[13]\\.[1-5].[[:xdigit:]]+$",
	.event_table = {
		.pmus = pmu_events__cf_z13,
		.num_pmus = ARRAY_SIZE(pmu_events__cf_z13)
	},
	.metric_table = {
		.pmus = pmu_metrics__cf_z13,
		.num_pmus = ARRAY_SIZE(pmu_metrics__cf_z13)
	}
},
{
	.arch = "s390",
	.cpuid = "^IBM.390[67].*[13]\\.[1-5].[[:xdigit:]]+$",
	.event_table = {
		.pmus = pmu_events__cf_z14,
		.num_pmus = ARRAY_SIZE(pmu_events__cf_z14)
	},
	.metric_table = {
		.pmus = pmu_metrics__cf_z14,
		.num_pmus = ARRAY_SIZE(pmu_metrics__cf_z14)
	}
},
{
	.arch = "s390",
	.cpuid = "^IBM.856[12].*3\\.6.[[:xdigit:]]+$",
	.event_table = {
		.pmus = pmu_events__cf_z15,
		.num_pmus = ARRAY_SIZE(pmu_events__cf_z15)
	},
	.metric_table = {
		.pmus = pmu_metrics__cf_z15,
		.num_pmus = ARRAY_SIZE(pmu_metrics__cf_z15)
	}
},
{
	.arch = "s390",
	.cpuid = "^IBM.393[12].*3\\.7.[[:xdigit:]]+$",
	.event_table = {
		.pmus = pmu_events__cf_z16,
		.num_pmus = ARRAY_SIZE(pmu_events__cf_z16)
	},
	.metric_table = {
		.pmus = pmu_metrics__cf_z16,
		.num_pmus = ARRAY_SIZE(pmu_metrics__cf_z16)
	}
},
{
	.arch = "testarch",
	.cpuid = "testcpu",
	.event_table = {
		.pmus = pmu_events__test_soc_cpu,
		.num_pmus = ARRAY_SIZE(pmu_events__test_soc_cpu),
	},
	.metric_table = {
		.pmus = pmu_metrics__test_soc_cpu,
		.num_pmus = ARRAY_SIZE(pmu_metrics__test_soc_cpu),
	}
},
{
	.arch = 0,
	.cpuid = 0,
	.event_table = { 0, 0 },
	.metric_table = { 0, 0 },
}
};

struct pmu_sys_events {
	const char *name;
	struct pmu_events_table event_table;
	struct pmu_metrics_table metric_table;
};

static const struct pmu_sys_events pmu_sys_event_tables[] = {
	{
		.event_table = {
			.pmus = pmu_events__test_soc_sys,
			.num_pmus = ARRAY_SIZE(pmu_events__test_soc_sys)
		},
		.name = "pmu_events__test_soc_sys",
	},
	{
		.event_table = { 0, 0 },
		.metric_table = { 0, 0 },
	},
};

static void decompress_event(int offset, struct pmu_event *pe)
{
	const char *p = &big_c_string[offset];

	pe->name = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->topic = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->desc = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->event = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->compat = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->deprecated = *p - '0';
	p++;
	pe->perpkg = *p - '0';
	p++;
	pe->unit = (*p == '\0' ? NULL : p);
	while (*p++);
	pe->long_desc = (*p == '\0' ? NULL : p);
}

static void decompress_metric(int offset, struct pmu_metric *pm)
{
	const char *p = &big_c_string[offset];

	pm->metric_name = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_group = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_expr = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metric_threshold = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->desc = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->long_desc = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->unit = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->compat = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->metricgroup_no_group = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->default_metricgroup_name = (*p == '\0' ? NULL : p);
	while (*p++);
	pm->aggr_mode = *p - '0';
	p++;
	pm->event_grouping = *p - '0';
}

static int pmu_events_table__for_each_event_pmu(const struct pmu_events_table *table,
                                                const struct pmu_table_entry *pmu,
                                                pmu_event_iter_fn fn,
                                                void *data)
{
        int ret;
        struct pmu_event pe = {
                .pmu = &big_c_string[pmu->pmu_name.offset],
        };

        for (uint32_t i = 0; i < pmu->num_entries; i++) {
                decompress_event(pmu->entries[i].offset, &pe);
                if (!pe.name)
                        continue;
                ret = fn(&pe, table, data);
                if (ret)
                        return ret;
        }
        return 0;
 }

static int pmu_events_table__find_event_pmu(const struct pmu_events_table *table,
                                            const struct pmu_table_entry *pmu,
                                            const char *name,
                                            pmu_event_iter_fn fn,
                                            void *data)
{
        struct pmu_event pe = {
                .pmu = &big_c_string[pmu->pmu_name.offset],
        };
        int low = 0, high = pmu->num_entries - 1;

        while (low <= high) {
                int cmp, mid = (low + high) / 2;

                decompress_event(pmu->entries[mid].offset, &pe);

                if (!pe.name && !name)
                        goto do_call;

                if (!pe.name && name) {
                        low = mid + 1;
                        continue;
                }
                if (pe.name && !name) {
                        high = mid - 1;
                        continue;
                }

                cmp = strcasecmp(pe.name, name);
                if (cmp < 0) {
                        low = mid + 1;
                        continue;
                }
                if (cmp > 0) {
                        high = mid - 1;
                        continue;
                }
  do_call:
                return fn ? fn(&pe, table, data) : 0;
        }
        return -1000;
}

int pmu_events_table__for_each_event(const struct pmu_events_table *table,
                                    struct perf_pmu *pmu,
                                    pmu_event_iter_fn fn,
                                    void *data)
{
        for (size_t i = 0; i < table->num_pmus; i++) {
                const struct pmu_table_entry *table_pmu = &table->pmus[i];
                const char *pmu_name = &big_c_string[table_pmu->pmu_name.offset];
                int ret;

                if (pmu && !pmu__name_match(pmu, pmu_name))
                        continue;

                ret = pmu_events_table__for_each_event_pmu(table, table_pmu, fn, data);
                if (pmu || ret)
                        return ret;
        }
        return 0;
}

int pmu_events_table__find_event(const struct pmu_events_table *table,
                                 struct perf_pmu *pmu,
                                 const char *name,
                                 pmu_event_iter_fn fn,
                                 void *data)
{
        for (size_t i = 0; i < table->num_pmus; i++) {
                const struct pmu_table_entry *table_pmu = &table->pmus[i];
                const char *pmu_name = &big_c_string[table_pmu->pmu_name.offset];
                int ret;

                if (!pmu__name_match(pmu, pmu_name))
                        continue;

                ret = pmu_events_table__find_event_pmu(table, table_pmu, name, fn, data);
                if (ret != -1000)
                        return ret;
        }
        return -1000;
}

size_t pmu_events_table__num_events(const struct pmu_events_table *table,
                                    struct perf_pmu *pmu)
{
        size_t count = 0;

        for (size_t i = 0; i < table->num_pmus; i++) {
                const struct pmu_table_entry *table_pmu = &table->pmus[i];
                const char *pmu_name = &big_c_string[table_pmu->pmu_name.offset];

                if (pmu__name_match(pmu, pmu_name))
                        count += table_pmu->num_entries;
        }
        return count;
}

static int pmu_metrics_table__for_each_metric_pmu(const struct pmu_metrics_table *table,
                                                const struct pmu_table_entry *pmu,
                                                pmu_metric_iter_fn fn,
                                                void *data)
{
        int ret;
        struct pmu_metric pm = {
                .pmu = &big_c_string[pmu->pmu_name.offset],
        };

        for (uint32_t i = 0; i < pmu->num_entries; i++) {
                decompress_metric(pmu->entries[i].offset, &pm);
                if (!pm.metric_expr)
                        continue;
                ret = fn(&pm, table, data);
                if (ret)
                        return ret;
        }
        return 0;
}

int pmu_metrics_table__for_each_metric(const struct pmu_metrics_table *table,
                                     pmu_metric_iter_fn fn,
                                     void *data)
{
        for (size_t i = 0; i < table->num_pmus; i++) {
                int ret = pmu_metrics_table__for_each_metric_pmu(table, &table->pmus[i],
                                                                 fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

static const struct pmu_events_map *map_for_pmu(struct perf_pmu *pmu)
{
        static struct {
                const struct pmu_events_map *map;
                struct perf_pmu *pmu;
        } last_result;
        static struct {
                const struct pmu_events_map *map;
                char *cpuid;
        } last_map_search;
        static bool has_last_result, has_last_map_search;
        const struct pmu_events_map *map = NULL;
        char *cpuid = NULL;
        size_t i;

        if (has_last_result && last_result.pmu == pmu)
                return last_result.map;

        cpuid = perf_pmu__getcpuid(pmu);

        /*
         * On some platforms which uses cpus map, cpuid can be NULL for
         * PMUs other than CORE PMUs.
         */
        if (!cpuid)
                goto out_update_last_result;

        if (has_last_map_search && !strcmp(last_map_search.cpuid, cpuid)) {
                map = last_map_search.map;
                free(cpuid);
        } else {
                i = 0;
                for (;;) {
                        map = &pmu_events_map[i++];

                        if (!map->arch) {
                                map = NULL;
                                break;
                        }

                        if (!strcmp_cpuid_str(map->cpuid, cpuid))
                                break;
               }
               free(last_map_search.cpuid);
               last_map_search.cpuid = cpuid;
               last_map_search.map = map;
               has_last_map_search = true;
        }
out_update_last_result:
        last_result.pmu = pmu;
        last_result.map = map;
        has_last_result = true;
        return map;
}

const struct pmu_events_table *perf_pmu__find_events_table(struct perf_pmu *pmu)
{
        const struct pmu_events_map *map = map_for_pmu(pmu);

        if (!map)
                return NULL;

        if (!pmu)
                return &map->event_table;

        for (size_t i = 0; i < map->event_table.num_pmus; i++) {
                const struct pmu_table_entry *table_pmu = &map->event_table.pmus[i];
                const char *pmu_name = &big_c_string[table_pmu->pmu_name.offset];

                if (pmu__name_match(pmu, pmu_name))
                         return &map->event_table;
        }
        return NULL;
}

const struct pmu_metrics_table *perf_pmu__find_metrics_table(struct perf_pmu *pmu)
{
        const struct pmu_events_map *map = map_for_pmu(pmu);

        if (!map)
                return NULL;

        if (!pmu)
                return &map->metric_table;

        for (size_t i = 0; i < map->metric_table.num_pmus; i++) {
                const struct pmu_table_entry *table_pmu = &map->metric_table.pmus[i];
                const char *pmu_name = &big_c_string[table_pmu->pmu_name.offset];

                if (pmu__name_match(pmu, pmu_name))
                           return &map->metric_table;
        }
        return NULL;
}

const struct pmu_events_table *find_core_events_table(const char *arch, const char *cpuid)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                if (!strcmp(tables->arch, arch) && !strcmp_cpuid_str(tables->cpuid, cpuid))
                        return &tables->event_table;
        }
        return NULL;
}

const struct pmu_metrics_table *find_core_metrics_table(const char *arch, const char *cpuid)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                if (!strcmp(tables->arch, arch) && !strcmp_cpuid_str(tables->cpuid, cpuid))
                        return &tables->metric_table;
        }
        return NULL;
}

int pmu_for_each_core_event(pmu_event_iter_fn fn, void *data)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                int ret = pmu_events_table__for_each_event(&tables->event_table,
                                                           /*pmu=*/ NULL, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

int pmu_for_each_core_metric(pmu_metric_iter_fn fn, void *data)
{
        for (const struct pmu_events_map *tables = &pmu_events_map[0];
             tables->arch;
             tables++) {
                int ret = pmu_metrics_table__for_each_metric(&tables->metric_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

const struct pmu_events_table *find_sys_events_table(const char *name)
{
        for (const struct pmu_sys_events *tables = &pmu_sys_event_tables[0];
             tables->name;
             tables++) {
                if (!strcmp(tables->name, name))
                        return &tables->event_table;
        }
        return NULL;
}

int pmu_for_each_sys_event(pmu_event_iter_fn fn, void *data)
{
        for (const struct pmu_sys_events *tables = &pmu_sys_event_tables[0];
             tables->name;
             tables++) {
                int ret = pmu_events_table__for_each_event(&tables->event_table,
                                                           /*pmu=*/ NULL, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

int pmu_for_each_sys_metric(pmu_metric_iter_fn fn, void *data)
{
        for (const struct pmu_sys_events *tables = &pmu_sys_event_tables[0];
             tables->name;
             tables++) {
                int ret = pmu_metrics_table__for_each_metric(&tables->metric_table, fn, data);

                if (ret)
                        return ret;
        }
        return 0;
}

static const int metricgroups[][2] = {

};

const char *describe_metricgroup(const char *group)
{
        int low = 0, high = (int)ARRAY_SIZE(metricgroups) - 1;

        while (low <= high) {
                int mid = (low + high) / 2;
                const char *mgroup = &big_c_string[metricgroups[mid][0]];
                int cmp = strcmp(mgroup, group);

                if (cmp == 0) {
                        return &big_c_string[metricgroups[mid][1]];
                } else if (cmp < 0) {
                        low = mid + 1;
                } else {
                        high = mid - 1;
                }
        }
        return NULL;
}
